/***************************************************************************//**
* \file CapSenseButton_RegisterMap.h
* \version 7.0
*
* \brief
*   This file provides the definitions for the Component data structure register.
*
* \see CapSenseButton v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSenseButton_REGISTER_MAP_H)
#define CY_SENSE_CapSenseButton_REGISTER_MAP_H

#include <cytypes.h>
#include "CapSenseButton_Configuration.h"
#include "CapSenseButton_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define CapSenseButton_CONFIG_ID_VALUE                      (CapSenseButton_dsRam.configId)
#define CapSenseButton_CONFIG_ID_OFFSET                     (0u)
#define CapSenseButton_CONFIG_ID_SIZE                       (2u)
#define CapSenseButton_CONFIG_ID_PARAM_ID                   (0x87000000u)

#define CapSenseButton_DEVICE_ID_VALUE                      (CapSenseButton_dsRam.deviceId)
#define CapSenseButton_DEVICE_ID_OFFSET                     (2u)
#define CapSenseButton_DEVICE_ID_SIZE                       (2u)
#define CapSenseButton_DEVICE_ID_PARAM_ID                   (0x8B000002u)

#define CapSenseButton_HW_CLOCK_VALUE                       (CapSenseButton_dsRam.hwClock)
#define CapSenseButton_HW_CLOCK_OFFSET                      (4u)
#define CapSenseButton_HW_CLOCK_SIZE                        (2u)
#define CapSenseButton_HW_CLOCK_PARAM_ID                    (0x86000004u)

#define CapSenseButton_TUNER_CMD_VALUE                      (CapSenseButton_dsRam.tunerCmd)
#define CapSenseButton_TUNER_CMD_OFFSET                     (6u)
#define CapSenseButton_TUNER_CMD_SIZE                       (2u)
#define CapSenseButton_TUNER_CMD_PARAM_ID                   (0xA1000006u)

#define CapSenseButton_SCAN_COUNTER_VALUE                   (CapSenseButton_dsRam.scanCounter)
#define CapSenseButton_SCAN_COUNTER_OFFSET                  (8u)
#define CapSenseButton_SCAN_COUNTER_SIZE                    (2u)
#define CapSenseButton_SCAN_COUNTER_PARAM_ID                (0x85000008u)

#define CapSenseButton_STATUS_VALUE                         (CapSenseButton_dsRam.status)
#define CapSenseButton_STATUS_OFFSET                        (12u)
#define CapSenseButton_STATUS_SIZE                          (4u)
#define CapSenseButton_STATUS_PARAM_ID                      (0xCB00000Cu)

#define CapSenseButton_WDGT_ENABLE0_VALUE                   (CapSenseButton_dsRam.wdgtEnable[0u])
#define CapSenseButton_WDGT_ENABLE0_OFFSET                  (16u)
#define CapSenseButton_WDGT_ENABLE0_SIZE                    (4u)
#define CapSenseButton_WDGT_ENABLE0_PARAM_ID                (0xE6000010u)

#define CapSenseButton_WDGT_WORKING0_VALUE                  (CapSenseButton_dsRam.wdgtWorking[0u])
#define CapSenseButton_WDGT_WORKING0_OFFSET                 (20u)
#define CapSenseButton_WDGT_WORKING0_SIZE                   (4u)
#define CapSenseButton_WDGT_WORKING0_PARAM_ID               (0xCC000014u)

#define CapSenseButton_WDGT_STATUS0_VALUE                   (CapSenseButton_dsRam.wdgtStatus[0u])
#define CapSenseButton_WDGT_STATUS0_OFFSET                  (24u)
#define CapSenseButton_WDGT_STATUS0_SIZE                    (4u)
#define CapSenseButton_WDGT_STATUS0_PARAM_ID                (0xCF000018u)

#define CapSenseButton_SNS_STATUS0_VALUE                    (CapSenseButton_dsRam.snsStatus[0u])
#define CapSenseButton_SNS_STATUS0_OFFSET                   (28u)
#define CapSenseButton_SNS_STATUS0_SIZE                     (1u)
#define CapSenseButton_SNS_STATUS0_PARAM_ID                 (0x4900001Cu)

#define CapSenseButton_CSD0_CONFIG_VALUE                    (CapSenseButton_dsRam.csd0Config)
#define CapSenseButton_CSD0_CONFIG_OFFSET                   (30u)
#define CapSenseButton_CSD0_CONFIG_SIZE                     (2u)
#define CapSenseButton_CSD0_CONFIG_PARAM_ID                 (0xAB80001Eu)

#define CapSenseButton_MOD_CSD_CLK_VALUE                    (CapSenseButton_dsRam.modCsdClk)
#define CapSenseButton_MOD_CSD_CLK_OFFSET                   (32u)
#define CapSenseButton_MOD_CSD_CLK_SIZE                     (1u)
#define CapSenseButton_MOD_CSD_CLK_PARAM_ID                 (0x63800020u)

#define CapSenseButton_GLB_CRC_VALUE                        (CapSenseButton_dsRam.glbCrc)
#define CapSenseButton_GLB_CRC_OFFSET                       (34u)
#define CapSenseButton_GLB_CRC_SIZE                         (2u)
#define CapSenseButton_GLB_CRC_PARAM_ID                     (0x81000022u)

#define CapSenseButton_BUTTON0_CRC_VALUE                    (CapSenseButton_dsRam.wdgtList.button0.crc)
#define CapSenseButton_BUTTON0_CRC_OFFSET                   (36u)
#define CapSenseButton_BUTTON0_CRC_SIZE                     (2u)
#define CapSenseButton_BUTTON0_CRC_PARAM_ID                 (0x8C000024u)

#define CapSenseButton_BUTTON0_RESOLUTION_VALUE             (CapSenseButton_dsRam.wdgtList.button0.resolution)
#define CapSenseButton_BUTTON0_RESOLUTION_OFFSET            (38u)
#define CapSenseButton_BUTTON0_RESOLUTION_SIZE              (2u)
#define CapSenseButton_BUTTON0_RESOLUTION_PARAM_ID          (0xA6800026u)

#define CapSenseButton_BUTTON0_FINGER_TH_VALUE              (CapSenseButton_dsRam.wdgtList.button0.fingerTh)
#define CapSenseButton_BUTTON0_FINGER_TH_OFFSET             (40u)
#define CapSenseButton_BUTTON0_FINGER_TH_SIZE               (2u)
#define CapSenseButton_BUTTON0_FINGER_TH_PARAM_ID           (0xA9800028u)

#define CapSenseButton_BUTTON0_NOISE_TH_VALUE               (CapSenseButton_dsRam.wdgtList.button0.noiseTh)
#define CapSenseButton_BUTTON0_NOISE_TH_OFFSET              (42u)
#define CapSenseButton_BUTTON0_NOISE_TH_SIZE                (1u)
#define CapSenseButton_BUTTON0_NOISE_TH_PARAM_ID            (0x6D80002Au)

#define CapSenseButton_BUTTON0_NNOISE_TH_VALUE              (CapSenseButton_dsRam.wdgtList.button0.nNoiseTh)
#define CapSenseButton_BUTTON0_NNOISE_TH_OFFSET             (43u)
#define CapSenseButton_BUTTON0_NNOISE_TH_SIZE               (1u)
#define CapSenseButton_BUTTON0_NNOISE_TH_PARAM_ID           (0x6B80002Bu)

#define CapSenseButton_BUTTON0_HYSTERESIS_VALUE             (CapSenseButton_dsRam.wdgtList.button0.hysteresis)
#define CapSenseButton_BUTTON0_HYSTERESIS_OFFSET            (44u)
#define CapSenseButton_BUTTON0_HYSTERESIS_SIZE              (1u)
#define CapSenseButton_BUTTON0_HYSTERESIS_PARAM_ID          (0x6080002Cu)

#define CapSenseButton_BUTTON0_ON_DEBOUNCE_VALUE            (CapSenseButton_dsRam.wdgtList.button0.onDebounce)
#define CapSenseButton_BUTTON0_ON_DEBOUNCE_OFFSET           (45u)
#define CapSenseButton_BUTTON0_ON_DEBOUNCE_SIZE             (1u)
#define CapSenseButton_BUTTON0_ON_DEBOUNCE_PARAM_ID         (0x6680002Du)

#define CapSenseButton_BUTTON0_LOW_BSLN_RST_VALUE           (CapSenseButton_dsRam.wdgtList.button0.lowBslnRst)
#define CapSenseButton_BUTTON0_LOW_BSLN_RST_OFFSET          (46u)
#define CapSenseButton_BUTTON0_LOW_BSLN_RST_SIZE            (1u)
#define CapSenseButton_BUTTON0_LOW_BSLN_RST_PARAM_ID        (0x6C80002Eu)

#define CapSenseButton_BUTTON0_IDAC_MOD0_VALUE              (CapSenseButton_dsRam.wdgtList.button0.idacMod[0u])
#define CapSenseButton_BUTTON0_IDAC_MOD0_OFFSET             (47u)
#define CapSenseButton_BUTTON0_IDAC_MOD0_SIZE               (1u)
#define CapSenseButton_BUTTON0_IDAC_MOD0_PARAM_ID           (0x4C00002Fu)

#define CapSenseButton_BUTTON0_IDAC_GAIN_INDEX_VALUE        (CapSenseButton_dsRam.wdgtList.button0.idacGainIndex)
#define CapSenseButton_BUTTON0_IDAC_GAIN_INDEX_OFFSET       (48u)
#define CapSenseButton_BUTTON0_IDAC_GAIN_INDEX_SIZE         (1u)
#define CapSenseButton_BUTTON0_IDAC_GAIN_INDEX_PARAM_ID     (0x4D800030u)

#define CapSenseButton_BUTTON0_SNS_CLK_VALUE                (CapSenseButton_dsRam.wdgtList.button0.snsClk)
#define CapSenseButton_BUTTON0_SNS_CLK_OFFSET               (50u)
#define CapSenseButton_BUTTON0_SNS_CLK_SIZE                 (2u)
#define CapSenseButton_BUTTON0_SNS_CLK_PARAM_ID             (0xA2800032u)

#define CapSenseButton_BUTTON0_SNS_CLK_SOURCE_VALUE         (CapSenseButton_dsRam.wdgtList.button0.snsClkSource)
#define CapSenseButton_BUTTON0_SNS_CLK_SOURCE_OFFSET        (52u)
#define CapSenseButton_BUTTON0_SNS_CLK_SOURCE_SIZE          (1u)
#define CapSenseButton_BUTTON0_SNS_CLK_SOURCE_PARAM_ID      (0x4C800034u)

#define CapSenseButton_BUTTON0_SNS0_RAW0_VALUE              (CapSenseButton_dsRam.snsList.button0[0u].raw[0u])
#define CapSenseButton_BUTTON0_SNS0_RAW0_OFFSET             (54u)
#define CapSenseButton_BUTTON0_SNS0_RAW0_SIZE               (2u)
#define CapSenseButton_BUTTON0_SNS0_RAW0_PARAM_ID           (0x85000036u)

#define CapSenseButton_BUTTON0_SNS0_BSLN0_VALUE             (CapSenseButton_dsRam.snsList.button0[0u].bsln[0u])
#define CapSenseButton_BUTTON0_SNS0_BSLN0_OFFSET            (56u)
#define CapSenseButton_BUTTON0_SNS0_BSLN0_SIZE              (2u)
#define CapSenseButton_BUTTON0_SNS0_BSLN0_PARAM_ID          (0x8A000038u)

#define CapSenseButton_BUTTON0_SNS0_BSLN_INV0_VALUE         (CapSenseButton_dsRam.snsList.button0[0u].bslnInv[0u])
#define CapSenseButton_BUTTON0_SNS0_BSLN_INV0_OFFSET        (58u)
#define CapSenseButton_BUTTON0_SNS0_BSLN_INV0_SIZE          (2u)
#define CapSenseButton_BUTTON0_SNS0_BSLN_INV0_PARAM_ID      (0x8600003Au)

#define CapSenseButton_BUTTON0_SNS0_BSLN_EXT0_VALUE         (CapSenseButton_dsRam.snsList.button0[0u].bslnExt[0u])
#define CapSenseButton_BUTTON0_SNS0_BSLN_EXT0_OFFSET        (60u)
#define CapSenseButton_BUTTON0_SNS0_BSLN_EXT0_SIZE          (1u)
#define CapSenseButton_BUTTON0_SNS0_BSLN_EXT0_PARAM_ID      (0x4300003Cu)

#define CapSenseButton_BUTTON0_SNS0_DIFF_VALUE              (CapSenseButton_dsRam.snsList.button0[0u].diff)
#define CapSenseButton_BUTTON0_SNS0_DIFF_OFFSET             (62u)
#define CapSenseButton_BUTTON0_SNS0_DIFF_SIZE               (2u)
#define CapSenseButton_BUTTON0_SNS0_DIFF_PARAM_ID           (0x8700003Eu)

#define CapSenseButton_BUTTON0_SNS0_NEG_BSLN_RST_CNT0_VALUE (CapSenseButton_dsRam.snsList.button0[0u].negBslnRstCnt[0u])
#define CapSenseButton_BUTTON0_SNS0_NEG_BSLN_RST_CNT0_OFFSET (64u)
#define CapSenseButton_BUTTON0_SNS0_NEG_BSLN_RST_CNT0_SIZE  (1u)
#define CapSenseButton_BUTTON0_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID (0x42000040u)

#define CapSenseButton_BUTTON0_SNS0_IDAC_COMP0_VALUE        (CapSenseButton_dsRam.snsList.button0[0u].idacComp[0u])
#define CapSenseButton_BUTTON0_SNS0_IDAC_COMP0_OFFSET       (65u)
#define CapSenseButton_BUTTON0_SNS0_IDAC_COMP0_SIZE         (1u)
#define CapSenseButton_BUTTON0_SNS0_IDAC_COMP0_PARAM_ID     (0x44000041u)

#define CapSenseButton_TEST_RESULT_MASK_VALUE               (CapSenseButton_dsRam.selfTest.testResultMask)
#define CapSenseButton_TEST_RESULT_MASK_OFFSET              (68u)
#define CapSenseButton_TEST_RESULT_MASK_SIZE                (4u)
#define CapSenseButton_TEST_RESULT_MASK_PARAM_ID            (0xEF000044u)

#define CapSenseButton_EXT_CAP0_VALUE                       (CapSenseButton_dsRam.selfTest.extCap[0u])
#define CapSenseButton_EXT_CAP0_OFFSET                      (72u)
#define CapSenseButton_EXT_CAP0_SIZE                        (2u)
#define CapSenseButton_EXT_CAP0_PARAM_ID                    (0xA3000048u)

#define CapSenseButton_VDDA_VOLTAGE_VALUE                   (CapSenseButton_dsRam.selfTest.vddaVoltage)
#define CapSenseButton_VDDA_VOLTAGE_OFFSET                  (74u)
#define CapSenseButton_VDDA_VOLTAGE_SIZE                    (2u)
#define CapSenseButton_VDDA_VOLTAGE_PARAM_ID                (0xAF00004Au)

#define CapSenseButton_GLB_CRC_CALC_VALUE                   (CapSenseButton_dsRam.selfTest.glbCrcCalc)
#define CapSenseButton_GLB_CRC_CALC_OFFSET                  (76u)
#define CapSenseButton_GLB_CRC_CALC_SIZE                    (2u)
#define CapSenseButton_GLB_CRC_CALC_PARAM_ID                (0xA200004Cu)

#define CapSenseButton_WDGT_CRC_CALC_VALUE                  (CapSenseButton_dsRam.selfTest.wdgtCrcCalc)
#define CapSenseButton_WDGT_CRC_CALC_OFFSET                 (78u)
#define CapSenseButton_WDGT_CRC_CALC_SIZE                   (2u)
#define CapSenseButton_WDGT_CRC_CALC_PARAM_ID               (0xAE00004Eu)

#define CapSenseButton_WDGT_CRC_ID_VALUE                    (CapSenseButton_dsRam.selfTest.wdgtCrcId)
#define CapSenseButton_WDGT_CRC_ID_OFFSET                   (80u)
#define CapSenseButton_WDGT_CRC_ID_SIZE                     (1u)
#define CapSenseButton_WDGT_CRC_ID_PARAM_ID                 (0x6C000050u)

#define CapSenseButton_INV_BSLN_WDGT_ID_VALUE               (CapSenseButton_dsRam.selfTest.invBslnWdgtId)
#define CapSenseButton_INV_BSLN_WDGT_ID_OFFSET              (81u)
#define CapSenseButton_INV_BSLN_WDGT_ID_SIZE                (1u)
#define CapSenseButton_INV_BSLN_WDGT_ID_PARAM_ID            (0x6A000051u)

#define CapSenseButton_INV_BSLN_SNS_ID_VALUE                (CapSenseButton_dsRam.selfTest.invBslnSnsId)
#define CapSenseButton_INV_BSLN_SNS_ID_OFFSET               (82u)
#define CapSenseButton_INV_BSLN_SNS_ID_SIZE                 (1u)
#define CapSenseButton_INV_BSLN_SNS_ID_PARAM_ID             (0x60000052u)

#define CapSenseButton_SHORTED_WDGT_ID_VALUE                (CapSenseButton_dsRam.selfTest.shortedWdgtId)
#define CapSenseButton_SHORTED_WDGT_ID_OFFSET               (83u)
#define CapSenseButton_SHORTED_WDGT_ID_SIZE                 (1u)
#define CapSenseButton_SHORTED_WDGT_ID_PARAM_ID             (0x66000053u)

#define CapSenseButton_SHORTED_SNS_ID_VALUE                 (CapSenseButton_dsRam.selfTest.shortedSnsId)
#define CapSenseButton_SHORTED_SNS_ID_OFFSET                (84u)
#define CapSenseButton_SHORTED_SNS_ID_SIZE                  (1u)
#define CapSenseButton_SHORTED_SNS_ID_PARAM_ID              (0x6D000054u)

#define CapSenseButton_IDAC_GAIN_INDEX_VALUE                (CapSenseButton_dsRam.selfTest.idacGainIndex)
#define CapSenseButton_IDAC_GAIN_INDEX_OFFSET               (85u)
#define CapSenseButton_IDAC_GAIN_INDEX_SIZE                 (1u)
#define CapSenseButton_IDAC_GAIN_INDEX_PARAM_ID             (0x6B000055u)

#define CapSenseButton_SNS_CLK_VALUE                        (CapSenseButton_dsRam.selfTest.snsClk)
#define CapSenseButton_SNS_CLK_OFFSET                       (86u)
#define CapSenseButton_SNS_CLK_SIZE                         (2u)
#define CapSenseButton_SNS_CLK_PARAM_ID                     (0xA9000056u)

#define CapSenseButton_SNS_CAP_SNS_CLK_HZ_VALUE             (CapSenseButton_dsRam.selfTestConfig.snsCapSnsClkHz)
#define CapSenseButton_SNS_CAP_SNS_CLK_HZ_OFFSET            (88u)
#define CapSenseButton_SNS_CAP_SNS_CLK_HZ_SIZE              (4u)
#define CapSenseButton_SNS_CAP_SNS_CLK_HZ_PARAM_ID          (0xE9000058u)

#define CapSenseButton_SNS_CAP_SNS_CLK_DIVIDER_VALUE        (CapSenseButton_dsRam.selfTestConfig.snsCapSnsClkDivider)
#define CapSenseButton_SNS_CAP_SNS_CLK_DIVIDER_OFFSET       (92u)
#define CapSenseButton_SNS_CAP_SNS_CLK_DIVIDER_SIZE         (2u)
#define CapSenseButton_SNS_CAP_SNS_CLK_DIVIDER_PARAM_ID     (0xA700005Cu)

#define CapSenseButton_SNS_CAP_MOD_CLK_KHZ_VALUE            (CapSenseButton_dsRam.selfTestConfig.snsCapModClkKHz)
#define CapSenseButton_SNS_CAP_MOD_CLK_KHZ_OFFSET           (94u)
#define CapSenseButton_SNS_CAP_MOD_CLK_KHZ_SIZE             (2u)
#define CapSenseButton_SNS_CAP_MOD_CLK_KHZ_PARAM_ID         (0xAB00005Eu)

#define CapSenseButton_SNS_CAP_MOD_CLK_DIVIDER_VALUE        (CapSenseButton_dsRam.selfTestConfig.snsCapModClkDivider)
#define CapSenseButton_SNS_CAP_MOD_CLK_DIVIDER_OFFSET       (96u)
#define CapSenseButton_SNS_CAP_MOD_CLK_DIVIDER_SIZE         (2u)
#define CapSenseButton_SNS_CAP_MOD_CLK_DIVIDER_PARAM_ID     (0xAB000060u)

#define CapSenseButton_SNS_CAP_VREF_VOLTAGE_VALUE           (CapSenseButton_dsRam.selfTestConfig.snsCapVrefVoltage)
#define CapSenseButton_SNS_CAP_VREF_VOLTAGE_OFFSET          (98u)
#define CapSenseButton_SNS_CAP_VREF_VOLTAGE_SIZE            (2u)
#define CapSenseButton_SNS_CAP_VREF_VOLTAGE_PARAM_ID        (0xA7000062u)

#define CapSenseButton_VDDA_VREF_VOLTAGE_VALUE              (CapSenseButton_dsRam.selfTestConfig.vddaVrefVoltage)
#define CapSenseButton_VDDA_VREF_VOLTAGE_OFFSET             (100u)
#define CapSenseButton_VDDA_VREF_VOLTAGE_SIZE               (2u)
#define CapSenseButton_VDDA_VREF_VOLTAGE_PARAM_ID           (0xAA000064u)

#define CapSenseButton_EXT_CAP_VREF_VOLTAGE_VALUE           (CapSenseButton_dsRam.selfTestConfig.extCapVrefVoltage)
#define CapSenseButton_EXT_CAP_VREF_VOLTAGE_OFFSET          (102u)
#define CapSenseButton_EXT_CAP_VREF_VOLTAGE_SIZE            (2u)
#define CapSenseButton_EXT_CAP_VREF_VOLTAGE_PARAM_ID        (0xA6000066u)

#define CapSenseButton_VDDA_MOD_CLK_DIVIDER_VALUE           (CapSenseButton_dsRam.selfTestConfig.vddaModClkDivider)
#define CapSenseButton_VDDA_MOD_CLK_DIVIDER_OFFSET          (104u)
#define CapSenseButton_VDDA_MOD_CLK_DIVIDER_SIZE            (1u)
#define CapSenseButton_VDDA_MOD_CLK_DIVIDER_PARAM_ID        (0x61000068u)

#define CapSenseButton_VDDA_VREF_GAIN_VALUE                 (CapSenseButton_dsRam.selfTestConfig.vddaVrefGain)
#define CapSenseButton_VDDA_VREF_GAIN_OFFSET                (105u)
#define CapSenseButton_VDDA_VREF_GAIN_SIZE                  (1u)
#define CapSenseButton_VDDA_VREF_GAIN_PARAM_ID              (0x67000069u)

#define CapSenseButton_VDDA_RESOLUTION_VALUE                (CapSenseButton_dsRam.selfTestConfig.vddaResolution)
#define CapSenseButton_VDDA_RESOLUTION_OFFSET               (106u)
#define CapSenseButton_VDDA_RESOLUTION_SIZE                 (1u)
#define CapSenseButton_VDDA_RESOLUTION_PARAM_ID             (0x6D00006Au)

#define CapSenseButton_VDDA_IDAC_DEFAULT_VALUE              (CapSenseButton_dsRam.selfTestConfig.vddaIdacDefault)
#define CapSenseButton_VDDA_IDAC_DEFAULT_OFFSET             (107u)
#define CapSenseButton_VDDA_IDAC_DEFAULT_SIZE               (1u)
#define CapSenseButton_VDDA_IDAC_DEFAULT_PARAM_ID           (0x6B00006Bu)

#define CapSenseButton_SNS_CAP_RESOLUTION_VALUE             (CapSenseButton_dsRam.selfTestConfig.snsCapResolution)
#define CapSenseButton_SNS_CAP_RESOLUTION_OFFSET            (108u)
#define CapSenseButton_SNS_CAP_RESOLUTION_SIZE              (1u)
#define CapSenseButton_SNS_CAP_RESOLUTION_PARAM_ID          (0x6000006Cu)

#define CapSenseButton_SNS_CAP_VREF_GAIN_VALUE              (CapSenseButton_dsRam.selfTestConfig.snsCapVrefGain)
#define CapSenseButton_SNS_CAP_VREF_GAIN_OFFSET             (109u)
#define CapSenseButton_SNS_CAP_VREF_GAIN_SIZE               (1u)
#define CapSenseButton_SNS_CAP_VREF_GAIN_PARAM_ID           (0x6600006Du)

#define CapSenseButton_BIST_CSD_SNS_CAP_ISC_VALUE           (CapSenseButton_dsRam.selfTestConfig.bistCsdSnsCapISC)
#define CapSenseButton_BIST_CSD_SNS_CAP_ISC_OFFSET          (110u)
#define CapSenseButton_BIST_CSD_SNS_CAP_ISC_SIZE            (1u)
#define CapSenseButton_BIST_CSD_SNS_CAP_ISC_PARAM_ID        (0x6C00006Eu)

#define CapSenseButton_BIST_CSX_SNS_CAP_ISC_VALUE           (CapSenseButton_dsRam.selfTestConfig.bistCsxSnsCapISC)
#define CapSenseButton_BIST_CSX_SNS_CAP_ISC_OFFSET          (111u)
#define CapSenseButton_BIST_CSX_SNS_CAP_ISC_SIZE            (1u)
#define CapSenseButton_BIST_CSX_SNS_CAP_ISC_PARAM_ID        (0x6A00006Fu)

#define CapSenseButton_BIST_CSD_SH_CAP_ISC_VALUE            (CapSenseButton_dsRam.selfTestConfig.bistCsdShCapISC)
#define CapSenseButton_BIST_CSD_SH_CAP_ISC_OFFSET           (112u)
#define CapSenseButton_BIST_CSD_SH_CAP_ISC_SIZE             (1u)
#define CapSenseButton_BIST_CSD_SH_CAP_ISC_PARAM_ID         (0x66000070u)

#define CapSenseButton_EXT_CAP_VREF_GAIN_VALUE              (CapSenseButton_dsRam.selfTestConfig.extCapVrefGain)
#define CapSenseButton_EXT_CAP_VREF_GAIN_OFFSET             (113u)
#define CapSenseButton_EXT_CAP_VREF_GAIN_SIZE               (1u)
#define CapSenseButton_EXT_CAP_VREF_GAIN_PARAM_ID           (0x60000071u)

#define CapSenseButton_STARTUP_DELAY_VALUE                  (CapSenseButton_dsRam.selfTestConfig.startupDelay)
#define CapSenseButton_STARTUP_DELAY_OFFSET                 (114u)
#define CapSenseButton_STARTUP_DELAY_SIZE                   (1u)
#define CapSenseButton_STARTUP_DELAY_PARAM_ID               (0x6A000072u)

#define CapSenseButton_FINE_INIT_TIME_VALUE                 (CapSenseButton_dsRam.selfTestConfig.fineInitTime)
#define CapSenseButton_FINE_INIT_TIME_OFFSET                (115u)
#define CapSenseButton_FINE_INIT_TIME_SIZE                  (1u)
#define CapSenseButton_FINE_INIT_TIME_PARAM_ID              (0x6C000073u)

#define CapSenseButton_SNS_SHORT_TIME_VALUE                 (CapSenseButton_dsRam.selfTestConfig.snsShortTimeUs)
#define CapSenseButton_SNS_SHORT_TIME_OFFSET                (116u)
#define CapSenseButton_SNS_SHORT_TIME_SIZE                  (1u)
#define CapSenseButton_SNS_SHORT_TIME_PARAM_ID              (0x67000074u)

#define CapSenseButton_BUTTON0_SNS_CP0_VALUE                (CapSenseButton_dsRam.snsCp.button0[0u])
#define CapSenseButton_BUTTON0_SNS_CP0_OFFSET               (120u)
#define CapSenseButton_BUTTON0_SNS_CP0_SIZE                 (4u)
#define CapSenseButton_BUTTON0_SNS_CP0_PARAM_ID             (0xE3000078u)

#define CapSenseButton_SNR_TEST_WIDGET_ID_VALUE             (CapSenseButton_dsRam.snrTestWidgetId)
#define CapSenseButton_SNR_TEST_WIDGET_ID_OFFSET            (124u)
#define CapSenseButton_SNR_TEST_WIDGET_ID_SIZE              (1u)
#define CapSenseButton_SNR_TEST_WIDGET_ID_PARAM_ID          (0x6500007Cu)

#define CapSenseButton_SNR_TEST_SENSOR_ID_VALUE             (CapSenseButton_dsRam.snrTestSensorId)
#define CapSenseButton_SNR_TEST_SENSOR_ID_OFFSET            (125u)
#define CapSenseButton_SNR_TEST_SENSOR_ID_SIZE              (1u)
#define CapSenseButton_SNR_TEST_SENSOR_ID_PARAM_ID          (0x6300007Du)

#define CapSenseButton_SNR_TEST_SCAN_COUNTER_VALUE          (CapSenseButton_dsRam.snrTestScanCounter)
#define CapSenseButton_SNR_TEST_SCAN_COUNTER_OFFSET         (126u)
#define CapSenseButton_SNR_TEST_SCAN_COUNTER_SIZE           (2u)
#define CapSenseButton_SNR_TEST_SCAN_COUNTER_PARAM_ID       (0x8A00007Eu)

#define CapSenseButton_SNR_TEST_RAW_COUNT0_VALUE            (CapSenseButton_dsRam.snrTestRawCount[0u])
#define CapSenseButton_SNR_TEST_RAW_COUNT0_OFFSET           (128u)
#define CapSenseButton_SNR_TEST_RAW_COUNT0_SIZE             (2u)
#define CapSenseButton_SNR_TEST_RAW_COUNT0_PARAM_ID         (0x84000080u)

#define CapSenseButton_SCAN_CSD_ISC_VALUE                   (CapSenseButton_dsRam.scanCsdISC)
#define CapSenseButton_SCAN_CSD_ISC_OFFSET                  (130u)
#define CapSenseButton_SCAN_CSD_ISC_SIZE                    (1u)
#define CapSenseButton_SCAN_CSD_ISC_PARAM_ID                (0x40000082u)

#define CapSenseButton_SCAN_CURRENT_ISC_VALUE               (CapSenseButton_dsRam.scanCurrentISC)
#define CapSenseButton_SCAN_CURRENT_ISC_OFFSET              (131u)
#define CapSenseButton_SCAN_CURRENT_ISC_SIZE                (1u)
#define CapSenseButton_SCAN_CURRENT_ISC_PARAM_ID            (0x46000083u)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define CapSenseButton_BUTTON0_PTR2SNS_FLASH_VALUE          (CapSenseButton_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define CapSenseButton_BUTTON0_PTR2SNS_FLASH_OFFSET         (0u)
#define CapSenseButton_BUTTON0_PTR2SNS_FLASH_SIZE           (4u)
#define CapSenseButton_BUTTON0_PTR2SNS_FLASH_PARAM_ID       (0xD1000000u)

#define CapSenseButton_BUTTON0_PTR2WD_RAM_VALUE             (CapSenseButton_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define CapSenseButton_BUTTON0_PTR2WD_RAM_OFFSET            (4u)
#define CapSenseButton_BUTTON0_PTR2WD_RAM_SIZE              (4u)
#define CapSenseButton_BUTTON0_PTR2WD_RAM_PARAM_ID          (0xD0000004u)

#define CapSenseButton_BUTTON0_PTR2SNS_RAM_VALUE            (CapSenseButton_dsFlash.wdgtArray[0].ptr2SnsRam)
#define CapSenseButton_BUTTON0_PTR2SNS_RAM_OFFSET           (8u)
#define CapSenseButton_BUTTON0_PTR2SNS_RAM_SIZE             (4u)
#define CapSenseButton_BUTTON0_PTR2SNS_RAM_PARAM_ID         (0xD3000008u)

#define CapSenseButton_BUTTON0_PTR2FLTR_HISTORY_VALUE       (CapSenseButton_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define CapSenseButton_BUTTON0_PTR2FLTR_HISTORY_OFFSET      (12u)
#define CapSenseButton_BUTTON0_PTR2FLTR_HISTORY_SIZE        (4u)
#define CapSenseButton_BUTTON0_PTR2FLTR_HISTORY_PARAM_ID    (0xD200000Cu)

#define CapSenseButton_BUTTON0_PTR2DEBOUNCE_VALUE           (CapSenseButton_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define CapSenseButton_BUTTON0_PTR2DEBOUNCE_OFFSET          (16u)
#define CapSenseButton_BUTTON0_PTR2DEBOUNCE_SIZE            (4u)
#define CapSenseButton_BUTTON0_PTR2DEBOUNCE_PARAM_ID        (0xD4000010u)

#define CapSenseButton_BUTTON0_STATIC_CONFIG_VALUE          (CapSenseButton_dsFlash.wdgtArray[0].staticConfig)
#define CapSenseButton_BUTTON0_STATIC_CONFIG_OFFSET         (20u)
#define CapSenseButton_BUTTON0_STATIC_CONFIG_SIZE           (4u)
#define CapSenseButton_BUTTON0_STATIC_CONFIG_PARAM_ID       (0xD5000014u)

#define CapSenseButton_BUTTON0_TOTAL_NUM_SNS_VALUE          (CapSenseButton_dsFlash.wdgtArray[0].totalNumSns)
#define CapSenseButton_BUTTON0_TOTAL_NUM_SNS_OFFSET         (24u)
#define CapSenseButton_BUTTON0_TOTAL_NUM_SNS_SIZE           (2u)
#define CapSenseButton_BUTTON0_TOTAL_NUM_SNS_PARAM_ID       (0x99000018u)

#define CapSenseButton_BUTTON0_TYPE_VALUE                   (CapSenseButton_dsFlash.wdgtArray[0].wdgtType)
#define CapSenseButton_BUTTON0_TYPE_OFFSET                  (26u)
#define CapSenseButton_BUTTON0_TYPE_SIZE                    (1u)
#define CapSenseButton_BUTTON0_TYPE_PARAM_ID                (0x5D00001Au)

#define CapSenseButton_BUTTON0_NUM_COLS_VALUE               (CapSenseButton_dsFlash.wdgtArray[0].numCols)
#define CapSenseButton_BUTTON0_NUM_COLS_OFFSET              (27u)
#define CapSenseButton_BUTTON0_NUM_COLS_SIZE                (1u)
#define CapSenseButton_BUTTON0_NUM_COLS_PARAM_ID            (0x5B00001Bu)

#define CapSenseButton_BUTTON0_PTR2SNS_CP_VALUE             (CapSenseButton_dsFlash.wdgtArray[0].ptr2SnsCpArr)
#define CapSenseButton_BUTTON0_PTR2SNS_CP_OFFSET            (28u)
#define CapSenseButton_BUTTON0_PTR2SNS_CP_SIZE              (4u)
#define CapSenseButton_BUTTON0_PTR2SNS_CP_PARAM_ID          (0xD700001Cu)


#endif /* End CY_SENSE_CapSenseButton_REGISTER_MAP_H */


/* [] END OF FILE */
