/***************************************************************************//**
* \file CapSenseButton_SensingCSD_LL.h
* \version 7.0
*
* \brief
*   This file provides the headers of APIs specific to CSD sensing implementation.
*
* \see CapSenseButton v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSenseButton_SENSINGCSD_LL_H)
#define CY_SENSE_CapSenseButton_SENSINGCSD_LL_H

#include <CyLib.h>
#include <cyfitter.h>
#include <cytypes.h>
#include <cypins.h>
#include "CapSenseButton_Structure.h"
#include "CapSenseButton_Configuration.h"
#include "CapSenseButton_Sensing.h"

/****************************************************************************
* Register and mode mask definition
****************************************************************************/

#if (CapSenseButton_ENABLE == CapSenseButton_CSDV2)
    #define CapSenseButton_CSD_CSDCMP_INIT                                (CapSenseButton_CSDCMP_CSDCMP_DISABLED)

    /* SW_HS_P_SEL switches state for Coarse initialization of CMOD (sense path) */
    #if (CapSenseButton_ENABLE == CapSenseButton_CSD_EN)
        #if (CapSenseButton_CSD__CMOD_PAD == CapSenseButton_CMOD_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_COARSE_CMOD               (CapSenseButton_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #elif (CapSenseButton_CSD__CSHIELD_PAD == CapSenseButton_CMOD_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_COARSE_CMOD               (CapSenseButton_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #else
            #define CapSenseButton_CSD_HS_P_SEL_COARSE_CMOD               (CapSenseButton_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #endif /* (CapSenseButton_CSD__CMOD_PAD == CapSenseButton_CMOD_CONNECTION) */
    #else
        #define CapSenseButton_CSD_HS_P_SEL_COARSE_CMOD                   (0x00000000uL)
    #endif /* (CapSenseButton_ENABLE == CapSenseButton_CSD_EN) */

    #if ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN) && \
        (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_COARSE_TANK               (CapSenseButton_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CapSenseButton_CSD__CSHIELD_PAD == CapSenseButton_CTANK_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_COARSE_TANK               (CapSenseButton_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CapSenseButton_CSD__CMOD_PAD == CapSenseButton_CTANK_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_COARSE_TANK               (CapSenseButton_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CapSenseButton_CSD_HS_P_SEL_COARSE_TANK               (CapSenseButton_SW_HS_P_SEL_SW_HMMA_STATIC_CLOSE)
        #endif /* (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION) */
    #else
        #define CapSenseButton_CSD_HS_P_SEL_COARSE_TANK                   (0x00000000uL)
    #endif /* ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN) && \
               (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN)) */

    #define CapSenseButton_CSD_SW_HS_P_SEL_COARSE                         (CapSenseButton_HS_P_SEL_COARSE_CMOD | CapSenseButton_CSD_HS_P_SEL_COARSE_TANK)

    /* C_mod config */
    #if ((CapSenseButton_CSD__CMOD_PAD == CapSenseButton_CMOD_CONNECTION) || (CapSenseButton_CSD__CMOD_PAD == CapSenseButton_CTANK_CONNECTION))
        #define CapSenseButton_CSD_SW_FW_MOD_SEL_INIT             (CapSenseButton_SW_FW_MOD_SEL_SW_F1PM_STATIC_CLOSE |\
                                                                     CapSenseButton_SW_FW_MOD_SEL_SW_F1MA_STATIC_CLOSE |\
                                                                     CapSenseButton_SW_FW_MOD_SEL_SW_F1CA_STATIC_CLOSE)
        #define CapSenseButton_SW_DSI_SEL_CMODPAD                 (CapSenseButton_SW_DSI_CMOD)
    #else
        #define CapSenseButton_CSD_SW_FW_MOD_SEL_INIT             (0x00000000uL)
        #define CapSenseButton_SW_DSI_SEL_CMODPAD                 (0x00000000uL)
    #endif /* (CapSenseButton_CSD__CMOD_PAD == CapSenseButton_CMOD_CONNECTION) */

    /* C_tank config */
    #if ((CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CMOD_CONNECTION) || (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION))
        #define CapSenseButton_CSD_SW_FW_TANK_SEL_INIT            (CapSenseButton_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                     CapSenseButton_SW_FW_TANK_SEL_SW_F2MA_STATIC_CLOSE |\
                                                                     CapSenseButton_SW_FW_TANK_SEL_SW_F2CA_STATIC_CLOSE)
        #define CapSenseButton_SW_DSI_SEL_TANKPAD                 (CapSenseButton_SW_DSI_CTANK)
    #else
        #define CapSenseButton_CSD_SW_FW_TANK_SEL_INIT            (0x00000000uL)
        #define CapSenseButton_SW_DSI_SEL_TANKPAD                 (0x00000000uL)
    #endif /* (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION) */

    #define CapSenseButton_CSD_SW_SHIELD_SEL_INIT                 (CapSenseButton_SW_SHIELD_SEL_SW_HCAV_HSCMP)

    /* Defining default HW configuration according to settings in customizer. */
    #define CapSenseButton_DEFAULT_CSD_CONFIG                 (CapSenseButton_CONFIG_FILTER_DELAY_12MHZ |\
                                                                 CapSenseButton_CONFIG_SAMPLE_SYNC_MASK)
    #if (CapSenseButton_ENABLE == CapSenseButton_CSD_AUTO_ZERO_EN)
        /* Enable CSDCMP */
        #define CapSenseButton_CSD_CSDCMP_SCAN                (CapSenseButton_CSDCMP_CSDCMP_EN_MASK |\
                                                                 CapSenseButton_CSDCMP_AZ_EN_MASK)
    #else
        /* Enable CSDCMP */
        #define CapSenseButton_CSD_CSDCMP_SCAN                (CapSenseButton_CSDCMP_CSDCMP_EN_MASK)
    #endif /* (CapSenseButton_ENABLE == CapSenseButton_CSD_AUTO_ZERO_EN) */

    #if ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN) && \
        (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseButton_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CapSenseButton_CSD__CSHIELD_PAD == CapSenseButton_CTANK_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseButton_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CapSenseButton_CSD__CMOD_PAD == CapSenseButton_CTANK_CONNECTION)
            #define CapSenseButton_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseButton_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CapSenseButton_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseButton_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
        #endif /* (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION) */
        #define CapSenseButton_CSD_SW_HS_P_SEL_SCAN                       (CapSenseButton_HS_P_SEL_SCAN_TANK)
    #elif(CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN)
        #define CapSenseButton_CSD_SW_HS_P_SEL_SCAN                       (CapSenseButton_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
    #else
        #define CapSenseButton_CSD_SW_HS_P_SEL_SCAN                       (CapSenseButton_STATIC_OPEN)
    #endif /* ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN) && \
               (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN)) */

    /* SW_FW_MOD_SEL switches state for Coarse initialization of CMOD (sense path) */
    #define CapSenseButton_CSD_SW_FW_MOD_SEL_SCAN                     (0x00000000uL)

    #if((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN) && \
        (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN) && \
        (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION))
        #define CapSenseButton_CSD_SW_FW_TANK_SEL_SCAN                (CapSenseButton_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE | \
                                                                         CapSenseButton_SW_FW_TANK_SEL_SW_F2CB_STATIC_CLOSE)
    #else
        #define CapSenseButton_CSD_SW_FW_TANK_SEL_SCAN                (0x00000000uL)
    #endif /* ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN) && \
               (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN) && \
               (CapSenseButton_CSD__CSH_TANK_PAD == CapSenseButton_CTANK_CONNECTION)) */

    /* Shield switch default config */
    #if ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN) && \
         (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN))
        #if (CapSenseButton_IDAC_SINKING == CapSenseButton_CSD_IDAC_CONFIG)
            #define CapSenseButton_CSD_SW_SHIELD_SEL_SCAN             (CapSenseButton_SW_SHIELD_SEL_SW_HCBG_HSCMP)
        #else
            #define CapSenseButton_CSD_SW_SHIELD_SEL_SCAN             (CapSenseButton_SW_SHIELD_SEL_SW_HCBV_HSCMP)
        #endif /* (CapSenseButton_IDAC_SINKING == CapSenseButton_CSD_IDAC_CONFIG) */
    #elif(CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN)
        #if (CapSenseButton_IDAC_SINKING == CapSenseButton_CSD_IDAC_CONFIG)
            #define CapSenseButton_CSD_SW_SHIELD_SEL_SCAN             (CapSenseButton_SW_SHIELD_SEL_SW_HCBV_PHI1 | \
                                                                         CapSenseButton_SW_SHIELD_SEL_SW_HCBG_PHI2_HSCMP)
        #else
            #define CapSenseButton_CSD_SW_SHIELD_SEL_SCAN             (CapSenseButton_SW_SHIELD_SEL_SW_HCBG_PHI1 | \
                                                                         CapSenseButton_SW_SHIELD_SEL_SW_HCBV_PHI2_HSCMP)
        #endif /* (CapSenseButton_IDAC_SINKING == CapSenseButton_CSD_IDAC_CONFIG) */
    #else
        #define CapSenseButton_CSD_SW_SHIELD_SEL_SCAN                 (0x00000000uL)
    #endif /* ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN) && \
               (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN)) */

    #define CapSenseButton_CSD_SW_RES_INIT                            (CapSenseButton_CSD_INIT_SWITCH_RES << CYFLD_CSD_RES_HCAV__OFFSET)
    #define CapSenseButton_CSD_SW_RES_SCAN                            ((CapSenseButton_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBV__OFFSET) |\
                                                                         (CapSenseButton_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBG__OFFSET))

    #define CapSenseButton_CSD_SHIELD_GPIO_DM                         (CapSenseButton_GPIO_STRGDRV)
    #define CapSenseButton_CSD_SENSOR_HSIOM_SEL                       (CapSenseButton_HSIOM_SEL_CSD_SENSE)
    #define CapSenseButton_CSD_SHIELD_HSIOM_SEL                       (CapSenseButton_HSIOM_SEL_CSD_SHIELD)
    #define CapSenseButton_CSD_CMOD_HSIOM_SEL                         (CapSenseButton_HSIOM_SEL_AMUXA)

    #define CapSenseButton_DEFAULT_IDAC_MOD_BALL_MODE                 ((uint32)CapSenseButton_IDAC_MOD_BALL_MODE_FULL <<\
                                                                         CYFLD_CSD_BAL_MODE__OFFSET)
    #define CapSenseButton_DEFAULT_IDAC_COMP_BALL_MODE                ((uint32)CapSenseButton_IDAC_COMP_BALL_MODE_FULL <<\
                                                                         CYFLD_CSD_BAL_MODE__OFFSET)

    #define CapSenseButton_DEFAULT_SENSE_DUTY_SEL                     (CapSenseButton_SENSE_DUTY_OVERLAP_PHI1_MASK |\
                                                                         CapSenseButton_SENSE_DUTY_OVERLAP_PHI2_MASK)

    #define CapSenseButton_CSD_CAL_MIDDLE_VALUE                       (0x40u)
    #define CapSenseButton_CSD_CAL_IDAC_MAX_VALUE                     (127u)

    #define CapSenseButton_DELAY_EXTRACYCLES_NUM                      (9u)

    /* Clock Source Mode */
    #if (CapSenseButton_CLK_SOURCE_DIRECT == CapSenseButton_CSD_SNS_CLK_SOURCE)
        #define CapSenseButton_DEFAULT_MODULATION_MODE                (CapSenseButton_CLK_SOURCE_DIRECT)
    #elif (CapSenseButton_CLK_SOURCE_PRSAUTO == CapSenseButton_CSD_SNS_CLK_SOURCE)
        #define CapSenseButton_DEFAULT_MODULATION_MODE                (CapSenseButton_CLK_SOURCE_SSC2)
    #elif ((CapSenseButton_CLK_SOURCE_PRS8) == CapSenseButton_CSD_SNS_CLK_SOURCE)
        #define CapSenseButton_DEFAULT_MODULATION_MODE                (CapSenseButton_CSD_SNS_CLK_SOURCE)
    #elif ((CapSenseButton_CLK_SOURCE_PRS12) == CapSenseButton_CSD_SNS_CLK_SOURCE)
        #define CapSenseButton_DEFAULT_MODULATION_MODE                (CapSenseButton_CSD_SNS_CLK_SOURCE)
    #else
        #define CapSenseButton_DEFAULT_MODULATION_MODE                (CapSenseButton_CSD_SNS_CLK_SOURCE)
    #endif /* (CapSenseButton_CLK_SOURCE_DIRECT != CapSenseButton_CSD_SNS_CLK_SOURCE) */

    /* IDACs Ranges */
    #if (CapSenseButton_IDAC_GAIN_LOW == CapSenseButton_CSD_IDAC_GAIN)
        #define CapSenseButton_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSenseButton_IDAC_MOD_RANGE_IDAC_LO << CYFLD_CSD_RANGE__OFFSET)
        #define CapSenseButton_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSenseButton_IDAC_COMP_RANGE_IDAC_LO << CYFLD_CSD_RANGE__OFFSET)
    #elif (CapSenseButton_IDAC_GAIN_MEDIUM == CapSenseButton_CSD_IDAC_GAIN)
        #define CapSenseButton_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSenseButton_IDAC_MOD_RANGE_IDAC_MED << CYFLD_CSD_RANGE__OFFSET)
        #define CapSenseButton_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSenseButton_IDAC_COMP_RANGE_IDAC_MED << CYFLD_CSD_RANGE__OFFSET)
    #else
        #define CapSenseButton_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSenseButton_IDAC_MOD_RANGE_IDAC_HI << CYFLD_CSD_RANGE__OFFSET)
        #define CapSenseButton_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSenseButton_IDAC_COMP_RANGE_IDAC_HI << CYFLD_CSD_RANGE__OFFSET)
    #endif

    /* IDACs Polarities */
    #if (CapSenseButton_IDAC_SINKING == CapSenseButton_CSD_IDAC_CONFIG)
        #define CapSenseButton_DEFAULT_IDAC_MOD_POLARITY              ((uint32)CapSenseButton_IDAC_MOD_POLARITY_VDDA_SNK << CYFLD_CSD_POLARITY__OFFSET)
        #define CapSenseButton_DEFAULT_IDAC_COMP_POLARITY             ((uint32)CapSenseButton_IDAC_COMP_POLARITY_VDDA_SNK << CYFLD_CSD_POLARITY__OFFSET)
    #else
        #define CapSenseButton_DEFAULT_IDAC_MOD_POLARITY              ((uint32)CapSenseButton_IDAC_MOD_POLARITY_VSSA_SRC << CYFLD_CSD_POLARITY__OFFSET)
        #define CapSenseButton_DEFAULT_IDAC_COMP_POLARITY             ((uint32)CapSenseButton_IDAC_COMP_POLARITY_VSSA_SRC << CYFLD_CSD_POLARITY__OFFSET)
    #endif /* (CapSenseButton_IDAC_SINKING == CapSenseButton_CSD_IDAC_CONFIG) */

    #define CapSenseButton_SW_REFGEN_VREF_SRC                         (CapSenseButton_SW_REFGEN_SEL_SW_SGR_MASK)

    /* IDAC legs configuration */
    #if (CapSenseButton_ENABLE == CapSenseButton_CSD_IDAC_COMP_EN)
            #define CapSenseButton_DEFAULT_SW_REFGEN_SEL              (CapSenseButton_SW_REFGEN_VREF_SRC | CapSenseButton_SW_REFGEN_SEL_SW_IAIB_MASK)
    #else
            #define CapSenseButton_DEFAULT_SW_REFGEN_SEL              (CapSenseButton_SW_REFGEN_VREF_SRC)
    #endif /* (CapSenseButton_ENABLE == CapSenseButton_CSD_IDAC_COMP_EN) */

    /* IDACs register configuration is based on the Component configuration */
    #define CapSenseButton_IDAC_MOD_DEFAULT_CFG                       (CapSenseButton_DEFAULT_IDAC_MOD_RANGE | \
                                                                         CapSenseButton_DEFAULT_IDAC_MOD_POLARITY | \
                                                                         CapSenseButton_DEFAULT_IDAC_MOD_BALL_MODE | \
                                                                        ((uint32)(CapSenseButton_IDAC_MOD_LEG1_MODE_CSD << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)(CapSenseButton_IDAC_MOD_LEG2_MODE_CSD << CYFLD_CSD_LEG2_MODE__OFFSET)) | \
                                                                         CapSenseButton_IDAC_MOD_LEG1_EN_MASK)

    #define CapSenseButton_IDAC_COMP_DEFAULT_CFG                      (CapSenseButton_DEFAULT_IDAC_COMP_RANGE | \
                                                                         CapSenseButton_DEFAULT_IDAC_COMP_POLARITY | \
                                                                         CapSenseButton_DEFAULT_IDAC_COMP_BALL_MODE | \
                                                                        ((uint32)(CapSenseButton_IDAC_COMP_LEG1_MODE_CSD_STATIC << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)(CapSenseButton_IDAC_COMP_LEG2_MODE_CSD_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET)) | \
                                                                         CapSenseButton_IDAC_COMP_LEG1_EN_MASK)

    #define CapSenseButton_IDAC_MOD_CALIBRATION_CFG                   ((uint32)(CapSenseButton_DEFAULT_IDAC_MOD_RANGE | \
                                                                         CapSenseButton_DEFAULT_IDAC_MOD_POLARITY | \
                                                                         CapSenseButton_DEFAULT_IDAC_MOD_BALL_MODE | \
                                                                        ((uint32)(CapSenseButton_IDAC_MOD_LEG1_MODE_CSD << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                         CapSenseButton_IDAC_MOD_LEG1_EN_MASK | \
                                                                        ((uint32)((uint32)CapSenseButton_IDAC_MOD_LEG2_MODE_GP_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET))))

    #define CapSenseButton_IDAC_COMP_CALIBRATION_CFG                  ((uint32)(CapSenseButton_DEFAULT_IDAC_COMP_RANGE | \
                                                                         CapSenseButton_DEFAULT_IDAC_COMP_POLARITY | \
                                                                         CapSenseButton_DEFAULT_IDAC_COMP_BALL_MODE | \
                                                                        ((uint32)((uint32)CapSenseButton_IDAC_COMP_LEG1_MODE_GP_STATIC << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)((uint32)CapSenseButton_IDAC_COMP_LEG2_MODE_GP_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET))))
#else
    #if (CapSenseButton_ENABLE == CapSenseButton_CSD_IDAC_COMP_EN)
        #define CapSenseButton_CSD_CAL_IDAC_MAX_VALUE                 (127u)
        #define CapSenseButton_CSD_CAL_MIDDLE_VALUE                   (0x40u)
    #else
        #define CapSenseButton_CSD_CAL_IDAC_MAX_VALUE                 (255u)
        #define CapSenseButton_CSD_CAL_MIDDLE_VALUE                   (0x80u)
    #endif

    #define CapSenseButton_IDAC_MOD_CFG_MASK                  (CapSenseButton_IDAC_POLARITY1_MIR_MASK |\
                                                                CapSenseButton_IDAC_MOD_RANGE_MASK |\
                                                                CapSenseButton_IDAC_MOD_MODE_MASK |\
                                                                CapSenseButton_IDAC_MOD_MASK)

    #define CapSenseButton_IDAC_COMP_CFG_MASK                 (CapSenseButton_IDAC_POLARITY2_MIR_MASK |\
                                                                CapSenseButton_IDAC_COMP_RANGE_MASK |\
                                                                CapSenseButton_IDAC_COMP_MODE_MASK |\
                                                                CapSenseButton_IDAC_COMP_MASK)

        #define CapSenseButton_PRS_8_CONFIG                       CapSenseButton_CONFIG_PRS_SELECT_MASK
    #define CapSenseButton_PRS_12_CONFIG                      (CapSenseButton_CONFIG_PRS_12_8_MASK |\
                                                                CapSenseButton_CONFIG_PRS_SELECT_MASK)

    /* Third-generation HW block Initial PRS mode */
    #if (CapSenseButton_CLK_SOURCE_PRS8 == CapSenseButton_CSD_SNS_CLK_SOURCE)
        #define CapSenseButton_DEFAULT_MODULATION_MODE        CapSenseButton_CONFIG_PRS_SELECT_MASK

    #elif (CapSenseButton_CLK_SOURCE_PRS12 == CapSenseButton_CSD_SNS_CLK_SOURCE)
        #define CapSenseButton_DEFAULT_MODULATION_MODE        (CapSenseButton_CONFIG_PRS_12_8_MASK |\
                                                                CapSenseButton_CONFIG_PRS_SELECT_MASK)
    #else
        #define CapSenseButton_DEFAULT_MODULATION_MODE        (0u)
    #endif /* (CapSenseButton_CSD_SNS_CLK_SOURCE == CapSenseButton_PRS_8BITS) */

    /* Defining default CSD configuration according to settings in customizer. */
    #define CapSenseButton_DEFAULT_CSD_CONFIG                 (CapSenseButton_CONFIG_SENSE_COMP_BW_MASK |\
                                                                CapSenseButton_DEFAULT_IDAC_POLARITY |\
                                                                CapSenseButton_CONFIG_SENSE_INSEL_MASK |\
                                                                CapSenseButton_CONFIG_REFBUF_DRV_MASK)

    /* Third-generation HW block Defining mask intended for clearing bits related to pre-charging options. */
    #define CapSenseButton_PRECHARGE_CONFIG_MASK              (CapSenseButton_CONFIG_REFBUF_EN_MASK |\
                                                                CapSenseButton_CONFIG_COMP_MODE_MASK |\
                                                                CapSenseButton_CONFIG_COMP_PIN_MASK  |\
                                                                CapSenseButton_CONFIG_REFBUF_OUTSEL_MASK)

    #define CapSenseButton_CMOD_PRECHARGE_CONFIG              (CapSenseButton_DEFAULT_CSD_CONFIG |\
                                                                CapSenseButton_CONFIG_REFBUF_EN_MASK |\
                                                                CapSenseButton_CONFIG_COMP_PIN_MASK)

    #define CapSenseButton_CMOD_PRECHARGE_CONFIG_CSD_EN       (CapSenseButton_DEFAULT_CSD_CONFIG |\
                                                                CapSenseButton_CSD_ENABLE_MASK |\
                                                                CapSenseButton_CONFIG_REFBUF_EN_MASK |\
                                                                CapSenseButton_CONFIG_COMP_PIN_MASK)


    #if (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN)
        #if((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_TANK_EN) &&\
            (CapSenseButton_CSH_PRECHARGE_IO_BUF == CapSenseButton_CSD_CSH_PRECHARGE_SRC))
            #define  CapSenseButton_CTANK_PRECHARGE_CONFIG    (CapSenseButton_DEFAULT_CSD_CONFIG |\
                                                                 CapSenseButton_CONFIG_REFBUF_OUTSEL_MASK |\
                                                                 CapSenseButton_CONFIG_REFBUF_EN_MASK |\
                                                                 CapSenseButton_CONFIG_COMP_MODE_MASK |\
                                                                 CapSenseButton_CONFIG_PRS_CLEAR_MASK |\
                                                                 CapSenseButton_CONFIG_COMP_PIN_MASK)
        #else
            #define  CapSenseButton_CTANK_PRECHARGE_CONFIG    (CapSenseButton_DEFAULT_CSD_CONFIG |\
                                                                 CapSenseButton_CONFIG_REFBUF_EN_MASK |\
                                                                 CapSenseButton_CONFIG_PRS_CLEAR_MASK |\
                                                                 CapSenseButton_CONFIG_REFBUF_OUTSEL_MASK)
        #endif
    #else
        #define  CapSenseButton_CTANK_PRECHARGE_CONFIG    (CapSenseButton_DEFAULT_CSD_CONFIG |\
                                                             CapSenseButton_CONFIG_REFBUF_OUTSEL_MASK |\
                                                             CapSenseButton_CONFIG_PRS_CLEAR_MASK)
    #endif /* (CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN) */


    #define  CapSenseButton_CTANK_PRECHARGE_CONFIG_CSD_EN     (CapSenseButton_CTANK_PRECHARGE_CONFIG |\
                                                                 CapSenseButton_CONFIG_ENABLE_MASK |\
                                                                 CapSenseButton_CONFIG_SENSE_COMP_EN_MASK)

#endif /* (CapSenseButton_ENABLE == CapSenseButton_CSDV2) */

#define CapSenseButton_CSD_AVG_CYCLES_PER_LOOP                   (5u)
#define CapSenseButton_CSD_MEASURE_MAX_TIME_US                   (200000u)
#define CapSenseButton_CSD_PRECHARGE_MAX_TIME_US                 (50u)
#define CapSenseButton_CSD_ONE_CLOCK_MAX_TIME_US                 (50u)
#define CapSenseButton_WIDGET_MAX_SCAN_TIME_US                   (5u * 1000000u)

#define CapSenseButton_CSD_CALIBR_WATCHDOG_CYCLES_NUM            (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseButton_CSD_MEASURE_MAX_TIME_US)) /\
                                                                    (CapSenseButton_CSD_AVG_CYCLES_PER_LOOP))
#define CapSenseButton_CSD_PRECHARGE_WATCHDOG_CYCLES_NUM         (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseButton_CSD_PRECHARGE_MAX_TIME_US)) /\
                                                                    (CapSenseButton_CSD_AVG_CYCLES_PER_LOOP))
#define CapSenseButton_ONE_CLOCK_WATCHDOG_CYCLES_NUM             (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseButton_CSD_ONE_CLOCK_MAX_TIME_US)) /\
                                                                    (CapSenseButton_CSD_AVG_CYCLES_PER_LOOP))
#define CapSenseButton_WIDGET_MAX_SCAN_TIME                      (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseButton_WIDGET_MAX_SCAN_TIME_US)) /\
                                                                    (CapSenseButton_CSD_AVG_CYCLES_PER_LOOP))

/***************************************
* Global software variables
***************************************/

extern uint32 CapSenseButton_configCsd;

#if (CapSenseButton_ENABLE == CapSenseButton_CSD_NOISE_METRIC_EN)
    extern uint8 CapSenseButton_badConversionsNum;
#endif /* (CapSenseButton_ENABLE == CapSenseButton_CSD_NOISE_METRIC_EN) */


/***************************************
* Function Prototypes
**************************************/

/**
* \cond SECTION_C_LOW_LEVEL
* \addtogroup group_c_low_level
* \{
*/

void CapSenseButton_CSDSetupWidget(uint32 widgetId);
void CapSenseButton_CSDSetupWidgetExt(uint32 widgetId, uint32 sensorId);
void CapSenseButton_CSDScan(void);
void CapSenseButton_CSDScanExt(void);
#if ((CapSenseButton_CSD_SS_DIS != CapSenseButton_CSD_AUTOTUNE) || \
     (CapSenseButton_ENABLE == CapSenseButton_CSD_IDAC_AUTOCAL_EN))
    cystatus CapSenseButton_CSDCalibrateWidget(uint32 widgetId, uint32 target);
#endif /* ((CapSenseButton_CSD_SS_DIS != CapSenseButton_CSD_AUTOTUNE) || \
           (CapSenseButton_ENABLE == CapSenseButton_CSD_IDAC_AUTOCAL_EN))  */
void CapSenseButton_CSDConnectSns(CapSenseButton_FLASH_IO_STRUCT const *snsAddrPtr);
void CapSenseButton_CSDDisconnectSns(CapSenseButton_FLASH_IO_STRUCT const *snsAddrPtr);

/** \}
* \endcond */

/*****************************************************
* Function Prototypes - internal Low Level functions
*****************************************************/

/**
* \cond SECTION_C_INTERNAL
* \addtogroup group_c_internal
* \{
*/

void CapSenseButton_SsCSDInitialize(void);
void CapSenseButton_SsCSDStartSample(void);
void CapSenseButton_SsCSDSetUpIdacs(CapSenseButton_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CapSenseButton_SsCSDConfigClock(void);
void CapSenseButton_SsCSDElectrodeCheck(void);
#if ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN) && \
     (0u != CapSenseButton_CSD_TOTAL_SHIELD_COUNT))
    void CapSenseButton_SsCSDEnableShieldElectrodes(void);
    void CapSenseButton_SsCSDDisableShieldElectrodes(void);
    void CapSenseButton_SsCSDSetShieldElectrodesState(uint32 state);
#endif /* ((CapSenseButton_ENABLE == CapSenseButton_CSD_SHIELD_EN) && \
           (0u != CapSenseButton_CSD_TOTAL_SHIELD_COUNT)) */
#if (CapSenseButton_ENABLE == CapSenseButton_CSDV2)
    uint32 CapSenseButton_SsCSDGetNumberOfConversions(uint32 snsClkDivider, uint32 resolution, uint32 snsClkSrc);
#endif /* (CapSenseButton_ENABLE == CapSenseButton_CSDV2) */
void CapSenseButton_SsCSDCalculateScanDuration(CapSenseButton_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CapSenseButton_SsCSDConnectSensorExt(uint32 widgetId, uint32 sensorId);
void CapSenseButton_SsCSDDisconnectSnsExt(uint32 widgetId, uint32 sensorId);

#if ((CapSenseButton_CSD_SS_DIS != CapSenseButton_CSD_AUTOTUNE) || \
     (CapSenseButton_ENABLE == CapSenseButton_SELF_TEST_EN) || \
     (CapSenseButton_ENABLE == CapSenseButton_CSD_IDAC_AUTOCAL_EN))
#endif /* ((CapSenseButton_CSD_SS_DIS != CapSenseButton_CSD_AUTOTUNE) || \
           (CapSenseButton_ENABLE == CapSenseButton_SELF_TEST_EN) || \
           (CapSenseButton_ENABLE == CapSenseButton_CSD_IDAC_AUTOCAL_EN)) */

/** \}
* \endcond */

/***************************************
* Global software variables
***************************************/
extern uint32 CapSenseButton_configCsd;

/* Interrupt handler */
extern CY_ISR_PROTO(CapSenseButton_CSDPostSingleScan);
extern CY_ISR_PROTO(CapSenseButton_CSDPostMultiScan);
#if (CapSenseButton_ENABLE == CapSenseButton_CSD_GANGED_SNS_EN)
extern CY_ISR_PROTO(CapSenseButton_CSDPostMultiScanGanged);
#endif /* (CapSenseButton_ENABLE == CapSenseButton_CSD_GANGED_SNS_EN) */
#if (CapSenseButton_ENABLE == CapSenseButton_CSD_NOISE_METRIC_EN)
    extern uint8 CapSenseButton_badConversionsNum;
#endif /* (CapSenseButton_ENABLE == CapSenseButton_CSD_NOISE_METRIC_EN) */

#endif /* End CY_SENSE_CapSenseButton_SENSINGCSD_LL_H */


/* [] END OF FILE */
