/*******************************************************************************
* \file CapSenseProx_Configuration.h
* \version 7.0
*
* \brief
*   This file provides the customizer parameters definitions.
*
* \see CapSenseProx v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSenseProx_CONFIGURATION_H)
#define CY_SENSE_CapSenseProx_CONFIGURATION_H

#include <cytypes.h>
#include <cyfitter.h>

/*******************************************************************************
* Customizer-generated defines
*******************************************************************************/
#define CapSenseProx_ENABLE                             (1u)
#define CapSenseProx_DISABLE                            (0u)

#define CapSenseProx_THIRD_GENERATION_BLOCK             (1u)
#define CapSenseProx_FOURTH_GENERATION_BLOCK            (2u)

#define CapSenseProx_GENERATION_BLOCK_VERSION           (2u)

/*******************************************************************************
* HW IP block global defines
*******************************************************************************/

#if (CapSenseProx_GENERATION_BLOCK_VERSION == CapSenseProx_THIRD_GENERATION_BLOCK)
    #define CapSenseProx_CSDV1                          (CapSenseProx_ENABLE)

    #ifdef CYIPBLOCK_m0s8csd_VERSION
        #if (0u == CYIPBLOCK_m0s8csd_VERSION)
            #define CapSenseProx_CSDV1_VER1             (CapSenseProx_ENABLE)
            #define CapSenseProx_CSDV1_VER2             (CapSenseProx_DISABLE)
        #else
            #define CapSenseProx_CSDV1_VER1             (CapSenseProx_DISABLE)
            #define CapSenseProx_CSDV1_VER2             (CapSenseProx_ENABLE)
        #endif
    #else
        #error "HW IP block version is not specified"
    #endif
#else
    #define CapSenseProx_CSDV1                          (CapSenseProx_DISABLE)
    #define CapSenseProx_CSDV1_VER1                     (CapSenseProx_DISABLE)
    #define CapSenseProx_CSDV1_VER2                     (CapSenseProx_DISABLE)
#endif

#if (CapSenseProx_GENERATION_BLOCK_VERSION == CapSenseProx_FOURTH_GENERATION_BLOCK)
    #define CapSenseProx_CSDV2                          (CapSenseProx_ENABLE)

    #ifdef CYIPBLOCK_m0s8csdv2_VERSION
        #if (1u == CYIPBLOCK_m0s8csdv2_VERSION)
            #define CapSenseProx_CSDV2_VER1             (CapSenseProx_ENABLE)
        #else
            #define CapSenseProx_CSDV2_VER1             (CapSenseProx_DISABLE)
        #endif
        #if (2u == CYIPBLOCK_m0s8csdv2_VERSION)
            #define CapSenseProx_CSDV2_VER2             (CapSenseProx_ENABLE)
        #else
            #define CapSenseProx_CSDV2_VER2             (CapSenseProx_DISABLE)
        #endif
    #else
        #error "HW IP block version is not specified"
    #endif
#else
    #define CapSenseProx_CSDV2                          (CapSenseProx_DISABLE)
    #define CapSenseProx_CSDV2_VER1                     (CapSenseProx_DISABLE)
    #define CapSenseProx_CSDV2_VER2                     (CapSenseProx_DISABLE)
#endif

/*******************************************************************************
* Project-global defines
*******************************************************************************/

#define CapSenseProx_2000_MV                            (2000u)

#ifdef CYDEV_VDDA_MV
    #define CapSenseProx_CYDEV_VDDA_MV                  (CYDEV_VDDA_MV)
#else
    #ifdef CYDEV_VDD_MV
        #define CapSenseProx_CYDEV_VDDA_MV              (CYDEV_VDD_MV)
    #endif
#endif

#define CapSenseProx_BAD_CONVERSIONS_NUM                (1u)
#define CapSenseProx_RESAMPLING_CYCLES_MAX_NUMBER       (1u)


/*******************************************************************************
* Enabled Scan Methods
*******************************************************************************/
#define CapSenseProx_CSD_EN                             (1u)
#define CapSenseProx_CSX_EN                             (0u)
#define CapSenseProx_ISX_EN                             (0u)
#define CapSenseProx_CSD_CSX_EN                         (CapSenseProx_CSD_EN && CapSenseProx_CSX_EN)

#define CapSenseProx_MANY_SENSE_MODES_EN                ((CapSenseProx_CSD_EN && CapSenseProx_CSX_EN) || \
                                                             (CapSenseProx_CSD_EN && CapSenseProx_ISX_EN) || \
                                                             (CapSenseProx_CSX_EN && CapSenseProx_ISX_EN) || \
                                                             (CapSenseProx_SELF_TEST_EN))

#define CapSenseProx_MANY_WIDGET_METHODS_EN             ((CapSenseProx_CSD_EN && CapSenseProx_CSX_EN) || \
                                                             (CapSenseProx_CSD_EN && CapSenseProx_ISX_EN) || \
                                                             (CapSenseProx_CSX_EN && CapSenseProx_ISX_EN))

#define CapSenseProx_CSD2X_EN                           (0u)
#define CapSenseProx_CSX2X_EN                           (0u)

/*******************************************************************************
* Definitions for number of widgets and sensors
*******************************************************************************/
#define CapSenseProx_TOTAL_WIDGETS                      (1u)
#define CapSenseProx_TOTAL_CSD_WIDGETS                  (1u)
#define CapSenseProx_TOTAL_CSD_SENSORS                  (1u)
#define CapSenseProx_TOTAL_CSX_WIDGETS                  (0u)
#define CapSenseProx_TOTAL_ISX_WIDGETS                  (0u)
#define CapSenseProx_TOTAL_CSX_NODES                    (0u)
#define CapSenseProx_TOTAL_ISX_NODES                    (0u)

/*******************************************************************************
* Total number of CSD sensors + CSX nodes
*******************************************************************************/
#define CapSenseProx_TOTAL_SENSORS            (CapSenseProx_TOTAL_CSD_SENSORS + \
                                                   CapSenseProx_TOTAL_CSX_NODES+ \
                                                   CapSenseProx_TOTAL_ISX_NODES)

/*******************************************************************************
* Total number of scan slots (used only when dual-channel scan is enabled)
*******************************************************************************/
#define CapSenseProx_TOTAL_SCAN_SLOTS         (1u)

/*******************************************************************************
* Defines widget IDs
*******************************************************************************/
#define CapSenseProx_PROXIMITY0_WDGT_ID         (0u)

/*******************************************************************************
* Defines sensor IDs
*******************************************************************************/

/* Proximity0 sensor names */
#define CapSenseProx_PROXIMITY0_SNS0_ID         (0u)



/*******************************************************************************
* Enabled widget types
*******************************************************************************/
#define CapSenseProx_BUTTON_WIDGET_EN         (0u)
#define CapSenseProx_SLIDER_WIDGET_EN         (0u)
#define CapSenseProx_MATRIX_WIDGET_EN         (0u)
#define CapSenseProx_PROXIMITY_WIDGET_EN      (1u)
#define CapSenseProx_TOUCHPAD_WIDGET_EN       (0u)
#define CapSenseProx_ENCODERDIAL_WIDGET_EN    (0u)

#define CapSenseProx_CSD_MATRIX_WIDGET_EN     (0u)
#define CapSenseProx_CSD_TOUCHPAD_WIDGET_EN   (0u)

#define CapSenseProx_CSX_MATRIX_WIDGET_EN     (0u)
#define CapSenseProx_CSX_TOUCHPAD_WIDGET_EN   (0u)

/*******************************************************************************
* Centroid APIs
*******************************************************************************/
#define CapSenseProx_CENTROID_EN              (0u)
#define CapSenseProx_TOTAL_DIPLEXED_SLIDERS   (0u)
#define CapSenseProx_TOTAL_LINEAR_SLIDERS     (0u)
#define CapSenseProx_TOTAL_RADIAL_SLIDERS     (0u)
#define CapSenseProx_TOTAL_TOUCHPADS          (0u)
#define CapSenseProx_MAX_CENTROID_LENGTH      (0u)
#define CapSenseProx_SLIDER_MULT_METHOD       (0u)
#define CapSenseProx_TOUCHPAD_MULT_METHOD     (0u)

/*******************************************************************************
* Enabled sensor types
*******************************************************************************/
#define CapSenseProx_REGULAR_SENSOR_EN        (0u)
#define CapSenseProx_PROXIMITY_SENSOR_EN      (1u)

/*******************************************************************************
* Sensor ganging
*******************************************************************************/
#define CapSenseProx_GANGED_SNS_EN            (0u)
#define CapSenseProx_CSD_GANGED_SNS_EN        (0u)
#define CapSenseProx_CSX_GANGED_SNS_EN        (0u)

/*******************************************************************************
* Max number of sensors used among all the widgets
*******************************************************************************/
#define CapSenseProx_MAX_SENSORS_PER_WIDGET   (2u)
#define CapSenseProx_MAX_SENSORS_PER_5X5_TOUCHPAD (1u)

/*******************************************************************************
* Total number of all used electrodes (NOT unique)
*******************************************************************************/
#define CapSenseProx_TOTAL_ELECTRODES         (1u)
/* Obsolete */
#define CapSenseProx_TOTAL_SENSOR_IOS         CapSenseProx_TOTAL_ELECTRODES

/*******************************************************************************
* Total number of used physical IOs (unique)
*******************************************************************************/
#define CapSenseProx_TOTAL_IO_CNT             (1u)

/*******************************************************************************
* Array length for widget status registers
*******************************************************************************/
#define CapSenseProx_WDGT_STATUS_WORDS        \
                        (((uint8)((CapSenseProx_TOTAL_WIDGETS - 1u) / 32u)) + 1u)


/*******************************************************************************
* Auto-tuning mode selection
*******************************************************************************/
#define CapSenseProx_CSD_SS_DIS         (0x00ul)
#define CapSenseProx_CSD_SS_HW_EN       (0x01ul)
#define CapSenseProx_CSD_SS_TH_EN       (0x02ul)
#define CapSenseProx_CSD_SS_HWTH_EN     (CapSenseProx_CSD_SS_HW_EN | \
                                             CapSenseProx_CSD_SS_TH_EN)

#define CapSenseProx_CSD_AUTOTUNE       CapSenseProx_CSD_SS_DIS


/*******************************************************************************
* General settings
*******************************************************************************/

#define CapSenseProx_AUTO_RESET_METHOD_LEGACY (0u)
#define CapSenseProx_AUTO_RESET_METHOD_SAMPLE (1u)

#define CapSenseProx_MULTI_FREQ_SCAN_EN       (0u)
#define CapSenseProx_SENSOR_AUTO_RESET_EN     (0u)
#define CapSenseProx_SENSOR_AUTO_RESET_METHOD (0u)
#define CapSenseProx_NUM_CENTROIDS            (1u)
#define CapSenseProx_4PTS_LOCAL_MAX_EN        (0u)
#define CapSenseProx_OFF_DEBOUNCE_EN          (0u)
#define CapSenseProx_CUSTOM_DS_RAM_SIZE       (0u)

/* Defines power status of HW block after scanning */
#define CapSenseProx_BLOCK_OFF_AFTER_SCAN_EN  (0u)

/* Defines number of scan frequencies */
#if (CapSenseProx_DISABLE != CapSenseProx_MULTI_FREQ_SCAN_EN)
    #define CapSenseProx_NUM_SCAN_FREQS       (3u)
#else
    #define CapSenseProx_NUM_SCAN_FREQS       (1u)
#endif /* #if (CapSenseProx_DISABLE != CapSenseProx_MULTI_FREQ_SCAN_EN) */

/* Data size for thresholds / low baseline reset */
#define CapSenseProx_SIZE_8BITS               (8u)
#define CapSenseProx_SIZE_16BITS              (16u)

#define CapSenseProx_THRESHOLD_SIZE           CapSenseProx_SIZE_16BITS
typedef uint16 CapSenseProx_THRESHOLD_TYPE;

#if (CapSenseProx_AUTO_RESET_METHOD_LEGACY == CapSenseProx_SENSOR_AUTO_RESET_METHOD)
    #define CapSenseProx_LOW_BSLN_RST_SIZE        CapSenseProx_SIZE_8BITS
    typedef uint8 CapSenseProx_LOW_BSLN_RST_TYPE;
#else
    #define CapSenseProx_LOW_BSLN_RST_SIZE    (16u)
    typedef uint16 CapSenseProx_LOW_BSLN_RST_TYPE;
#endif /* #if (CapSenseProx_AUTO_RESET_METHOD_LEGACY == CapSenseProx_SENSOR_AUTO_RESET_METHOD) */

/* Coefficient to define touch threshold for proximity sensors */
#define CapSenseProx_PROX_TOUCH_COEFF         (300u)

/*******************************************************************************
* General Filter Constants
*******************************************************************************/

/* Baseline algorithm options */
#define CapSenseProx_IIR_BASELINE                 (0u)
#define CapSenseProx_BUCKET_BASELINE              (1u)

#define CapSenseProx_BASELINE_TYPE                CapSenseProx_IIR_BASELINE

/* IIR baseline filter algorithm for regular sensors*/
#define CapSenseProx_REGULAR_IIR_BL_TYPE          CapSenseProx_IIR_FILTER_PERFORMANCE

/* IIR baseline coefficients for regular sensors */
#define CapSenseProx_REGULAR_IIR_BL_N             (1u)
#define CapSenseProx_REGULAR_IIR_BL_SHIFT         (8u)

/* IIR baseline filter algorithm for proximity sensors*/
#define CapSenseProx_PROX_IIR_BL_TYPE             CapSenseProx_IIR_FILTER_PERFORMANCE

/* IIR baseline coefficients for proximity sensors */
#define CapSenseProx_PROX_IIR_BL_N                (5u)
#define CapSenseProx_PROX_IIR_BL_SHIFT            (8u)


/* IIR filter constants */
#define CapSenseProx_IIR_COEFFICIENT_K            (256u)

/* IIR filter type */
#define CapSenseProx_IIR_FILTER_STANDARD          (1u)
#define CapSenseProx_IIR_FILTER_PERFORMANCE       (2u)
#define CapSenseProx_IIR_FILTER_MEMORY            (3u)

/* Regular sensor raw count filters */
#define CapSenseProx_REGULAR_RC_FILTER_EN         (0u)
#define CapSenseProx_REGULAR_RC_IIR_FILTER_EN     (0u)
#define CapSenseProx_REGULAR_RC_MEDIAN_FILTER_EN  (0u)
#define CapSenseProx_REGULAR_RC_AVERAGE_FILTER_EN (0u)
#define CapSenseProx_REGULAR_RC_CUSTOM_FILTER_EN  (0u)
#define CapSenseProx_REGULAR_RC_ALP_FILTER_EN     (0u)

/* Proximity sensor raw count filters */
#define CapSenseProx_PROX_RC_FILTER_EN            (1u)
#define CapSenseProx_PROX_RC_IIR_FILTER_EN        (1u)
#define CapSenseProx_PROX_RC_MEDIAN_FILTER_EN     (0u)
#define CapSenseProx_PROX_RC_AVERAGE_FILTER_EN    (0u)
#define CapSenseProx_PROX_RC_CUSTOM_FILTER_EN     (0u)
#define CapSenseProx_PROX_RC_ALP_FILTER_EN        (0u)

#define CapSenseProx_ALP_FILTER_EN                (0u)
#define CapSenseProx_REGULAR_RC_ALP_FILTER_COEFF  (2u)
#define CapSenseProx_PROX_RC_ALP_FILTER_COEFF     (2u)

/* Raw count filters */
#define CapSenseProx_RC_FILTER_EN                 (CapSenseProx_REGULAR_RC_FILTER_EN || CapSenseProx_PROX_RC_FILTER_EN)

/* IIR raw count filter algorithm for regular sensors */
#define CapSenseProx_REGULAR_IIR_RC_TYPE          (CapSenseProx_IIR_FILTER_STANDARD)

/* IIR raw count filter coefficients for regular sensors */
#define CapSenseProx_REGULAR_IIR_RC_N             (64u)
#define CapSenseProx_REGULAR_IIR_RC_SHIFT         (0u)

/* IIR raw count filter algorithm for proximity sensors*/
#define CapSenseProx_PROX_IIR_RC_TYPE             (CapSenseProx_IIR_FILTER_STANDARD)

/* IIR raw count filter coefficients for proximity sensors */
#define CapSenseProx_PROX_IIR_RC_N                (128u)
#define CapSenseProx_PROX_IIR_RC_SHIFT            (0u)

/* Median filter constants */

/* Order of regular sensor median filter */
#define CapSenseProx_REGULAR_MEDIAN_LEN           (2u)

/* Order of proximity sensor median filter */
#define CapSenseProx_PROX_MEDIAN_LEN              (2u)

/* Average filter constants*/
#define CapSenseProx_AVERAGE_FILTER_LEN_2         (1u)
#define CapSenseProx_AVERAGE_FILTER_LEN_4         (3u)

/* Order of regular sensor average filter */
#define CapSenseProx_REGULAR_AVERAGE_LEN          (CapSenseProx_AVERAGE_FILTER_LEN_4)

/* Order of proximity sensor average filter */
#define CapSenseProx_PROX_AVERAGE_LEN             (CapSenseProx_AVERAGE_FILTER_LEN_4)

/* Widget baseline coefficient enable */
#define CapSenseProx_WD_BSLN_COEFF_EN             (0u)

/* Centroid position filters */
#define CapSenseProx_POSITION_FILTER_EN           (0u)
#define CapSenseProx_POS_MEDIAN_FILTER_EN         (0u)
#define CapSenseProx_POS_IIR_FILTER_EN            (0u)
#define CapSenseProx_POS_ADAPTIVE_IIR_FILTER_EN   (0u)
#define CapSenseProx_POS_AVERAGE_FILTER_EN        (0u)
#define CapSenseProx_POS_JITTER_FILTER_EN         (0u)
#define CapSenseProx_BALLISTIC_MULTIPLIER_EN      (0u)
#define CapSenseProx_CENTROID_3X3_CSD_EN          (0u)
#define CapSenseProx_CENTROID_5X5_CSD_EN          (0u)
#define CapSenseProx_CSD_5X5_MAX_FINGERS          (1u)

#define CapSenseProx_POS_IIR_COEFF                (128u)
#define CapSenseProx_POS_IIR_RESET_RADIAL_SLIDER  (35u)

#define CapSenseProx_CSX_TOUCHPAD_UNDEFINED       (40u)

/* IDAC options */

/* Third-generation HW block IDAC gain */
#define CapSenseProx_IDAC_GAIN_4X                 (4u)
#define CapSenseProx_IDAC_GAIN_8X                 (8u)

/* Fourth-generation HW block IDAC gain */
#define CapSenseProx_IDAC_GAIN_LOW                (0uL)
#define CapSenseProx_IDAC_GAIN_MEDIUM             (1uL)
#define CapSenseProx_IDAC_GAIN_HIGH               (2uL)

#define CapSenseProx_IDAC_SOURCING                (0u)
#define CapSenseProx_IDAC_SINKING                 (1u)

/* Shield tank capacitor precharge source */
#define CapSenseProx_CSH_PRECHARGE_VREF           (0u)
#define CapSenseProx_CSH_PRECHARGE_IO_BUF         (1u)

/* Shield electrode delay */
#define CapSenseProx_NO_DELAY                     (0u)

#if(CapSenseProx_ENABLE == CapSenseProx_CSDV2)
    #define CapSenseProx_SH_DELAY_5NS             (1u)
    #define CapSenseProx_SH_DELAY_10NS            (2u)
    #define CapSenseProx_SH_DELAY_20NS            (3u)
#else
    #if(CapSenseProx_ENABLE == CapSenseProx_CSDV1_VER2)
        #define CapSenseProx_SH_DELAY_10NS        (3u)
        #define CapSenseProx_SH_DELAY_50NS        (2u)
    #else
        #define CapSenseProx_SH_DELAY_1CYCLES     (1u)
        #define CapSenseProx_SH_DELAY_2CYCLES     (2u)
    #endif /* (CapSenseProx_ENABLE == CapSenseProx_CSDV1_VER2) */
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSDV2) */

/* Inactive sensor connection options */
#define CapSenseProx_SNS_CONNECTION_GROUND        (0x00000000u)
#define CapSenseProx_SNS_CONNECTION_HIGHZ         (0x00000001u)
#define CapSenseProx_SNS_CONNECTION_SHIELD        (0x00000002u)
#define CapSenseProx_SNS_CONNECTION_UNDEFINED     (0x00000003u)

/* Sense clock selection options */
#if defined(CapSenseProx_TAPEOUT_STAR_USED)
    #define CapSenseProx_CSDV2_REF9P6UA_EN            (0u)
#else
    #define CapSenseProx_CSDV2_REF9P6UA_EN            (1u)
#endif /* defined(CapSenseProx_TAPEOUT_STAR_USED) */

#define CapSenseProx_CLK_SOURCE_DIRECT            (0x00000000Lu)

#define CapSenseProx_CLK_SOURCE_SSC1              (0x01u)
#define CapSenseProx_CLK_SOURCE_SSC2              (0x02u)
#define CapSenseProx_CLK_SOURCE_SSC3              (0x03u)
#define CapSenseProx_CLK_SOURCE_SSC4              (0x04u)

#define CapSenseProx_CLK_SOURCE_PRS8              (0x05u)
#define CapSenseProx_CLK_SOURCE_PRS12             (0x06u)
#define CapSenseProx_CLK_SOURCE_PRSAUTO           (0xFFu)

#define CapSenseProx_MFS_IMO                      (0u)
#define CapSenseProx_MFS_SNS_CLK                  (1u)

/* Defines scan resolutions */
#define CapSenseProx_RES6BIT                      (6u)
#define CapSenseProx_RES7BIT                      (7u)
#define CapSenseProx_RES8BIT                      (8u)
#define CapSenseProx_RES9BIT                      (9u)
#define CapSenseProx_RES10BIT                     (10u)
#define CapSenseProx_RES11BIT                     (11u)
#define CapSenseProx_RES12BIT                     (12u)
#define CapSenseProx_RES13BIT                     (13u)
#define CapSenseProx_RES14BIT                     (14u)
#define CapSenseProx_RES15BIT                     (15u)
#define CapSenseProx_RES16BIT                     (16u)

/* Fourth-generation HW block: Initialization switch resistance */
#define CapSenseProx_INIT_SW_RES_LOW              (0x00000000Lu)
#define CapSenseProx_INIT_SW_RES_MEDIUM           (0x00000001Lu)
#define CapSenseProx_INIT_SW_RES_HIGH             (0x00000002Lu)

/* Fourth-generation HW block: Initialization switch resistance */
#define CapSenseProx_SCAN_SW_RES_LOW              (0x00000000Lu)
#define CapSenseProx_SCAN_SW_RES_MEDIUM           (0x00000001Lu)
#define CapSenseProx_SCAN_SW_RES_HIGH             (0x00000002Lu)

/* Fourth-generation HW block: CSD shield switch resistance */
#define CapSenseProx_SHIELD_SW_RES_LOW            (0x00000000Lu)
#define CapSenseProx_SHIELD_SW_RES_MEDIUM         (0x00000001Lu)
#define CapSenseProx_SHIELD_SW_RES_HIGH           (0x00000002Lu)
#define CapSenseProx_SHIELD_SW_RES_LOW_EMI        (0x00000003Lu)

/* Fourth-generation HW block: CSD shield switch resistance */
#define CapSenseProx_INIT_SHIELD_SW_RES_LOW       (0x00000000Lu)
#define CapSenseProx_INIT_SHIELD_SW_RES_MEDIUM    (0x00000001Lu)
#define CapSenseProx_INIT_SHIELD_SW_RES_HIGH      (0x00000002Lu)
#define CapSenseProx_INIT_SHIELD_SW_RES_LOW_EMI   (0x00000003Lu)

/* Fourth-generation HW block: CSD shield switch resistance */
#define CapSenseProx_SCAN_SHIELD_SW_RES_LOW       (0x00000000Lu)
#define CapSenseProx_SCAN_SHIELD_SW_RES_MEDIUM    (0x00000001Lu)
#define CapSenseProx_SCAN_SHIELD_SW_RES_HIGH      (0x00000002Lu)
#define CapSenseProx_SCAN_SHIELD_SW_RES_LOW_EMI   (0x00000003Lu)

/* Sensing method */
#define CapSenseProx_SENSING_LEGACY               (0x00000000Lu)
#define CapSenseProx_SENSING_LOW_EMI              (0x00000001Lu)
#define CapSenseProx_SENSING_FULL_WAVE            (0x00000002Lu)


/*******************************************************************************
* CSD/CSX Common Settings
*******************************************************************************/

#define CapSenseProx_BLOCK_ANALOG_WAKEUP_DELAY_US (0u)

#define CapSenseProx_MFS_METHOD                   (0u)
#define CapSenseProx_IMO_FREQUENCY_OFFSET_F1      (20u)
#define CapSenseProx_IMO_FREQUENCY_OFFSET_F2      (20u)

/*******************************************************************************
* CSD Specific Settings
*******************************************************************************/

/* CSD scan method settings */
#define CapSenseProx_CSD_IDAC_AUTOCAL_EN          (1u)
#define CapSenseProx_CSD_IDAC_GAIN                (CapSenseProx_IDAC_GAIN_HIGH)
#define CapSenseProx_CSD_SHIELD_EN                (0u)
#define CapSenseProx_CSD_SHIELD_TANK_EN           (1u)
#define CapSenseProx_CSD_CSH_PRECHARGE_SRC        (CapSenseProx_CSH_PRECHARGE_VREF)
#define CapSenseProx_CSD_SHIELD_DELAY             (CapSenseProx_NO_DELAY)
#define CapSenseProx_CSD_TOTAL_SHIELD_COUNT       (0u)
#define CapSenseProx_CSD_SCANSPEED_DIVIDER        (1u)
#define CapSenseProx_CSD_COMMON_SNS_CLK_EN        (0u)
#define CapSenseProx_CSD_SNS_CLK_SOURCE           (CapSenseProx_CLK_SOURCE_PRS12)
#define CapSenseProx_CSD_SNS_CLK_DIVIDER          (4u)
#define CapSenseProx_CSD_INACTIVE_SNS_CONNECTION  (CapSenseProx_SNS_CONNECTION_GROUND)
#define CapSenseProx_CSD_IDAC_COMP_EN             (1u)
#define CapSenseProx_CSD_IDAC_CONFIG              (CapSenseProx_IDAC_SOURCING)
#define CapSenseProx_CSD_RAWCOUNT_CAL_LEVEL       (85u)
#define CapSenseProx_CSD_DUALIDAC_LEVEL           (50u)
#define CapSenseProx_CSD_PRESCAN_SETTLING_TIME    (5u)
#define CapSenseProx_CSD_SNSCLK_R_CONST           (1000u)
#define CapSenseProx_CSD_VREF_MV                  (2021u)

#define CapSenseProx_CSD_CALIBRATION_ERROR        (10u)
#define CapSenseProx_CSD_IDAC_AUTO_GAIN_EN        (1u)
#define CapSenseProx_CSD_IDAC_GAIN_INDEX_DEFAULT  (4u)
#define CapSenseProx_CSD_IDAC_MIN                 (20u)
#define CapSenseProx_CSD_COL_ROW_IDAC_ALIGNMENT_EN      (1u)

/* The macro is obsolete and should not be used */
#define CapSenseProx_CSD_DEDICATED_IDAC_COMP_EN   (1u)
/* CSD settings - Fourth-generation HW block */
#define CapSenseProx_CSD_ANALOG_STARTUP_DELAY_US  (0u)
#define CapSenseProx_CSD_FINE_INIT_TIME           (10u)
#define CapSenseProx_CSD_AUTO_ZERO_EN             (0u)
#define CapSenseProx_CSD_AUTO_ZERO_TIME           (1Lu)
#define CapSenseProx_CSD_NOISE_METRIC_EN          (0u)
#define CapSenseProx_CSD_NOISE_METRIC_TH          (1Lu)
#define CapSenseProx_CSD_INIT_SWITCH_RES          (CapSenseProx_INIT_SW_RES_MEDIUM)
#define CapSenseProx_CSD_SENSING_METHOD           (0)
#define CapSenseProx_CSD_SHIELD_SWITCH_RES        (CapSenseProx_SHIELD_SW_RES_MEDIUM)
#define CapSenseProx_CSD_GAIN                     (18Lu)

#define CapSenseProx_CSD_MFS_DIVIDER_OFFSET_F1    (1u)
#define CapSenseProx_CSD_MFS_DIVIDER_OFFSET_F2    (2u)

/*******************************************************************************
* CSX Specific Settings
*******************************************************************************/

/* CSX scan method settings */
#define CapSenseProx_CSX_SCANSPEED_DIVIDER        (1u)
#define CapSenseProx_CSX_COMMON_TX_CLK_EN         (0u)
#define CapSenseProx_CSX_TX_CLK_SOURCE            (CapSenseProx_CLK_SOURCE_PRSAUTO)
#define CapSenseProx_CSX_TX_CLK_DIVIDER           (80u)
#define CapSenseProx_CSX_INACTIVE_SNS_CONNECTION  (CapSenseProx_SNS_CONNECTION_GROUND)
#define CapSenseProx_CSX_MAX_FINGERS              (1u)
#define CapSenseProx_CSX_MAX_LOCAL_PEAKS          (5u)
#define CapSenseProx_CSX_IDAC_AUTOCAL_EN          (0u)
#define CapSenseProx_CSX_IDAC_BITS_USED           (7u)
#define CapSenseProx_CSX_RAWCOUNT_CAL_LEVEL       (40u)
#define CapSenseProx_CSX_IDAC_GAIN                (CapSenseProx_IDAC_GAIN_MEDIUM)
#define CapSenseProx_CSX_CALIBRATION_ERROR        (20u)
#define CapSenseProx_CSX_SKIP_OVSMPL_SPECIFIC_NODES (0u)
#define CapSenseProx_CSX_MULTIPHASE_TX_EN         (0u)
#define CapSenseProx_CSX_MAX_TX_PHASE_LENGTH      (0u)

/* CSX settings - Fourth-generation HW block */
#define CapSenseProx_CSX_ANALOG_STARTUP_DELAY_US  (0u)
#define CapSenseProx_CSX_AUTO_ZERO_EN             (0u)
#define CapSenseProx_CSX_AUTO_ZERO_TIME           (1u)
#define CapSenseProx_CSX_FINE_INIT_TIME           (4u)
#define CapSenseProx_CSX_NOISE_METRIC_EN          (0u)
#define CapSenseProx_CSX_NOISE_METRIC_TH          (1u)
#define CapSenseProx_CSX_INIT_SWITCH_RES          (CapSenseProx_INIT_SW_RES_MEDIUM)
#define CapSenseProx_CSX_SCAN_SWITCH_RES          (CapSenseProx_SCAN_SW_RES_LOW)
#define CapSenseProx_CSX_INIT_SHIELD_SWITCH_RES   (CapSenseProx_INIT_SHIELD_SW_RES_HIGH)
#define CapSenseProx_CSX_SCAN_SHIELD_SWITCH_RES   (CapSenseProx_SCAN_SHIELD_SW_RES_LOW)

#define CapSenseProx_CSX_MFS_DIVIDER_OFFSET_F1    (1u)
#define CapSenseProx_CSX_MFS_DIVIDER_OFFSET_F2    (2u)

/* Gesture parameters */
#define CapSenseProx_GES_GLOBAL_EN                (0u)

/*******************************************************************************
* ISX Specific Settings
*******************************************************************************/

/* ISX scan method settings */
#define CapSenseProx_ISX_SCANSPEED_DIVIDER        (1u)
#define CapSenseProx_ISX_LX_CLK_DIVIDER           (80u)
#define CapSenseProx_ISX_IDAC_AUTOCAL_EN          (0u)
#define CapSenseProx_ISX_IDAC_BITS_USED           (7u)
#define CapSenseProx_ISX_RAWCOUNT_CAL_LEVEL       (30u)
#define CapSenseProx_ISX_IDAC_GAIN                (CapSenseProx_IDAC_GAIN_MEDIUM)
#define CapSenseProx_ISX_SKIP_OVSMPL_SPECIFIC_NODES (0u)
#define CapSenseProx_ISX_MAX_TX_PHASE_LENGTH      (0u)
#define CapSenseProx_ISX_PIN_COUNT_LX             (u)
/* ISX settings - Fourth-generation HW block */
#define CapSenseProx_ISX_AUTO_ZERO_EN             (0u)
#define CapSenseProx_ISX_AUTO_ZERO_TIME           (15u)
#define CapSenseProx_ISX_FINE_INIT_TIME           (20u)
#define CapSenseProx_ISX_NOISE_METRIC_EN          (0u)
#define CapSenseProx_ISX_NOISE_METRIC_TH          (1u)
#define CapSenseProx_ISX_INIT_SWITCH_RES          (CapSenseProx_INIT_SW_RES_MEDIUM)
#define CapSenseProx_ISX_SCAN_SWITCH_RES          (CapSenseProx_SCAN_SW_RES_LOW)
#define CapSenseProx_ISX_INIT_SHIELD_SWITCH_RES   (CapSenseProx_INIT_SHIELD_SW_RES_HIGH)
#define CapSenseProx_ISX_SCAN_SHIELD_SWITCH_RES   (CapSenseProx_SCAN_SHIELD_SW_RES_LOW)
#define CapSenseProx_ISX_SAMPLE_PHASE_DEG         (30u)

/*******************************************************************************
* Global Parameter Definitions
*******************************************************************************/

/* Compound section definitions */
#define CapSenseProx_ANY_NONSS_AUTOCAL ((0u != CapSenseProx_CSX_IDAC_AUTOCAL_EN) || \
                                       (0u != CapSenseProx_ISX_IDAC_AUTOCAL_EN) || \
                                      ((CapSenseProx_CSD_AUTOTUNE == CapSenseProx_CSD_SS_DIS) && (0u != CapSenseProx_CSD_IDAC_AUTOCAL_EN)))
#define CapSenseProx_ANYMODE_AUTOCAL (((0u != CapSenseProx_CSX_IDAC_AUTOCAL_EN) \
                                       || (0u != CapSenseProx_ISX_IDAC_AUTOCAL_EN)) \
                                       || (0u != CapSenseProx_CSD_IDAC_AUTOCAL_EN))
/* RAM Global Parameters Definitions */
#define CapSenseProx_CONFIG_ID                  (0xC4C8u)
#define CapSenseProx_DEVICE_ID                  (0x0100u)
#define CapSenseProx_HW_CLOCK                   (0x0BB8u)
#define CapSenseProx_CSD0_CONFIG                (0x0008u)
#define CapSenseProx_GLB_CRC                    (0x7444u)

/*******************************************************************************
* Proximity0 initialization values for FLASH data structure
*******************************************************************************/
#define CapSenseProx_PROXIMITY0_STATIC_CONFIG   (10241u)
#define CapSenseProx_PROXIMITY0_NUM_SENSORS     (1u)

/*******************************************************************************
* Proximity0 initialization values for RAM data structure
*******************************************************************************/
#define CapSenseProx_PROXIMITY0_CRC             (0xF328u)
#define CapSenseProx_PROXIMITY0_RESOLUTION      (CapSenseProx_RES16BIT)
#define CapSenseProx_PROXIMITY0_FINGER_TH       (250u)
#define CapSenseProx_PROXIMITY0_NOISE_TH        (50u)
#define CapSenseProx_PROXIMITY0_NNOISE_TH       (50u)
#define CapSenseProx_PROXIMITY0_HYSTERESIS      (25u)
#define CapSenseProx_PROXIMITY0_ON_DEBOUNCE     (3u)
#define CapSenseProx_PROXIMITY0_LOW_BSLN_RST    (30u)
#define CapSenseProx_PROXIMITY0_IDAC_MOD0       (32u)
#define CapSenseProx_PROXIMITY0_IDAC_GAIN_INDEX (4u)
#define CapSenseProx_PROXIMITY0_SNS_CLK         (4u)
#define CapSenseProx_PROXIMITY0_SNS_CLK_SOURCE  (0u)
#define CapSenseProx_PROXIMITY0_PROX_TOUCH_TH   (250u)

/* RAM Sensor Parameters Definitions */
#define CapSenseProx_PROXIMITY0_SNS0_IDAC_COMP0 (32u)



/*******************************************************************************
* ADC Specific Macros
*******************************************************************************/
#define CapSenseProx_ADC_RES8BIT                  (8u)
#define CapSenseProx_ADC_RES10BIT                 (10u)

#define CapSenseProx_ADC_FULLRANGE_MODE           (0u)
#define CapSenseProx_ADC_VREF_MODE                (1u)

#define CapSenseProx_ADC_MIN_CHANNELS             (1u)
#define CapSenseProx_ADC_EN                       (0u)
#define CapSenseProx_ADC_STANDALONE_EN            (0u)
#define CapSenseProx_ADC_TOTAL_CHANNELS           (1u)
#define CapSenseProx_ADC_RESOLUTION               (CapSenseProx_ADC_RES10BIT)
#define CapSenseProx_ADC_AMUXB_INPUT_EN           (0u)
#define CapSenseProx_ADC_SELECT_AMUXB_CH          (0u)
#define CapSenseProx_ADC_AZ_EN                    (0Lu)
#define CapSenseProx_ADC_AZ_TIME                  (10u)
#define CapSenseProx_ADC_VREF_MV                  (2133u)
#define CapSenseProx_ADC_GAIN                     (17Lu)
#define CapSenseProx_ADC_IDAC_DEFAULT             (15u)
#define CapSenseProx_ADC_MODCLK_DIV_DEFAULT       (1u)
#define CapSenseProx_ADC_MEASURE_MODE             (CapSenseProx_ADC_FULLRANGE_MODE)
#define CapSenseProx_ADC_ANALOG_STARTUP_DELAY_US  (23u)
#define CapSenseProx_ADC_ACQUISITION_TIME_US      (10u)

/*******************************************************************************
* Built-In Self-Test Configuration
*******************************************************************************/
#define CapSenseProx_SELF_TEST_EN                   (1Lu)
#define CapSenseProx_TST_GLOBAL_CRC_EN              (1Lu)
#define CapSenseProx_TST_WDGT_CRC_EN                (1Lu)
#define CapSenseProx_TST_BSLN_DUPLICATION_EN        (1Lu)
#define CapSenseProx_TST_BSLN_RAW_OUT_RANGE_EN      (1Lu)
#define CapSenseProx_TST_SNS_SHORT_EN               (1Lu)
#define CapSenseProx_TST_SNS_CAP_EN                 (1Lu)
#define CapSenseProx_TST_SH_CAP_EN                  (0Lu)
#define CapSenseProx_TST_EXTERNAL_CAP_EN            (1Lu)
#define CapSenseProx_TST_VDDA_EN                    (1Lu)

#define CapSenseProx_TST_GLOBAL_CRC         (1Lu << 0u)
#define CapSenseProx_TST_WDGT_CRC           (1Lu << 1u)
#define CapSenseProx_TST_BSLN_DUPLICATION   (1Lu << 4u)
#define CapSenseProx_TST_BSLN_RAW_OUT_RANGE (1Lu << 5u)
#define CapSenseProx_TST_SNS_SHORT          (1Lu << 8u)
#define CapSenseProx_TST_SNS_CAP            (1Lu << 12u)
#define CapSenseProx_TST_EXTERNAL_CAP       (1Lu << 16u)
#define CapSenseProx_TST_VDDA               (1Lu << 20u)
#define CapSenseProx_TST_RUN_SELF_TEST_MASK (CapSenseProx_TST_GLOBAL_CRC | \
                                             CapSenseProx_TST_WDGT_CRC | \
                                             CapSenseProx_TST_BSLN_DUPLICATION | \
                                             CapSenseProx_TST_SNS_SHORT | \
                                             CapSenseProx_TST_SNS_CAP | \
                                             CapSenseProx_TST_EXTERNAL_CAP | \
                                             CapSenseProx_TST_VDDA)
#define CapSenseProx_TST_RUN_SELF_TEST_START_MASK (CapSenseProx_TST_GLOBAL_CRC | \
                                             CapSenseProx_TST_WDGT_CRC | \
                                             CapSenseProx_TST_SNS_SHORT)


#define CapSenseProx_TST_CMOD_ID            (0u)
#define CapSenseProx_TST_EXT_CAPS_NUM       (1u)

/* The divider that provides highest possible modulator clock frequency */
#define CapSenseProx_TST_MOD_CLK_DIVIDER    (1u)
/* The modulator clock frequency in kHz */
#define CapSenseProx_TST_MOD_CLK_KHZ        (24000u)
/* The highest possible sense clock frequency to satisfy equation:
 * SnsClkFreq < 1 / (10 * R * 500pF) */
#define CapSenseProx_TST_BASE_SNS_CLK_KHZ   (375u)
/* The sense clock frequency to measure sensor capacitance should satisfy equation:
 * SnsClkFreq < 1 / (10 * R * 250pF) */
#define CapSenseProx_TST_SNS_CAP_SNS_CLK_HZ (375000u)
/* The sense clock divider for CapSenseProx_TST_SNS_CAP_SNS_CLK_HZ */
#define CapSenseProx_TST_SNS_CAP_SNS_CLK_DIVIDER (64u)
/* The sense clock divider for CapSenseProx_TST_BASE_SNS_CLK_KHZ */
#define CapSenseProx_TST_BASE_SNS_CLK_DIVIDER (64u)
/* The minimum valid sense clock divider */
#define CapSenseProx_TST_MIN_SNS_CLK_DIVIDER (4u)
/* Sensor capacitance measurement test configuration */
#define CapSenseProx_TST_SNS_CAP_VREF_MV    (1200u)
#define CapSenseProx_TST_SNS_CAP_VREF_GAIN  (31u)
/* External capacitor capacitance measurement test configuration */
#define CapSenseProx_TST_EXT_CAP_VREF_MV    (1200u)
#define CapSenseProx_TST_EXT_CAP_VREF_GAIN  (31u)

#define CapSenseProx_GLOBAL_CRC_AREA_START          (30u)
#define CapSenseProx_GLOBAL_CRC_AREA_SIZE           (4u)
#define CapSenseProx_WIDGET_CRC_AREA_START          (2u)
#define CapSenseProx_WIDGET_CRC_AREA_SIZE           (16u)

/* The resolution for sensor capacity measurement */
#define CapSenseProx_TST_SNS_CAP_RESOLUTION         (12u)

/* VDDA measurement test configuration */
/* The resolution for VDDA measurement */
#define CapSenseProx_TST_VDDA_RESOLUTION            (10u)
/* The ModClk divider for external capacitor capacity measurement */
#define CapSenseProx_TST_VDDA_MOD_CLK_DIVIDER       (1u)

#define CapSenseProx_TST_VDDA_VREF_MV               (2021u)
#define CapSenseProx_TST_VDDA_VREF_GAIN             (18u)
#define CapSenseProx_TST_VDDA_IDAC_DEFAULT          (15u)

#define CapSenseProx_TST_FINE_INIT_TIME             (10u)
#define CapSenseProx_TST_ANALOG_STARTUP_DELAY_US    (23u)

#define CapSenseProx_TST_IDAC_AUTO_GAIN_EN          (1u)
#define CapSenseProx_TST_SNS_CAP_RAW_ERROR          (10u)
#define CapSenseProx_TST_IDAC_GAIN_INDEX            (4u)
#define CapSenseProx_TST_RAW_TARGET                 (85u)

#define CapSenseProx_TST_SNS_SHORT_TIME             (2u)

#define CapSenseProx_SNS_CAP_CSD_INACTIVE_CONNECTION        (CapSenseProx_SNS_CONNECTION_GROUND)
#define CapSenseProx_SNS_CAP_CSX_INACTIVE_CONNECTION        (CapSenseProx_SNS_CONNECTION_GROUND)
#define CapSenseProx_SHIELD_CAP_INACTIVE_CONNECTION         (CapSenseProx_SNS_CONNECTION_GROUND)


/*******************************************************************************
* Gesture Configuration
*******************************************************************************/
#define CapSenseProx_TIMESTAMP_INTERVAL             (1Lu)
#define CapSenseProx_GESTURE_EN_WIDGET_ID           (0Lu)
#define CapSenseProx_BALLISTIC_EN_WIDGET_ID         (0Lu)


#endif /* CY_SENSE_CapSenseProx_CONFIGURATION_H */


/* [] END OF FILE */
