/***************************************************************************//**
* \file CapSenseProx_RegisterMap.h
* \version 7.0
*
* \brief
*   This file provides the definitions for the Component data structure register.
*
* \see CapSenseProx v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSenseProx_REGISTER_MAP_H)
#define CY_SENSE_CapSenseProx_REGISTER_MAP_H

#include <cytypes.h>
#include "CapSenseProx_Configuration.h"
#include "CapSenseProx_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define CapSenseProx_CONFIG_ID_VALUE                        (CapSenseProx_dsRam.configId)
#define CapSenseProx_CONFIG_ID_OFFSET                       (0u)
#define CapSenseProx_CONFIG_ID_SIZE                         (2u)
#define CapSenseProx_CONFIG_ID_PARAM_ID                     (0x87000000u)

#define CapSenseProx_DEVICE_ID_VALUE                        (CapSenseProx_dsRam.deviceId)
#define CapSenseProx_DEVICE_ID_OFFSET                       (2u)
#define CapSenseProx_DEVICE_ID_SIZE                         (2u)
#define CapSenseProx_DEVICE_ID_PARAM_ID                     (0x8B000002u)

#define CapSenseProx_HW_CLOCK_VALUE                         (CapSenseProx_dsRam.hwClock)
#define CapSenseProx_HW_CLOCK_OFFSET                        (4u)
#define CapSenseProx_HW_CLOCK_SIZE                          (2u)
#define CapSenseProx_HW_CLOCK_PARAM_ID                      (0x86000004u)

#define CapSenseProx_TUNER_CMD_VALUE                        (CapSenseProx_dsRam.tunerCmd)
#define CapSenseProx_TUNER_CMD_OFFSET                       (6u)
#define CapSenseProx_TUNER_CMD_SIZE                         (2u)
#define CapSenseProx_TUNER_CMD_PARAM_ID                     (0xA1000006u)

#define CapSenseProx_SCAN_COUNTER_VALUE                     (CapSenseProx_dsRam.scanCounter)
#define CapSenseProx_SCAN_COUNTER_OFFSET                    (8u)
#define CapSenseProx_SCAN_COUNTER_SIZE                      (2u)
#define CapSenseProx_SCAN_COUNTER_PARAM_ID                  (0x85000008u)

#define CapSenseProx_STATUS_VALUE                           (CapSenseProx_dsRam.status)
#define CapSenseProx_STATUS_OFFSET                          (12u)
#define CapSenseProx_STATUS_SIZE                            (4u)
#define CapSenseProx_STATUS_PARAM_ID                        (0xCB00000Cu)

#define CapSenseProx_WDGT_ENABLE0_VALUE                     (CapSenseProx_dsRam.wdgtEnable[0u])
#define CapSenseProx_WDGT_ENABLE0_OFFSET                    (16u)
#define CapSenseProx_WDGT_ENABLE0_SIZE                      (4u)
#define CapSenseProx_WDGT_ENABLE0_PARAM_ID                  (0xE6000010u)

#define CapSenseProx_WDGT_WORKING0_VALUE                    (CapSenseProx_dsRam.wdgtWorking[0u])
#define CapSenseProx_WDGT_WORKING0_OFFSET                   (20u)
#define CapSenseProx_WDGT_WORKING0_SIZE                     (4u)
#define CapSenseProx_WDGT_WORKING0_PARAM_ID                 (0xCC000014u)

#define CapSenseProx_WDGT_STATUS0_VALUE                     (CapSenseProx_dsRam.wdgtStatus[0u])
#define CapSenseProx_WDGT_STATUS0_OFFSET                    (24u)
#define CapSenseProx_WDGT_STATUS0_SIZE                      (4u)
#define CapSenseProx_WDGT_STATUS0_PARAM_ID                  (0xCF000018u)

#define CapSenseProx_SNS_STATUS0_VALUE                      (CapSenseProx_dsRam.snsStatus[0u])
#define CapSenseProx_SNS_STATUS0_OFFSET                     (28u)
#define CapSenseProx_SNS_STATUS0_SIZE                       (1u)
#define CapSenseProx_SNS_STATUS0_PARAM_ID                   (0x4900001Cu)

#define CapSenseProx_CSD0_CONFIG_VALUE                      (CapSenseProx_dsRam.csd0Config)
#define CapSenseProx_CSD0_CONFIG_OFFSET                     (30u)
#define CapSenseProx_CSD0_CONFIG_SIZE                       (2u)
#define CapSenseProx_CSD0_CONFIG_PARAM_ID                   (0xAB80001Eu)

#define CapSenseProx_MOD_CSD_CLK_VALUE                      (CapSenseProx_dsRam.modCsdClk)
#define CapSenseProx_MOD_CSD_CLK_OFFSET                     (32u)
#define CapSenseProx_MOD_CSD_CLK_SIZE                       (1u)
#define CapSenseProx_MOD_CSD_CLK_PARAM_ID                   (0x63800020u)

#define CapSenseProx_GLB_CRC_VALUE                          (CapSenseProx_dsRam.glbCrc)
#define CapSenseProx_GLB_CRC_OFFSET                         (34u)
#define CapSenseProx_GLB_CRC_SIZE                           (2u)
#define CapSenseProx_GLB_CRC_PARAM_ID                       (0x81000022u)

#define CapSenseProx_PROXIMITY0_CRC_VALUE                   (CapSenseProx_dsRam.wdgtList.proximity0.crc)
#define CapSenseProx_PROXIMITY0_CRC_OFFSET                  (36u)
#define CapSenseProx_PROXIMITY0_CRC_SIZE                    (2u)
#define CapSenseProx_PROXIMITY0_CRC_PARAM_ID                (0x8C000024u)

#define CapSenseProx_PROXIMITY0_RESOLUTION_VALUE            (CapSenseProx_dsRam.wdgtList.proximity0.resolution)
#define CapSenseProx_PROXIMITY0_RESOLUTION_OFFSET           (38u)
#define CapSenseProx_PROXIMITY0_RESOLUTION_SIZE             (2u)
#define CapSenseProx_PROXIMITY0_RESOLUTION_PARAM_ID         (0xA6800026u)

#define CapSenseProx_PROXIMITY0_FINGER_TH_VALUE             (CapSenseProx_dsRam.wdgtList.proximity0.fingerTh)
#define CapSenseProx_PROXIMITY0_FINGER_TH_OFFSET            (40u)
#define CapSenseProx_PROXIMITY0_FINGER_TH_SIZE              (2u)
#define CapSenseProx_PROXIMITY0_FINGER_TH_PARAM_ID          (0xA9800028u)

#define CapSenseProx_PROXIMITY0_NOISE_TH_VALUE              (CapSenseProx_dsRam.wdgtList.proximity0.noiseTh)
#define CapSenseProx_PROXIMITY0_NOISE_TH_OFFSET             (42u)
#define CapSenseProx_PROXIMITY0_NOISE_TH_SIZE               (1u)
#define CapSenseProx_PROXIMITY0_NOISE_TH_PARAM_ID           (0x6D80002Au)

#define CapSenseProx_PROXIMITY0_NNOISE_TH_VALUE             (CapSenseProx_dsRam.wdgtList.proximity0.nNoiseTh)
#define CapSenseProx_PROXIMITY0_NNOISE_TH_OFFSET            (43u)
#define CapSenseProx_PROXIMITY0_NNOISE_TH_SIZE              (1u)
#define CapSenseProx_PROXIMITY0_NNOISE_TH_PARAM_ID          (0x6B80002Bu)

#define CapSenseProx_PROXIMITY0_HYSTERESIS_VALUE            (CapSenseProx_dsRam.wdgtList.proximity0.hysteresis)
#define CapSenseProx_PROXIMITY0_HYSTERESIS_OFFSET           (44u)
#define CapSenseProx_PROXIMITY0_HYSTERESIS_SIZE             (1u)
#define CapSenseProx_PROXIMITY0_HYSTERESIS_PARAM_ID         (0x6080002Cu)

#define CapSenseProx_PROXIMITY0_ON_DEBOUNCE_VALUE           (CapSenseProx_dsRam.wdgtList.proximity0.onDebounce)
#define CapSenseProx_PROXIMITY0_ON_DEBOUNCE_OFFSET          (45u)
#define CapSenseProx_PROXIMITY0_ON_DEBOUNCE_SIZE            (1u)
#define CapSenseProx_PROXIMITY0_ON_DEBOUNCE_PARAM_ID        (0x6680002Du)

#define CapSenseProx_PROXIMITY0_LOW_BSLN_RST_VALUE          (CapSenseProx_dsRam.wdgtList.proximity0.lowBslnRst)
#define CapSenseProx_PROXIMITY0_LOW_BSLN_RST_OFFSET         (46u)
#define CapSenseProx_PROXIMITY0_LOW_BSLN_RST_SIZE           (1u)
#define CapSenseProx_PROXIMITY0_LOW_BSLN_RST_PARAM_ID       (0x6C80002Eu)

#define CapSenseProx_PROXIMITY0_IDAC_MOD0_VALUE             (CapSenseProx_dsRam.wdgtList.proximity0.idacMod[0u])
#define CapSenseProx_PROXIMITY0_IDAC_MOD0_OFFSET            (47u)
#define CapSenseProx_PROXIMITY0_IDAC_MOD0_SIZE              (1u)
#define CapSenseProx_PROXIMITY0_IDAC_MOD0_PARAM_ID          (0x4C00002Fu)

#define CapSenseProx_PROXIMITY0_IDAC_GAIN_INDEX_VALUE       (CapSenseProx_dsRam.wdgtList.proximity0.idacGainIndex)
#define CapSenseProx_PROXIMITY0_IDAC_GAIN_INDEX_OFFSET      (48u)
#define CapSenseProx_PROXIMITY0_IDAC_GAIN_INDEX_SIZE        (1u)
#define CapSenseProx_PROXIMITY0_IDAC_GAIN_INDEX_PARAM_ID    (0x4D800030u)

#define CapSenseProx_PROXIMITY0_SNS_CLK_VALUE               (CapSenseProx_dsRam.wdgtList.proximity0.snsClk)
#define CapSenseProx_PROXIMITY0_SNS_CLK_OFFSET              (50u)
#define CapSenseProx_PROXIMITY0_SNS_CLK_SIZE                (2u)
#define CapSenseProx_PROXIMITY0_SNS_CLK_PARAM_ID            (0xA2800032u)

#define CapSenseProx_PROXIMITY0_SNS_CLK_SOURCE_VALUE        (CapSenseProx_dsRam.wdgtList.proximity0.snsClkSource)
#define CapSenseProx_PROXIMITY0_SNS_CLK_SOURCE_OFFSET       (52u)
#define CapSenseProx_PROXIMITY0_SNS_CLK_SOURCE_SIZE         (1u)
#define CapSenseProx_PROXIMITY0_SNS_CLK_SOURCE_PARAM_ID     (0x4C800034u)

#define CapSenseProx_PROXIMITY0_PROX_TOUCH_TH_VALUE         (CapSenseProx_dsRam.wdgtList.proximity0.proxTouchTh)
#define CapSenseProx_PROXIMITY0_PROX_TOUCH_TH_OFFSET        (54u)
#define CapSenseProx_PROXIMITY0_PROX_TOUCH_TH_SIZE          (2u)
#define CapSenseProx_PROXIMITY0_PROX_TOUCH_TH_PARAM_ID      (0xAE000036u)

#define CapSenseProx_PROXIMITY0_SNS0_RAW0_VALUE             (CapSenseProx_dsRam.snsList.proximity0[0u].raw[0u])
#define CapSenseProx_PROXIMITY0_SNS0_RAW0_OFFSET            (56u)
#define CapSenseProx_PROXIMITY0_SNS0_RAW0_SIZE              (2u)
#define CapSenseProx_PROXIMITY0_SNS0_RAW0_PARAM_ID          (0x8A000038u)

#define CapSenseProx_PROXIMITY0_SNS0_BSLN0_VALUE            (CapSenseProx_dsRam.snsList.proximity0[0u].bsln[0u])
#define CapSenseProx_PROXIMITY0_SNS0_BSLN0_OFFSET           (58u)
#define CapSenseProx_PROXIMITY0_SNS0_BSLN0_SIZE             (2u)
#define CapSenseProx_PROXIMITY0_SNS0_BSLN0_PARAM_ID         (0x8600003Au)

#define CapSenseProx_PROXIMITY0_SNS0_BSLN_INV0_VALUE        (CapSenseProx_dsRam.snsList.proximity0[0u].bslnInv[0u])
#define CapSenseProx_PROXIMITY0_SNS0_BSLN_INV0_OFFSET       (60u)
#define CapSenseProx_PROXIMITY0_SNS0_BSLN_INV0_SIZE         (2u)
#define CapSenseProx_PROXIMITY0_SNS0_BSLN_INV0_PARAM_ID     (0x8B00003Cu)

#define CapSenseProx_PROXIMITY0_SNS0_BSLN_EXT0_VALUE        (CapSenseProx_dsRam.snsList.proximity0[0u].bslnExt[0u])
#define CapSenseProx_PROXIMITY0_SNS0_BSLN_EXT0_OFFSET       (62u)
#define CapSenseProx_PROXIMITY0_SNS0_BSLN_EXT0_SIZE         (1u)
#define CapSenseProx_PROXIMITY0_SNS0_BSLN_EXT0_PARAM_ID     (0x4F00003Eu)

#define CapSenseProx_PROXIMITY0_SNS0_DIFF_VALUE             (CapSenseProx_dsRam.snsList.proximity0[0u].diff)
#define CapSenseProx_PROXIMITY0_SNS0_DIFF_OFFSET            (64u)
#define CapSenseProx_PROXIMITY0_SNS0_DIFF_SIZE              (2u)
#define CapSenseProx_PROXIMITY0_SNS0_DIFF_PARAM_ID          (0x8A000040u)

#define CapSenseProx_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_VALUE (CapSenseProx_dsRam.snsList.proximity0[0u].negBslnRstCnt[0u])
#define CapSenseProx_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_OFFSET (66u)
#define CapSenseProx_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_SIZE (1u)
#define CapSenseProx_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID (0x4E000042u)

#define CapSenseProx_PROXIMITY0_SNS0_IDAC_COMP0_VALUE       (CapSenseProx_dsRam.snsList.proximity0[0u].idacComp[0u])
#define CapSenseProx_PROXIMITY0_SNS0_IDAC_COMP0_OFFSET      (67u)
#define CapSenseProx_PROXIMITY0_SNS0_IDAC_COMP0_SIZE        (1u)
#define CapSenseProx_PROXIMITY0_SNS0_IDAC_COMP0_PARAM_ID    (0x48000043u)

#define CapSenseProx_TEST_RESULT_MASK_VALUE                 (CapSenseProx_dsRam.selfTest.testResultMask)
#define CapSenseProx_TEST_RESULT_MASK_OFFSET                (68u)
#define CapSenseProx_TEST_RESULT_MASK_SIZE                  (4u)
#define CapSenseProx_TEST_RESULT_MASK_PARAM_ID              (0xEF000044u)

#define CapSenseProx_EXT_CAP0_VALUE                         (CapSenseProx_dsRam.selfTest.extCap[0u])
#define CapSenseProx_EXT_CAP0_OFFSET                        (72u)
#define CapSenseProx_EXT_CAP0_SIZE                          (2u)
#define CapSenseProx_EXT_CAP0_PARAM_ID                      (0xA3000048u)

#define CapSenseProx_VDDA_VOLTAGE_VALUE                     (CapSenseProx_dsRam.selfTest.vddaVoltage)
#define CapSenseProx_VDDA_VOLTAGE_OFFSET                    (74u)
#define CapSenseProx_VDDA_VOLTAGE_SIZE                      (2u)
#define CapSenseProx_VDDA_VOLTAGE_PARAM_ID                  (0xAF00004Au)

#define CapSenseProx_GLB_CRC_CALC_VALUE                     (CapSenseProx_dsRam.selfTest.glbCrcCalc)
#define CapSenseProx_GLB_CRC_CALC_OFFSET                    (76u)
#define CapSenseProx_GLB_CRC_CALC_SIZE                      (2u)
#define CapSenseProx_GLB_CRC_CALC_PARAM_ID                  (0xA200004Cu)

#define CapSenseProx_WDGT_CRC_CALC_VALUE                    (CapSenseProx_dsRam.selfTest.wdgtCrcCalc)
#define CapSenseProx_WDGT_CRC_CALC_OFFSET                   (78u)
#define CapSenseProx_WDGT_CRC_CALC_SIZE                     (2u)
#define CapSenseProx_WDGT_CRC_CALC_PARAM_ID                 (0xAE00004Eu)

#define CapSenseProx_WDGT_CRC_ID_VALUE                      (CapSenseProx_dsRam.selfTest.wdgtCrcId)
#define CapSenseProx_WDGT_CRC_ID_OFFSET                     (80u)
#define CapSenseProx_WDGT_CRC_ID_SIZE                       (1u)
#define CapSenseProx_WDGT_CRC_ID_PARAM_ID                   (0x6C000050u)

#define CapSenseProx_INV_BSLN_WDGT_ID_VALUE                 (CapSenseProx_dsRam.selfTest.invBslnWdgtId)
#define CapSenseProx_INV_BSLN_WDGT_ID_OFFSET                (81u)
#define CapSenseProx_INV_BSLN_WDGT_ID_SIZE                  (1u)
#define CapSenseProx_INV_BSLN_WDGT_ID_PARAM_ID              (0x6A000051u)

#define CapSenseProx_INV_BSLN_SNS_ID_VALUE                  (CapSenseProx_dsRam.selfTest.invBslnSnsId)
#define CapSenseProx_INV_BSLN_SNS_ID_OFFSET                 (82u)
#define CapSenseProx_INV_BSLN_SNS_ID_SIZE                   (1u)
#define CapSenseProx_INV_BSLN_SNS_ID_PARAM_ID               (0x60000052u)

#define CapSenseProx_SHORTED_WDGT_ID_VALUE                  (CapSenseProx_dsRam.selfTest.shortedWdgtId)
#define CapSenseProx_SHORTED_WDGT_ID_OFFSET                 (83u)
#define CapSenseProx_SHORTED_WDGT_ID_SIZE                   (1u)
#define CapSenseProx_SHORTED_WDGT_ID_PARAM_ID               (0x66000053u)

#define CapSenseProx_SHORTED_SNS_ID_VALUE                   (CapSenseProx_dsRam.selfTest.shortedSnsId)
#define CapSenseProx_SHORTED_SNS_ID_OFFSET                  (84u)
#define CapSenseProx_SHORTED_SNS_ID_SIZE                    (1u)
#define CapSenseProx_SHORTED_SNS_ID_PARAM_ID                (0x6D000054u)

#define CapSenseProx_IDAC_GAIN_INDEX_VALUE                  (CapSenseProx_dsRam.selfTest.idacGainIndex)
#define CapSenseProx_IDAC_GAIN_INDEX_OFFSET                 (85u)
#define CapSenseProx_IDAC_GAIN_INDEX_SIZE                   (1u)
#define CapSenseProx_IDAC_GAIN_INDEX_PARAM_ID               (0x6B000055u)

#define CapSenseProx_SNS_CLK_VALUE                          (CapSenseProx_dsRam.selfTest.snsClk)
#define CapSenseProx_SNS_CLK_OFFSET                         (86u)
#define CapSenseProx_SNS_CLK_SIZE                           (2u)
#define CapSenseProx_SNS_CLK_PARAM_ID                       (0xA9000056u)

#define CapSenseProx_SNS_CAP_SNS_CLK_HZ_VALUE               (CapSenseProx_dsRam.selfTestConfig.snsCapSnsClkHz)
#define CapSenseProx_SNS_CAP_SNS_CLK_HZ_OFFSET              (88u)
#define CapSenseProx_SNS_CAP_SNS_CLK_HZ_SIZE                (4u)
#define CapSenseProx_SNS_CAP_SNS_CLK_HZ_PARAM_ID            (0xE9000058u)

#define CapSenseProx_SNS_CAP_SNS_CLK_DIVIDER_VALUE          (CapSenseProx_dsRam.selfTestConfig.snsCapSnsClkDivider)
#define CapSenseProx_SNS_CAP_SNS_CLK_DIVIDER_OFFSET         (92u)
#define CapSenseProx_SNS_CAP_SNS_CLK_DIVIDER_SIZE           (2u)
#define CapSenseProx_SNS_CAP_SNS_CLK_DIVIDER_PARAM_ID       (0xA700005Cu)

#define CapSenseProx_SNS_CAP_MOD_CLK_KHZ_VALUE              (CapSenseProx_dsRam.selfTestConfig.snsCapModClkKHz)
#define CapSenseProx_SNS_CAP_MOD_CLK_KHZ_OFFSET             (94u)
#define CapSenseProx_SNS_CAP_MOD_CLK_KHZ_SIZE               (2u)
#define CapSenseProx_SNS_CAP_MOD_CLK_KHZ_PARAM_ID           (0xAB00005Eu)

#define CapSenseProx_SNS_CAP_MOD_CLK_DIVIDER_VALUE          (CapSenseProx_dsRam.selfTestConfig.snsCapModClkDivider)
#define CapSenseProx_SNS_CAP_MOD_CLK_DIVIDER_OFFSET         (96u)
#define CapSenseProx_SNS_CAP_MOD_CLK_DIVIDER_SIZE           (2u)
#define CapSenseProx_SNS_CAP_MOD_CLK_DIVIDER_PARAM_ID       (0xAB000060u)

#define CapSenseProx_SNS_CAP_VREF_VOLTAGE_VALUE             (CapSenseProx_dsRam.selfTestConfig.snsCapVrefVoltage)
#define CapSenseProx_SNS_CAP_VREF_VOLTAGE_OFFSET            (98u)
#define CapSenseProx_SNS_CAP_VREF_VOLTAGE_SIZE              (2u)
#define CapSenseProx_SNS_CAP_VREF_VOLTAGE_PARAM_ID          (0xA7000062u)

#define CapSenseProx_VDDA_VREF_VOLTAGE_VALUE                (CapSenseProx_dsRam.selfTestConfig.vddaVrefVoltage)
#define CapSenseProx_VDDA_VREF_VOLTAGE_OFFSET               (100u)
#define CapSenseProx_VDDA_VREF_VOLTAGE_SIZE                 (2u)
#define CapSenseProx_VDDA_VREF_VOLTAGE_PARAM_ID             (0xAA000064u)

#define CapSenseProx_EXT_CAP_VREF_VOLTAGE_VALUE             (CapSenseProx_dsRam.selfTestConfig.extCapVrefVoltage)
#define CapSenseProx_EXT_CAP_VREF_VOLTAGE_OFFSET            (102u)
#define CapSenseProx_EXT_CAP_VREF_VOLTAGE_SIZE              (2u)
#define CapSenseProx_EXT_CAP_VREF_VOLTAGE_PARAM_ID          (0xA6000066u)

#define CapSenseProx_VDDA_MOD_CLK_DIVIDER_VALUE             (CapSenseProx_dsRam.selfTestConfig.vddaModClkDivider)
#define CapSenseProx_VDDA_MOD_CLK_DIVIDER_OFFSET            (104u)
#define CapSenseProx_VDDA_MOD_CLK_DIVIDER_SIZE              (1u)
#define CapSenseProx_VDDA_MOD_CLK_DIVIDER_PARAM_ID          (0x61000068u)

#define CapSenseProx_VDDA_VREF_GAIN_VALUE                   (CapSenseProx_dsRam.selfTestConfig.vddaVrefGain)
#define CapSenseProx_VDDA_VREF_GAIN_OFFSET                  (105u)
#define CapSenseProx_VDDA_VREF_GAIN_SIZE                    (1u)
#define CapSenseProx_VDDA_VREF_GAIN_PARAM_ID                (0x67000069u)

#define CapSenseProx_VDDA_RESOLUTION_VALUE                  (CapSenseProx_dsRam.selfTestConfig.vddaResolution)
#define CapSenseProx_VDDA_RESOLUTION_OFFSET                 (106u)
#define CapSenseProx_VDDA_RESOLUTION_SIZE                   (1u)
#define CapSenseProx_VDDA_RESOLUTION_PARAM_ID               (0x6D00006Au)

#define CapSenseProx_VDDA_IDAC_DEFAULT_VALUE                (CapSenseProx_dsRam.selfTestConfig.vddaIdacDefault)
#define CapSenseProx_VDDA_IDAC_DEFAULT_OFFSET               (107u)
#define CapSenseProx_VDDA_IDAC_DEFAULT_SIZE                 (1u)
#define CapSenseProx_VDDA_IDAC_DEFAULT_PARAM_ID             (0x6B00006Bu)

#define CapSenseProx_SNS_CAP_RESOLUTION_VALUE               (CapSenseProx_dsRam.selfTestConfig.snsCapResolution)
#define CapSenseProx_SNS_CAP_RESOLUTION_OFFSET              (108u)
#define CapSenseProx_SNS_CAP_RESOLUTION_SIZE                (1u)
#define CapSenseProx_SNS_CAP_RESOLUTION_PARAM_ID            (0x6000006Cu)

#define CapSenseProx_SNS_CAP_VREF_GAIN_VALUE                (CapSenseProx_dsRam.selfTestConfig.snsCapVrefGain)
#define CapSenseProx_SNS_CAP_VREF_GAIN_OFFSET               (109u)
#define CapSenseProx_SNS_CAP_VREF_GAIN_SIZE                 (1u)
#define CapSenseProx_SNS_CAP_VREF_GAIN_PARAM_ID             (0x6600006Du)

#define CapSenseProx_BIST_CSD_SNS_CAP_ISC_VALUE             (CapSenseProx_dsRam.selfTestConfig.bistCsdSnsCapISC)
#define CapSenseProx_BIST_CSD_SNS_CAP_ISC_OFFSET            (110u)
#define CapSenseProx_BIST_CSD_SNS_CAP_ISC_SIZE              (1u)
#define CapSenseProx_BIST_CSD_SNS_CAP_ISC_PARAM_ID          (0x6C00006Eu)

#define CapSenseProx_BIST_CSX_SNS_CAP_ISC_VALUE             (CapSenseProx_dsRam.selfTestConfig.bistCsxSnsCapISC)
#define CapSenseProx_BIST_CSX_SNS_CAP_ISC_OFFSET            (111u)
#define CapSenseProx_BIST_CSX_SNS_CAP_ISC_SIZE              (1u)
#define CapSenseProx_BIST_CSX_SNS_CAP_ISC_PARAM_ID          (0x6A00006Fu)

#define CapSenseProx_BIST_CSD_SH_CAP_ISC_VALUE              (CapSenseProx_dsRam.selfTestConfig.bistCsdShCapISC)
#define CapSenseProx_BIST_CSD_SH_CAP_ISC_OFFSET             (112u)
#define CapSenseProx_BIST_CSD_SH_CAP_ISC_SIZE               (1u)
#define CapSenseProx_BIST_CSD_SH_CAP_ISC_PARAM_ID           (0x66000070u)

#define CapSenseProx_EXT_CAP_VREF_GAIN_VALUE                (CapSenseProx_dsRam.selfTestConfig.extCapVrefGain)
#define CapSenseProx_EXT_CAP_VREF_GAIN_OFFSET               (113u)
#define CapSenseProx_EXT_CAP_VREF_GAIN_SIZE                 (1u)
#define CapSenseProx_EXT_CAP_VREF_GAIN_PARAM_ID             (0x60000071u)

#define CapSenseProx_STARTUP_DELAY_VALUE                    (CapSenseProx_dsRam.selfTestConfig.startupDelay)
#define CapSenseProx_STARTUP_DELAY_OFFSET                   (114u)
#define CapSenseProx_STARTUP_DELAY_SIZE                     (1u)
#define CapSenseProx_STARTUP_DELAY_PARAM_ID                 (0x6A000072u)

#define CapSenseProx_FINE_INIT_TIME_VALUE                   (CapSenseProx_dsRam.selfTestConfig.fineInitTime)
#define CapSenseProx_FINE_INIT_TIME_OFFSET                  (115u)
#define CapSenseProx_FINE_INIT_TIME_SIZE                    (1u)
#define CapSenseProx_FINE_INIT_TIME_PARAM_ID                (0x6C000073u)

#define CapSenseProx_SNS_SHORT_TIME_VALUE                   (CapSenseProx_dsRam.selfTestConfig.snsShortTimeUs)
#define CapSenseProx_SNS_SHORT_TIME_OFFSET                  (116u)
#define CapSenseProx_SNS_SHORT_TIME_SIZE                    (1u)
#define CapSenseProx_SNS_SHORT_TIME_PARAM_ID                (0x67000074u)

#define CapSenseProx_PROXIMITY0_SNS_CP0_VALUE               (CapSenseProx_dsRam.snsCp.proximity0[0u])
#define CapSenseProx_PROXIMITY0_SNS_CP0_OFFSET              (120u)
#define CapSenseProx_PROXIMITY0_SNS_CP0_SIZE                (4u)
#define CapSenseProx_PROXIMITY0_SNS_CP0_PARAM_ID            (0xE3000078u)

#define CapSenseProx_SNR_TEST_WIDGET_ID_VALUE               (CapSenseProx_dsRam.snrTestWidgetId)
#define CapSenseProx_SNR_TEST_WIDGET_ID_OFFSET              (124u)
#define CapSenseProx_SNR_TEST_WIDGET_ID_SIZE                (1u)
#define CapSenseProx_SNR_TEST_WIDGET_ID_PARAM_ID            (0x6500007Cu)

#define CapSenseProx_SNR_TEST_SENSOR_ID_VALUE               (CapSenseProx_dsRam.snrTestSensorId)
#define CapSenseProx_SNR_TEST_SENSOR_ID_OFFSET              (125u)
#define CapSenseProx_SNR_TEST_SENSOR_ID_SIZE                (1u)
#define CapSenseProx_SNR_TEST_SENSOR_ID_PARAM_ID            (0x6300007Du)

#define CapSenseProx_SNR_TEST_SCAN_COUNTER_VALUE            (CapSenseProx_dsRam.snrTestScanCounter)
#define CapSenseProx_SNR_TEST_SCAN_COUNTER_OFFSET           (126u)
#define CapSenseProx_SNR_TEST_SCAN_COUNTER_SIZE             (2u)
#define CapSenseProx_SNR_TEST_SCAN_COUNTER_PARAM_ID         (0x8A00007Eu)

#define CapSenseProx_SNR_TEST_RAW_COUNT0_VALUE              (CapSenseProx_dsRam.snrTestRawCount[0u])
#define CapSenseProx_SNR_TEST_RAW_COUNT0_OFFSET             (128u)
#define CapSenseProx_SNR_TEST_RAW_COUNT0_SIZE               (2u)
#define CapSenseProx_SNR_TEST_RAW_COUNT0_PARAM_ID           (0x84000080u)

#define CapSenseProx_SCAN_CSD_ISC_VALUE                     (CapSenseProx_dsRam.scanCsdISC)
#define CapSenseProx_SCAN_CSD_ISC_OFFSET                    (130u)
#define CapSenseProx_SCAN_CSD_ISC_SIZE                      (1u)
#define CapSenseProx_SCAN_CSD_ISC_PARAM_ID                  (0x40000082u)

#define CapSenseProx_SCAN_CURRENT_ISC_VALUE                 (CapSenseProx_dsRam.scanCurrentISC)
#define CapSenseProx_SCAN_CURRENT_ISC_OFFSET                (131u)
#define CapSenseProx_SCAN_CURRENT_ISC_SIZE                  (1u)
#define CapSenseProx_SCAN_CURRENT_ISC_PARAM_ID              (0x46000083u)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define CapSenseProx_PROXIMITY0_PTR2SNS_FLASH_VALUE         (CapSenseProx_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define CapSenseProx_PROXIMITY0_PTR2SNS_FLASH_OFFSET        (0u)
#define CapSenseProx_PROXIMITY0_PTR2SNS_FLASH_SIZE          (4u)
#define CapSenseProx_PROXIMITY0_PTR2SNS_FLASH_PARAM_ID      (0xD1000000u)

#define CapSenseProx_PROXIMITY0_PTR2WD_RAM_VALUE            (CapSenseProx_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define CapSenseProx_PROXIMITY0_PTR2WD_RAM_OFFSET           (4u)
#define CapSenseProx_PROXIMITY0_PTR2WD_RAM_SIZE             (4u)
#define CapSenseProx_PROXIMITY0_PTR2WD_RAM_PARAM_ID         (0xD0000004u)

#define CapSenseProx_PROXIMITY0_PTR2SNS_RAM_VALUE           (CapSenseProx_dsFlash.wdgtArray[0].ptr2SnsRam)
#define CapSenseProx_PROXIMITY0_PTR2SNS_RAM_OFFSET          (8u)
#define CapSenseProx_PROXIMITY0_PTR2SNS_RAM_SIZE            (4u)
#define CapSenseProx_PROXIMITY0_PTR2SNS_RAM_PARAM_ID        (0xD3000008u)

#define CapSenseProx_PROXIMITY0_PTR2FLTR_HISTORY_VALUE      (CapSenseProx_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define CapSenseProx_PROXIMITY0_PTR2FLTR_HISTORY_OFFSET     (12u)
#define CapSenseProx_PROXIMITY0_PTR2FLTR_HISTORY_SIZE       (4u)
#define CapSenseProx_PROXIMITY0_PTR2FLTR_HISTORY_PARAM_ID   (0xD200000Cu)

#define CapSenseProx_PROXIMITY0_PTR2DEBOUNCE_VALUE          (CapSenseProx_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define CapSenseProx_PROXIMITY0_PTR2DEBOUNCE_OFFSET         (16u)
#define CapSenseProx_PROXIMITY0_PTR2DEBOUNCE_SIZE           (4u)
#define CapSenseProx_PROXIMITY0_PTR2DEBOUNCE_PARAM_ID       (0xD4000010u)

#define CapSenseProx_PROXIMITY0_STATIC_CONFIG_VALUE         (CapSenseProx_dsFlash.wdgtArray[0].staticConfig)
#define CapSenseProx_PROXIMITY0_STATIC_CONFIG_OFFSET        (20u)
#define CapSenseProx_PROXIMITY0_STATIC_CONFIG_SIZE          (4u)
#define CapSenseProx_PROXIMITY0_STATIC_CONFIG_PARAM_ID      (0xD5000014u)

#define CapSenseProx_PROXIMITY0_TOTAL_NUM_SNS_VALUE         (CapSenseProx_dsFlash.wdgtArray[0].totalNumSns)
#define CapSenseProx_PROXIMITY0_TOTAL_NUM_SNS_OFFSET        (24u)
#define CapSenseProx_PROXIMITY0_TOTAL_NUM_SNS_SIZE          (2u)
#define CapSenseProx_PROXIMITY0_TOTAL_NUM_SNS_PARAM_ID      (0x99000018u)

#define CapSenseProx_PROXIMITY0_TYPE_VALUE                  (CapSenseProx_dsFlash.wdgtArray[0].wdgtType)
#define CapSenseProx_PROXIMITY0_TYPE_OFFSET                 (26u)
#define CapSenseProx_PROXIMITY0_TYPE_SIZE                   (1u)
#define CapSenseProx_PROXIMITY0_TYPE_PARAM_ID               (0x5D00001Au)

#define CapSenseProx_PROXIMITY0_NUM_COLS_VALUE              (CapSenseProx_dsFlash.wdgtArray[0].numCols)
#define CapSenseProx_PROXIMITY0_NUM_COLS_OFFSET             (27u)
#define CapSenseProx_PROXIMITY0_NUM_COLS_SIZE               (1u)
#define CapSenseProx_PROXIMITY0_NUM_COLS_PARAM_ID           (0x5B00001Bu)

#define CapSenseProx_PROXIMITY0_PTR2SNS_CP_VALUE            (CapSenseProx_dsFlash.wdgtArray[0].ptr2SnsCpArr)
#define CapSenseProx_PROXIMITY0_PTR2SNS_CP_OFFSET           (28u)
#define CapSenseProx_PROXIMITY0_PTR2SNS_CP_SIZE             (4u)
#define CapSenseProx_PROXIMITY0_PTR2SNS_CP_PARAM_ID         (0xD700001Cu)


#endif /* End CY_SENSE_CapSenseProx_REGISTER_MAP_H */


/* [] END OF FILE */
