/***************************************************************************//**
* \file CapSenseProx_SelfTest.h
* \version 7.0
*
* \brief
*   This file provides the function prototypes for the Built-In Self-Test
*   library.
*
* \see CapSenseProx v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSenseProx_SELFTEST_H)
#define CY_SENSE_CapSenseProx_SELFTEST_H

#include "cytypes.h"
#include "CapSenseProx_Configuration.h"
#include "CapSenseProx_Structure.h"
#include "CapSenseProx_Sensing.h"

#if (CapSenseProx_ENABLE == CapSenseProx_SELF_TEST_EN)

/*******************************************************************************
* Function Prototypes - High-level API
*******************************************************************************/

/**
* \cond (SECTION_C_HIGH_LEVEL)
* \addtogroup group_c_high_level
* \{
*/

uint32 CapSenseProx_RunSelfTest(uint32 testEnMask);

/** \}
* \endcond */

/*******************************************************************************
* Function Prototypes - Low-level API
*******************************************************************************/

/**
* \cond (SECTION_C_LOW_LEVEL)
* \addtogroup group_c_low_level
* \{
*/

/* CRC test group */
#if (CapSenseProx_ENABLE == CapSenseProx_TST_GLOBAL_CRC_EN)
    uint32 CapSenseProx_CheckGlobalCRC(void);
#endif /*(CapSenseProx_ENABLE == CapSenseProx_TST_GLOBAL_CRC_EN) */
#if (CapSenseProx_ENABLE == CapSenseProx_TST_WDGT_CRC_EN)
    uint32 CapSenseProx_CheckWidgetCRC(uint32 widgetId);
#endif /*(CapSenseProx_ENABLE == CapSenseProx_TST_WDGT_CRC_EN) */

/* Baseline test group */
#if (CapSenseProx_ENABLE == CapSenseProx_TST_BSLN_DUPLICATION_EN)
    uint32 CapSenseProx_CheckBaselineDuplication(uint32 widgetId, uint32 sensorId);
#endif /* (CapSenseProx_ENABLE == CapSenseProx_TST_BSLN_DUPLICATION_EN) */
#if (CapSenseProx_ENABLE == CapSenseProx_TST_BSLN_RAW_OUT_RANGE_EN)
    uint32 CapSenseProx_CheckBaselineRawcountRange(uint32 widgetId, uint32 sensorId,
                                    CapSenseProx_BSLN_RAW_RANGE_STRUCT *ranges);
#endif /* (CapSenseProx_ENABLE == CapSenseProx_TST_BSLN_RAW_OUT_RANGE_EN) */

#if ((CapSenseProx_ENABLE == CapSenseProx_CSD_EN) || (CapSenseProx_ENABLE == CapSenseProx_CSX_EN))
    /* Short test group */
    #if (CapSenseProx_ENABLE == CapSenseProx_TST_SNS_SHORT_EN)
        uint32 CapSenseProx_CheckIntegritySensorPins(uint32 widgetId, uint32 sensorId);
    #endif

    /* Capacitance measurement test group */
    #if (CapSenseProx_ENABLE == CapSenseProx_TST_SNS_CAP_EN)
        uint32 CapSenseProx_GetSensorCapacitance(uint32 widgetId,
                                                     uint32 sensorElement,
                                                     CapSenseProx_TST_MEASUREMENT_STATUS_ENUM * measurementStatusPtr);
    #endif /*(CapSenseProx_ENABLE == CapSenseProx_TST_SNS_CAP_EN) */
    #if (CapSenseProx_ENABLE == CapSenseProx_TST_SH_CAP_EN)
            uint32 CapSenseProx_GetShieldCapacitance(CapSenseProx_TST_MEASUREMENT_STATUS_ENUM * measurementStatusPtr);
    #endif /*(CapSenseProx_ENABLE == CapSenseProx__TST_SH_CAP_EN) */
#endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_EN) || (CapSenseProx_ENABLE == CapSenseProx_CSX_EN)) */

#if (CapSenseProx_ENABLE == CapSenseProx_TST_EXTERNAL_CAP_EN)
    uint32 CapSenseProx_GetExtCapCapacitance(uint32 extCapId);
#endif /*(CapSenseProx_ENABLE == CapSenseProx_TST_EXTERNAL_CAP_EN) */

/* Vdda measurement */
#if ((CapSenseProx_ENABLE == CapSenseProx_TST_VDDA_EN) && (CapSenseProx_ENABLE == CapSenseProx_CSDV2))
    uint16 CapSenseProx_GetVdda(void);
#endif /* ((CapSenseProx_ENABLE == CapSenseProx_TST_VDDA_EN) && (CapSenseProx_ENABLE == CapSenseProx_CSDV2)) */

/** \}
* \endcond */

/*******************************************************************************
* Function Prototypes - Internal Functions
*******************************************************************************/

/**
* \cond SECTION_C_INTERNAL
* \addtogroup group_c_internal
* \{
*/
#if (CapSenseProx_ENABLE == CapSenseProx_TST_GLOBAL_CRC_EN)
    void CapSenseProx_DsUpdateGlobalCrc(void);
#endif /*(CapSenseProx_ENABLE == CapSenseProx_TST_GLOBAL_CRC_EN) */
#if (CapSenseProx_ENABLE == CapSenseProx_TST_WDGT_CRC_EN)
    void CapSenseProx_DsUpdateWidgetCrc(uint32 widgetId);
#endif /*(CapSenseProx_ENABLE == CapSenseProx_TST_WDGT_CRC_EN) */
#if (CapSenseProx_ENABLE == CapSenseProx_TST_BSLN_DUPLICATION_EN)
    void CapSenseProx_UpdateTestResultBaselineDuplication(uint32 widgetId, uint32 sensorId);
#endif /* (CapSenseProx_ENABLE == CapSenseProx_TST_BSLN_DUPLICATION_EN) */

void CapSenseProx_BistInitialize(void);
void CapSenseProx_BistDisableMode(void);

#if ((CapSenseProx_ENABLE == CapSenseProx_TST_SNS_CAP_EN) || \
     (CapSenseProx_ENABLE == CapSenseProx_TST_SH_CAP_EN) || \
     (CapSenseProx_ENABLE == CapSenseProx_TST_EXTERNAL_CAP_EN))
    CY_ISR_PROTO(CapSenseProx_BistPostSingleScan);
#endif

/** \}
* \endcond */


/***********************************************************************************************************************
* Local definition
***********************************************************************************************************************/

/***************************************************************************//**
* \brief Declares the fixed IDAC gain and code values table for Cp measurement
*******************************************************************************/
typedef struct
{
    /**
     *  IDAC gain index for Cp subrange
     */
    uint32 gainIdx;

    /**
     *  IDAC code Cp for subrange
     */
    uint32 code;
} CapSenseProx_TST_CP_CAP_IDAC_TABLE_STRUCT;

#if (CapSenseProx_ENABLE == CapSenseProx_CSDV1)
    #define CapSenseProx_TST_CP_CAP_IDAC_TABLE_INIT     {{0u, 5u},\
                                                             {1u, 10u},\
                                                             {1u, 40u},\
                                                             {1u, 160u}}
#elif (CapSenseProx_ENABLE == CapSenseProx_CSDV2_VER1)
    #define CapSenseProx_TST_CP_CAP_IDAC_TABLE_INIT     {{2u, 20u},\
                                                             {2u, 80u},\
                                                             {4u, 40u},\
                                                             {5u, 80u}}
#else
    #define CapSenseProx_TST_CP_CAP_IDAC_TABLE_INIT     {{2u, 20u},\
                                                             {2u, 80u},\
                                                             {5u, 40u},\
                                                             {6u, 80u}}
#endif

extern CapSenseProx_TST_CP_CAP_IDAC_TABLE_STRUCT const CapSenseProx_BistIdacTable[4u];

/* Defines the mask for baseline data processing failure */
#define CapSenseProx_PROCESS_BASELINE_FAILED                    (0x00000001uL << 31u)

/* Defines constants for Self-Test library */
#define CapSenseProx_TST_LSBYTE                                 (0x000000FFuL)
#define CapSenseProx_TST_FAILED                                 (0x0000FFFFuL)
#define CapSenseProx_TST_BAD_PARAM                              (0x00000001uL << 30u)
#define CapSenseProx_TST_NOT_EXECUTED                           (0x00000001uL << 31u)

/* Defines external capacitor ID */
#define CapSenseProx_TST_CMOD_MAP                               (0u)
#define CapSenseProx_TST_CSH_MAP                                (1u)
#define CapSenseProx_TST_CINTA_MAP                              (2u)
#define CapSenseProx_TST_CINTB_MAP                              (3u)

#define CapSenseProx_BIST_NF_TO_FF_FACTOR                       (1000000uL)
#define CapSenseProx_BIST_PROMILLE_FACTOR                       (1000u)
#define CapSenseProx_BIST_MEGA_2_KILO_FACTOR                    (1000u)

#define CapSenseProx_BIST_SNS_CAP_MAX_CP                        ((0x00000001uL << 8uL) - 1uL)
#define CapSenseProx_BIST_SH_CAP_MAX_CP                         ((0x00000001uL << 16uL) - 1uL)
#define CapSenseProx_BIST_SNS_CAP_UNIT_SCALE                    (1000uL)
#define CapSenseProx_BIST_10_BIT_MASK                           ((0x00000001uL << 10uL) - 1uL)
#define CapSenseProx_BIST_SNS_CAP_MASK                          ((0x00000001uL << CapSenseProx_TST_SNS_CAP_RESOLUTION) - 1uL)
#define CapSenseProx_BIST_10_BIT_RES                            (0x00000001uL << 10uL)
#define CapSenseProx_BIST_CP_CAP_MAX_NUM                        ((0x00000001uL << CapSenseProx_TST_SNS_CAP_RESOLUTION) - 1uL)
#define CapSenseProx_BIST_CP_CAP_MIN_RAW_PROMILLE               (75u)
#define CapSenseProx_BIST_CP_CAP_MAX_RAW_PROMILLE               (450u)
#define CapSenseProx_BIST_CALIBRATION_TARGET                    ((CapSenseProx_BIST_10_BIT_MASK * \
                                                                          CapSenseProx_TST_RAW_TARGET) / \
                                                                          CapSenseProx_PERCENTAGE_100)

#define CapSenseProx_BIST_AVG_CYCLES_PER_LOOP                   (5u)
#define CapSenseProx_BIST_MEASURE_MAX_TIME_US                   (3000u)
#define CapSenseProx_BIST_PRECHARGE_MAX_TIME_US                 (50u)

#define CapSenseProx_BIST_MEASURE_WATCHDOG_CYCLES_NUM           (((CYDEV_BCLK__HFCLK__MHZ) * (CapSenseProx_BIST_MEASURE_MAX_TIME_US)) /\
                                                                    (CapSenseProx_BIST_AVG_CYCLES_PER_LOOP))
#define CapSenseProx_BIST_PRECHARGE_WATCHDOG_CYCLES_NUM         (((CYDEV_BCLK__HFCLK__MHZ) * (CapSenseProx_BIST_PRECHARGE_MAX_TIME_US)) /\
                                                                    (CapSenseProx_BIST_AVG_CYCLES_PER_LOOP))

#if (CapSenseProx_ENABLE == CapSenseProx_CSDV2)
    #define CapSenseProx_TST_EXT_CAP_LOW_RANGE                  (4000uL)
    #define CapSenseProx_TST_EXT_CAP_RESOLUTION                 (0x00000001uL << 10uL)
    #define CapSenseProx_TST_EXT_CAP_DURATION                   (1uL)
    #define CapSenseProx_TST_EXT_CAP_MODCLK_MHZ                 (8uL)
    #define CapSenseProx_SENSE_DUTY_TST_EXT_CAP_WIDTH           (10uL)
    #define CapSenseProx_SEQ_INIT_CNT_FINE_INIT_SKIP            (0x00000000uL)
    #define CapSenseProx_IDAC_BITS_USED                         (7u)
#else /* (CapSenseProx_ENABLE == CapSenseProx_CSDV2) */
    #define CapSenseProx_TST_EXT_CAP_LOW_RANGE                  (4000uL)
    #define CapSenseProx_TST_EXT_CAP_RESOLUTION                 (0xFFuL)
    #define CapSenseProx_TST_EXT_CAP_SNSCLK_DIVIDER             (0xFFuL)
    #define CapSenseProx_TST_EXT_CAP_DURATION                   (CapSenseProx_TST_EXT_CAP_RESOLUTION << \
                                                                     CapSenseProx_RESOLUTION_OFFSET)
    #define CapSenseProx_TST_EXT_CAP_MODCLK_MHZ                 (2uL)
    #define CapSenseProx_IDAC_BITS_USED                         (8u)
    #define CapSenseProx_BIST_MIN_IDAC_VALUE                    (10uL)
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSDV2) */

#define CapSenseProx_BIST_CAL_MIDDLE_BIT                        (1uL << (CapSenseProx_IDAC_BITS_USED - 1u))
#define CapSenseProx_BIST_MAX_IDAC_VALUE                        ((1uL << CapSenseProx_IDAC_BITS_USED) - 1u)
#define CapSenseProx_TST_EXT_CAP_MLTPLR                         (2u)
#define CapSenseProx_CSDCMP_TST_CAP_MEAS                        (0x00000201uL)

#define CapSenseProx_TST_EXT_CAP_MOD_CLK_FREQ_MHZ               (2u)
#define CapSenseProx_TST_EXT_CAP_MEASURE_WND                    (512u)

/***********************************************************************************************************************
* HW CSD Block Config
***********************************************************************************************************************/
#if (CapSenseProx_ENABLE == CapSenseProx_CSDV2)

    #define CapSenseProx_BIST_INTR_SET_CFG                          (0x00000000uL)
    #define CapSenseProx_BIST_SW_FW_TANK_SEL_CFG                    (0x00000000uL)
    #define CapSenseProx_BIST_CAP_SENSE_DUTY_SEL                    (0x00010000uL)
    #define CapSenseProx_BIST_AMBUF_PWR_MODE_OFF                    (CapSenseProx_AMBUF_PWR_MODE_OFF)
    #define CapSenseProx_BIST_AUTO_ZERO_TIME                        (CapSenseProx_CSD_AUTO_ZERO_TIME)

    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_EN)
        #if (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION)
            #define CapSenseProx_BIST_SW_DSI_SEL_CMODPAD                (CapSenseProx_SW_DSI_CMOD)
        #elif (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CMOD_CONNECTION)
            #define CapSenseProx_BIST_SW_DSI_SEL_CMODPAD                (CapSenseProx_SW_DSI_CTANK)
        #else
            #define CapSenseProx_BIST_SW_DSI_SEL_CMODPAD                (0x00000000uL)
        #endif

        #if (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_BIST_SW_DSI_SEL_TANKPAD                (CapSenseProx_SW_DSI_CTANK)
        #elif (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_BIST_SW_DSI_SEL_TANKPAD                (CapSenseProx_SW_DSI_CMOD)
        #else
            #define CapSenseProx_BIST_SW_DSI_SEL_TANKPAD                (0x00000000uL)
        #endif
    #else
        #define CapSenseProx_BIST_SW_DSI_SEL_CMODPAD                (CapSenseProx_SW_DSI_CMOD)
        #define CapSenseProx_BIST_SW_DSI_SEL_TANKPAD                (CapSenseProx_SW_DSI_CTANK)
    #endif

    #define CapSenseProx_BIST_DEFAULT_SW_DSI_SEL                    (CapSenseProx_BIST_SW_DSI_SEL_CMODPAD | \
                                                                         CapSenseProx_BIST_SW_DSI_SEL_TANKPAD)
    #define CapSenseProx_BIST_ADC_CTL_CFG                           (0x00000000uL)
    /* Shield switch default config */
    #define CapSenseProx_BIST_SW_SHIELD_SEL_INIT                 (CapSenseProx_SW_SHIELD_SEL_SW_HCAV_HSCMP)
    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
         (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN))
        #if (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG)
            #define CapSenseProx_BIST_SW_SHIELD_SEL_CFG          (CapSenseProx_SW_SHIELD_SEL_SW_HCBG_HSCMP)
        #else
            #define CapSenseProx_BIST_SW_SHIELD_SEL_CFG          (CapSenseProx_SW_SHIELD_SEL_SW_HCBV_HSCMP)
        #endif /* (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG) */
    #elif(CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)
        #if (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG)
            #define CapSenseProx_BIST_SW_SHIELD_SEL_CFG          (CapSenseProx_SW_SHIELD_SEL_SW_HCBV_PHI1 | \
                                                                      CapSenseProx_SW_SHIELD_SEL_SW_HCBG_PHI2_HSCMP)
        #else
            #define CapSenseProx_BIST_SW_SHIELD_SEL_CFG          (CapSenseProx_SW_SHIELD_SEL_SW_HCBG_PHI1 | \
                                                                      CapSenseProx_SW_SHIELD_SEL_SW_HCBV_PHI2_HSCMP)
        #endif /* (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG) */
    #else
        #define CapSenseProx_BIST_SW_SHIELD_SEL_CFG              (0x00000000uL)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
               (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN)) */

    /* SW_HS_P_SEL switches state for Coarse initialization of CMOD (sense path) */
    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_EN)
        #if (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION)
            #define CapSenseProx_BIST_HS_P_SEL_COARSE_CMOD               (CapSenseProx_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CSHIELD_PAD == CapSenseProx_CMOD_CONNECTION)
            #define CapSenseProx_BIST_HS_P_SEL_COARSE_CMOD               (CapSenseProx_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #else
            #define CapSenseProx_BIST_HS_P_SEL_COARSE_CMOD               (CapSenseProx_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #endif /* (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION) */
    #else
        #define CapSenseProx_BIST_HS_P_SEL_COARSE_CMOD                   (CapSenseProx_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_CSX_EN) && (CapSenseProx_ENABLE == CapSenseProx_CSD_EN)) */

    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
        (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_BIST_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
            #define CapSenseProx_BIST_HS_P_SEL_SCAN_TANK                (CapSenseProx_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CSHIELD_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_BIST_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
            #define CapSenseProx_BIST_HS_P_SEL_SCAN_TANK                (CapSenseProx_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_BIST_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
            #define CapSenseProx_BIST_HS_P_SEL_SCAN_TANK                (CapSenseProx_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CapSenseProx_BIST_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMMA_STATIC_CLOSE)
            #define CapSenseProx_BIST_HS_P_SEL_SCAN_TANK                (CapSenseProx_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
        #endif /* (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION) */
    #else
        #define CapSenseProx_BIST_HS_P_SEL_COARSE_TANK                   (CapSenseProx_STATIC_OPEN)
        #define CapSenseProx_BIST_HS_P_SEL_SCAN_TANK                     (CapSenseProx_STATIC_OPEN)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
               (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)) */

    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
        (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN))
        #define CapSenseProx_BIST_HS_P_SEL_SCAN                       (CapSenseProx_BIST_HS_P_SEL_SCAN_TANK)
    #elif(CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)
        #define CapSenseProx_BIST_HS_P_SEL_SCAN                       (CapSenseProx_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
    #else
        #define CapSenseProx_BIST_HS_P_SEL_SCAN                       (CapSenseProx_STATIC_OPEN)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
               (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)) */

    #define CapSenseProx_BIST_SW_HS_P_SEL_COARSE                    (CapSenseProx_BIST_HS_P_SEL_COARSE_CMOD | CapSenseProx_BIST_HS_P_SEL_COARSE_TANK)
    #define CapSenseProx_BIST_SW_HS_P_SEL_CFG                       (0x00000000uL)
    #define CapSenseProx_BIST_SW_HS_N_SEL_CFG                       (0x00000000uL)

    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_AUTO_ZERO_EN)
        #define CapSenseProx_BIST_AZ_ENABLE_CFG                  (CapSenseProx_CSD_AZ_EN_MASK)
    #else
        #define CapSenseProx_BIST_AZ_ENABLE_CFG                  (0uL)
    #endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_AUTO_ZERO_EN) */

    #define CapSenseProx_BIST_HSCMP_CFG                             (CapSenseProx_HSCMP_EN_MASK | CapSenseProx_BIST_AZ_ENABLE_CFG)
    #define CapSenseProx_BIST_CSDCMP_INIT                           (CapSenseProx_CSDCMP_CSDCMP_DISABLED)

    #define CapSenseProx_BIST_BLOCK_ON_DELAY                        (3uL * CYDEV_BCLK__HFCLK__MHZ)
    #define CapSenseProx_BIST_HSCMP_ON_DELAY                        (1uL * CYDEV_BCLK__HFCLK__MHZ)

    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_EN)
        #if (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION)
            #define CapSenseProx_BIST_SW_FW_MOD_SEL_INIT    (CapSenseProx_SW_FW_MOD_SEL_SW_F1PM_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_MOD_SEL_SW_F1MA_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_MOD_SEL_SW_F1CA_STATIC_CLOSE)
        #else
            #define CapSenseProx_BIST_SW_FW_MOD_SEL_INIT    (0x00000000uL)
        #endif /* (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION) */

        #if (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_BIST_SW_FW_TANK_SEL_INIT   (CapSenseProx_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_TANK_SEL_SW_F2MA_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_TANK_SEL_SW_F2CA_STATIC_CLOSE)
        #else
            #define CapSenseProx_BIST_SW_FW_TANK_SEL_INIT   (0x00000000uL)
        #endif /* (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION) */

    #elif (CapSenseProx_ENABLE == CapSenseProx_CSX_EN)
        #define CapSenseProx_BIST_SW_FW_MOD_SEL_INIT        (CapSenseProx_SW_FW_MOD_SEL_SW_F1PM_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_MOD_SEL_SW_F1MA_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_MOD_SEL_SW_F1CA_STATIC_CLOSE)

        #define CapSenseProx_BIST_SW_FW_TANK_SEL_INIT       (CapSenseProx_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_TANK_SEL_SW_F2MA_STATIC_CLOSE |\
                                                                 CapSenseProx_SW_FW_TANK_SEL_SW_F2CA_STATIC_CLOSE)
    #else
        #define CapSenseProx_BIST_SW_FW_MOD_SEL_INIT        (0x00000000uL)
        #define CapSenseProx_BIST_SW_FW_TANK_SEL_INIT       (0x00000000uL)
    #endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_EN) */


    #define CapSenseProx_BIST_SW_RES_INIT                           (CapSenseProx_CSD_INIT_SWITCH_RES << CYFLD_CSD_RES_HCAV__OFFSET)
    #define CapSenseProx_BIST_SW_FW_MOD_SEL_SCAN                    (0x00000000uL)
    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
         (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
         (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION))
        #define CapSenseProx_BIST_SW_FW_TANK_SEL_SCAN               (CapSenseProx_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                         CapSenseProx_SW_FW_TANK_SEL_SW_F2CB_PHI2)
    #else
        #define CapSenseProx_BIST_SW_FW_TANK_SEL_SCAN               (0x00000000uL)
    #endif

    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
         (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
         (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION))
        #define CapSenseProx_BIST_SW_SHIELD_SEL                     (CapSenseProx_SW_SHIELD_SEL_SW_HCBV_HSCMP)
    #elif((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
          (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN))
        #define CapSenseProx_BIST_SW_SHIELD_SEL                     (CapSenseProx_SW_SHIELD_SEL_SW_HCBV_HSCMP)
    #elif(CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)
        #define CapSenseProx_BIST_SW_SHIELD_SEL                     (CapSenseProx_SW_SHIELD_SEL_SW_HCBG_PHI1 | \
                                                                         CapSenseProx_SW_SHIELD_SEL_SW_HCBV_PHI2_HSCMP)
    #else
        #define CapSenseProx_BIST_SW_SHIELD_SEL                     (0x00000000uL)
    #endif
    #define CapSenseProx_BIST_SW_RES_SCAN                           ((CapSenseProx_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBV__OFFSET) |\
                                                                         (CapSenseProx_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBG__OFFSET))
    #define CapSenseProx_BIST_HSCMP_SCAN_MASK                       (CapSenseProx_HSCMP_EN_MASK)
    #define CapSenseProx_BIST_IDACB_CFG                             (0x00000000uL)
    #define CapSenseProx_BIST_IDACA_CFG                             (0x01830000uL)
    #define CapSenseProx_BIST_IDACA_MODE                            (0x000F0000uL)

    /* IDAC Gain in nA */
    #define CapSenseProx_TST_SNS_CAP_IDAC_GAIN                      (2400uL)

    #if ((CYDEV_BCLK__HFCLK__HZ / CapSenseProx_TST_MOD_CLK_DIVIDER) <= CapSenseProx_MOD_CSD_CLK_12MHZ)
        #define CapSenseProx_FILTER_DELAY_CFG                       (CapSenseProx_CONFIG_FILTER_DELAY_12MHZ)
    #elif ((CYDEV_BCLK__HFCLK__HZ / CapSenseProx_TST_MOD_CLK_DIVIDER) <= CapSenseProx_MOD_CSD_CLK_24MHZ)
        #define CapSenseProx_FILTER_DELAY_CFG                       (CapSenseProx_CONFIG_FILTER_DELAY_24MHZ)
    #else
        /* ((CYDEV_BCLK__HFCLK__HZ / CapSenseProx_TST_MOD_CLK_DIVIDER) <= CapSenseProx_MOD_CSD_CLK_48MHZ) */
        #define CapSenseProx_FILTER_DELAY_CFG                       (CapSenseProx_CONFIG_FILTER_DELAY_48MHZ)
    #endif

    #define CapSenseProx_BIST_CSD_CONFIG                            (CapSenseProx_CONFIG_FILTER_DELAY_2_CYCLES)
    #define CapSenseProx_BIST_SW_REFGEN_SEL_CFG                     (CapSenseProx_SW_REFGEN_SEL_SW_SGR_MASK)

    #define CapSenseProx_TST_MEASMODE_VREF                              (0x1uL << CYFLD_CSD_ADC_MODE__OFFSET)
    #define CapSenseProx_TST_MEASMODE_VREFBY2                           (0x2uL << CYFLD_CSD_ADC_MODE__OFFSET)
    #define CapSenseProx_TST_MEASMODE_VIN                               (0x3uL << CYFLD_CSD_ADC_MODE__OFFSET)

    /* Clock defines */
    #define CapSenseProx_TST_VDDA_SENSE_DIV_DEFAULT                     (0x4uL)
    /* Acquisition time definitions: ADC_CTL */
    #define CapSenseProx_VDDA_ACQUISITION_TIME_US                       (10uL)
    #define CapSenseProx_TST_VDDA_ADC_AZ_TIME                           (5uL)

    #define CapSenseProx_TST_VDDA_FILTER_DELAY                          (2uL)
    #define CapSenseProx_TST_VDDA_FINE_INIT_TIME                        (CapSenseProx_TST_FINE_INIT_TIME)
    #define CapSenseProx_TST_VDDA_SCAN_DURATION                         (2uL)

    #define CapSenseProx_TST_VDDA_VREF_TRIM_MAX_DEVIATION               (20uL)

    /* The reference voltage macros */
    #define CapSenseProx_TST_VDDA_VREF_CALIB_USED                       (2400uL)

    #define CapSenseProx_TST_VDDA_BAD_RESULT                            (0xFFFFu)


    #define CapSenseProx_TST_VDDA_CONFIG_DEFAULT_CFG                    (CapSenseProx_CONFIG_ENABLE_MASK |\
                                                                             CapSenseProx_CONFIG_SAMPLE_SYNC_MASK |\
                                                                             CapSenseProx_CONFIG_SENSE_EN_MASK |\
                                                                             CapSenseProx_CONFIG_DSI_COUNT_SEL_MASK)

    #define CapSenseProx_TST_VDDA_IDACA_DEFAULT_CFG                     (0x00000000uL)
    #define CapSenseProx_TST_VDDA_IDACB_DEFAULT_CFG                     (CapSenseProx_TST_VDDA_IDAC_DEFAULT |\
                                                                            (CapSenseProx_IDAC_COMP_POL_DYN_DYNAMIC << \
                                                                              CYFLD_CSD_POL_DYN__OFFSET) |\
                                                                              CapSenseProx_IDAC_COMP_LEG3_EN_MASK)

    #define CapSenseProx_TST_CSDCMP_DEFAULT_CFG                         (0x00000000uL)
    #define CapSenseProx_TST_SW_DSI_SEL_DEFAULT_CFG                     (0x00000000uL)
    #define CapSenseProx_TST_SENSE_DUTY_VDDA_CFG                        (0x00000000uL)
    #define CapSenseProx_TST_SEQ_INIT_CNT_DEFAULT_CFG                   (1u)
    #define CapSenseProx_TST_SEQ_NORM_CNT_DEFAULT_CFG                   (CapSenseProx_TST_VDDA_SCAN_DURATION)
    #define CapSenseProx_TST_SW_HS_P_SEL_DEFAULT_CFG                    (CapSenseProx_SW_HS_P_SEL_SW_HMRH_STATIC_CLOSE)
    #define CapSenseProx_TST_SW_HS_N_SEL_DEFAULT_CFG                    (CapSenseProx_SW_HS_N_SEL_SW_HCCD_STATIC_CLOSE)
    #define CapSenseProx_TST_SW_SHIELD_SEL_DEFAULT_CFG                  (0x00000000uL)
    #define CapSenseProx_TST_SW_BYP_SEL_DEFAULT_CFG                     (CapSenseProx_SW_BYP_SEL_SW_BYA_MASK |\
                                                                             CapSenseProx_SW_BYP_SEL_SW_BYB_MASK)
    #define CapSenseProx_TST_SW_CMP_P_SEL_DEFAULT_CFG                   (0x00000000uL)
    #define CapSenseProx_TST_SW_CMP_N_SEL_DEFAULT_CFG                   (0x00000000uL)
    #define CapSenseProx_TST_SW_FW_MOD_SEL_DEFAULT_CFG                  (CapSenseProx_SW_FW_MOD_SEL_SW_C1CC_STATIC_CLOSE |\
                                                                             CapSenseProx_SW_FW_MOD_SEL_SW_C1CD_STATIC_CLOSE)
    #define CapSenseProx_TST_SW_FW_TANK_SEL_DEFAULT_CFG                 (CapSenseProx_SW_FW_TANK_SEL_SW_C2CC_STATIC_CLOSE |\
                                                                             CapSenseProx_SW_FW_TANK_SEL_SW_C2CD_STATIC_CLOSE)
    #define CapSenseProx_TST_SW_REFGEN_SEL_DEFAULT_CFG                  (CapSenseProx_SW_REFGEN_SEL_SW_SGR_MASK)

    #define CapSenseProx_TST_REFGEN_LV                                  (CapSenseProx_REFGEN_REFGEN_EN_MASK |\
                                                                             CapSenseProx_REFGEN_BYPASS_MASK)

    #define CapSenseProx_TST_REFGEN_HV                                  (CapSenseProx_REFGEN_REFGEN_EN_MASK |\
                                                                             CapSenseProx_REFGEN_RES_EN_MASK)

    #define CapSenseProx_TST_SW_AMUXBUF_SEL_DEFAULT_CFG                 (0x00000000uL)
    #define CapSenseProx_TST_HSCMP_DEFAULT_CFG                          (CapSenseProx_HSCMP_EN_MASK |\
                                                                             CapSenseProx_CSD_AZ_EN_MASK)

    #define CapSenseProx_TST_VDDA_SEQ_START_MEASURE_CFG                 (CapSenseProx_SEQ_START_AZ0_SKIP_MASK |\
                                                                            CapSenseProx_SEQ_START_START_MASK)
#else /* (CapSenseProx_ENABLE == CapSenseProx_CSDV2) */

#define CapSenseProx_BIST_CSD_CONFIG                            (CapSenseProx_CONFIG_SENSE_COMP_BW_MASK | \
                                                                     CapSenseProx_CONFIG_SENSE_INSEL_MASK | \
                                                                     CapSenseProx_CONFIG_REFBUF_DRV_MASK)

#define CapSenseProx_BIST_CMOD_PRECHARGE_CONFIG                 (CapSenseProx_BIST_CSD_CONFIG | \
                                                                     CapSenseProx_CONFIG_REFBUF_EN_MASK | \
                                                                     CapSenseProx_CONFIG_COMP_PIN_MASK)

#define CapSenseProx_BIST_CMOD_PRECHARGE_CONFIG_CSD_EN          (CapSenseProx_BIST_CMOD_PRECHARGE_CONFIG | \
                                                                     CapSenseProx_CSD_ENABLE_MASK)

/* Third-generation HW block Ctank pre-charge mode configuration */
#if (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)
    #if((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) &&\
        (CapSenseProx_CSH_PRECHARGE_IO_BUF == CapSenseProx_CSD_CSH_PRECHARGE_SRC))
        #define  CapSenseProx_BIST_CTANK_PRECHARGE_CONFIG       (CapSenseProx_BIST_CSD_CONFIG |\
                                                                    CapSenseProx_CONFIG_REFBUF_OUTSEL_MASK |\
                                                                    CapSenseProx_CONFIG_REFBUF_EN_MASK |\
                                                                    CapSenseProx_CONFIG_COMP_MODE_MASK |\
                                                                    CapSenseProx_CONFIG_PRS_CLEAR_MASK |\
                                                                    CapSenseProx_CONFIG_COMP_PIN_MASK)
    #else
        #define  CapSenseProx_BIST_CTANK_PRECHARGE_CONFIG       (CapSenseProx_BIST_CSD_CONFIG |\
                                                                    CapSenseProx_CONFIG_REFBUF_EN_MASK |\
                                                                    CapSenseProx_CONFIG_PRS_CLEAR_MASK |\
                                                                    CapSenseProx_CONFIG_REFBUF_OUTSEL_MASK)
    #endif
#else
    #define  CapSenseProx_BIST_CTANK_PRECHARGE_CONFIG           (CapSenseProx_BIST_CSD_CONFIG |\
                                                                    CapSenseProx_CONFIG_REFBUF_OUTSEL_MASK |\
                                                                    CapSenseProx_CONFIG_PRS_CLEAR_MASK)
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) */


#define  CapSenseProx_BIST_CTANK_PRECHARGE_CONFIG_CSD_EN        (CapSenseProx_BIST_CTANK_PRECHARGE_CONFIG | \
                                                                     CapSenseProx_CONFIG_ENABLE_MASK | \
                                                                     CapSenseProx_CONFIG_SENSE_COMP_EN_MASK)

#define CapSenseProx_BIST_IDAC_CFG                              (0x00000200uL)
#define CapSenseProx_BIST_IDAC_MOD_MASK                         (0x000017FFuL)
#define CapSenseProx_BIST_IDAC_MOD_VAL_MASK                     (0x000000FFuL)

/* IDAC Gain = 8x that corresponds to 1LSB = 1200 nA */
#define CapSenseProx_TST_SNS_CAP_IDAC_GAIN                      (1200uL)

#define CapSenseProx_BIST_SCAN_DURATION                         (CapSenseProx_BIST_SNS_CAP_MASK << CapSenseProx_RESOLUTION_OFFSET)
#define CapSenseProx_BIST_SCAN_DURATION_255                     (0x1FFuL << CapSenseProx_RESOLUTION_OFFSET)
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSDV2) */

#endif /* #if (CapSenseProx_ENABLE == CapSenseProx_SELF_TEST_EN) */

#endif /* End CY_SENSE_CapSenseProx_SELFTEST_H */


/* [] END OF FILE */
