/***************************************************************************//**
* \file CapSenseProx_SensingCSD_LL.h
* \version 7.0
*
* \brief
*   This file provides the headers of APIs specific to CSD sensing implementation.
*
* \see CapSenseProx v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSenseProx_SENSINGCSD_LL_H)
#define CY_SENSE_CapSenseProx_SENSINGCSD_LL_H

#include <CyLib.h>
#include <cyfitter.h>
#include <cytypes.h>
#include <cypins.h>
#include "CapSenseProx_Structure.h"
#include "CapSenseProx_Configuration.h"
#include "CapSenseProx_Sensing.h"

/****************************************************************************
* Register and mode mask definition
****************************************************************************/

#if (CapSenseProx_ENABLE == CapSenseProx_CSDV2)
    #define CapSenseProx_CSD_CSDCMP_INIT                                (CapSenseProx_CSDCMP_CSDCMP_DISABLED)

    /* SW_HS_P_SEL switches state for Coarse initialization of CMOD (sense path) */
    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_EN)
        #if (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_COARSE_CMOD               (CapSenseProx_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CSHIELD_PAD == CapSenseProx_CMOD_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_COARSE_CMOD               (CapSenseProx_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #else
            #define CapSenseProx_CSD_HS_P_SEL_COARSE_CMOD               (CapSenseProx_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #endif /* (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION) */
    #else
        #define CapSenseProx_CSD_HS_P_SEL_COARSE_CMOD                   (0x00000000uL)
    #endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_EN) */

    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
        (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CSHIELD_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CapSenseProx_CSD_HS_P_SEL_COARSE_TANK               (CapSenseProx_SW_HS_P_SEL_SW_HMMA_STATIC_CLOSE)
        #endif /* (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION) */
    #else
        #define CapSenseProx_CSD_HS_P_SEL_COARSE_TANK                   (0x00000000uL)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
               (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)) */

    #define CapSenseProx_CSD_SW_HS_P_SEL_COARSE                         (CapSenseProx_HS_P_SEL_COARSE_CMOD | CapSenseProx_CSD_HS_P_SEL_COARSE_TANK)

    /* C_mod config */
    #if ((CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION) || (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CTANK_CONNECTION))
        #define CapSenseProx_CSD_SW_FW_MOD_SEL_INIT             (CapSenseProx_SW_FW_MOD_SEL_SW_F1PM_STATIC_CLOSE |\
                                                                     CapSenseProx_SW_FW_MOD_SEL_SW_F1MA_STATIC_CLOSE |\
                                                                     CapSenseProx_SW_FW_MOD_SEL_SW_F1CA_STATIC_CLOSE)
        #define CapSenseProx_SW_DSI_SEL_CMODPAD                 (CapSenseProx_SW_DSI_CMOD)
    #else
        #define CapSenseProx_CSD_SW_FW_MOD_SEL_INIT             (0x00000000uL)
        #define CapSenseProx_SW_DSI_SEL_CMODPAD                 (0x00000000uL)
    #endif /* (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CMOD_CONNECTION) */

    /* C_tank config */
    #if ((CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CMOD_CONNECTION) || (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION))
        #define CapSenseProx_CSD_SW_FW_TANK_SEL_INIT            (CapSenseProx_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                     CapSenseProx_SW_FW_TANK_SEL_SW_F2MA_STATIC_CLOSE |\
                                                                     CapSenseProx_SW_FW_TANK_SEL_SW_F2CA_STATIC_CLOSE)
        #define CapSenseProx_SW_DSI_SEL_TANKPAD                 (CapSenseProx_SW_DSI_CTANK)
    #else
        #define CapSenseProx_CSD_SW_FW_TANK_SEL_INIT            (0x00000000uL)
        #define CapSenseProx_SW_DSI_SEL_TANKPAD                 (0x00000000uL)
    #endif /* (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION) */

    #define CapSenseProx_CSD_SW_SHIELD_SEL_INIT                 (CapSenseProx_SW_SHIELD_SEL_SW_HCAV_HSCMP)

    /* Defining default HW configuration according to settings in customizer. */
    #define CapSenseProx_DEFAULT_CSD_CONFIG                 (CapSenseProx_CONFIG_FILTER_DELAY_12MHZ |\
                                                                 CapSenseProx_CONFIG_SAMPLE_SYNC_MASK)
    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_AUTO_ZERO_EN)
        /* Enable CSDCMP */
        #define CapSenseProx_CSD_CSDCMP_SCAN                (CapSenseProx_CSDCMP_CSDCMP_EN_MASK |\
                                                                 CapSenseProx_CSDCMP_AZ_EN_MASK)
    #else
        /* Enable CSDCMP */
        #define CapSenseProx_CSD_CSDCMP_SCAN                (CapSenseProx_CSDCMP_CSDCMP_EN_MASK)
    #endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_AUTO_ZERO_EN) */

    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
        (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseProx_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CSHIELD_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseProx_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CapSenseProx_CSD__CMOD_PAD == CapSenseProx_CTANK_CONNECTION)
            #define CapSenseProx_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseProx_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CapSenseProx_CSD_HS_P_SEL_SCAN_TANK                 (CapSenseProx_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
        #endif /* (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION) */
        #define CapSenseProx_CSD_SW_HS_P_SEL_SCAN                       (CapSenseProx_HS_P_SEL_SCAN_TANK)
    #elif(CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)
        #define CapSenseProx_CSD_SW_HS_P_SEL_SCAN                       (CapSenseProx_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
    #else
        #define CapSenseProx_CSD_SW_HS_P_SEL_SCAN                       (CapSenseProx_STATIC_OPEN)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
               (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)) */

    /* SW_FW_MOD_SEL switches state for Coarse initialization of CMOD (sense path) */
    #define CapSenseProx_CSD_SW_FW_MOD_SEL_SCAN                     (0x00000000uL)

    #if((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
        (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
        (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION))
        #define CapSenseProx_CSD_SW_FW_TANK_SEL_SCAN                (CapSenseProx_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE | \
                                                                         CapSenseProx_SW_FW_TANK_SEL_SW_F2CB_STATIC_CLOSE)
    #else
        #define CapSenseProx_CSD_SW_FW_TANK_SEL_SCAN                (0x00000000uL)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
               (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) && \
               (CapSenseProx_CSD__CSH_TANK_PAD == CapSenseProx_CTANK_CONNECTION)) */

    /* Shield switch default config */
    #if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
         (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN))
        #if (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG)
            #define CapSenseProx_CSD_SW_SHIELD_SEL_SCAN             (CapSenseProx_SW_SHIELD_SEL_SW_HCBG_HSCMP)
        #else
            #define CapSenseProx_CSD_SW_SHIELD_SEL_SCAN             (CapSenseProx_SW_SHIELD_SEL_SW_HCBV_HSCMP)
        #endif /* (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG) */
    #elif(CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)
        #if (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG)
            #define CapSenseProx_CSD_SW_SHIELD_SEL_SCAN             (CapSenseProx_SW_SHIELD_SEL_SW_HCBV_PHI1 | \
                                                                         CapSenseProx_SW_SHIELD_SEL_SW_HCBG_PHI2_HSCMP)
        #else
            #define CapSenseProx_CSD_SW_SHIELD_SEL_SCAN             (CapSenseProx_SW_SHIELD_SEL_SW_HCBG_PHI1 | \
                                                                         CapSenseProx_SW_SHIELD_SEL_SW_HCBV_PHI2_HSCMP)
        #endif /* (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG) */
    #else
        #define CapSenseProx_CSD_SW_SHIELD_SEL_SCAN                 (0x00000000uL)
    #endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
               (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN)) */

    #define CapSenseProx_CSD_SW_RES_INIT                            (CapSenseProx_CSD_INIT_SWITCH_RES << CYFLD_CSD_RES_HCAV__OFFSET)
    #define CapSenseProx_CSD_SW_RES_SCAN                            ((CapSenseProx_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBV__OFFSET) |\
                                                                         (CapSenseProx_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBG__OFFSET))

    #define CapSenseProx_CSD_SHIELD_GPIO_DM                         (CapSenseProx_GPIO_STRGDRV)
    #define CapSenseProx_CSD_SENSOR_HSIOM_SEL                       (CapSenseProx_HSIOM_SEL_CSD_SENSE)
    #define CapSenseProx_CSD_SHIELD_HSIOM_SEL                       (CapSenseProx_HSIOM_SEL_CSD_SHIELD)
    #define CapSenseProx_CSD_CMOD_HSIOM_SEL                         (CapSenseProx_HSIOM_SEL_AMUXA)

    #define CapSenseProx_DEFAULT_IDAC_MOD_BALL_MODE                 ((uint32)CapSenseProx_IDAC_MOD_BALL_MODE_FULL <<\
                                                                         CYFLD_CSD_BAL_MODE__OFFSET)
    #define CapSenseProx_DEFAULT_IDAC_COMP_BALL_MODE                ((uint32)CapSenseProx_IDAC_COMP_BALL_MODE_FULL <<\
                                                                         CYFLD_CSD_BAL_MODE__OFFSET)

    #define CapSenseProx_DEFAULT_SENSE_DUTY_SEL                     (CapSenseProx_SENSE_DUTY_OVERLAP_PHI1_MASK |\
                                                                         CapSenseProx_SENSE_DUTY_OVERLAP_PHI2_MASK)

    #define CapSenseProx_CSD_CAL_MIDDLE_VALUE                       (0x40u)
    #define CapSenseProx_CSD_CAL_IDAC_MAX_VALUE                     (127u)

    #define CapSenseProx_DELAY_EXTRACYCLES_NUM                      (9u)

    /* Clock Source Mode */
    #if (CapSenseProx_CLK_SOURCE_DIRECT == CapSenseProx_CSD_SNS_CLK_SOURCE)
        #define CapSenseProx_DEFAULT_MODULATION_MODE                (CapSenseProx_CLK_SOURCE_DIRECT)
    #elif (CapSenseProx_CLK_SOURCE_PRSAUTO == CapSenseProx_CSD_SNS_CLK_SOURCE)
        #define CapSenseProx_DEFAULT_MODULATION_MODE                (CapSenseProx_CLK_SOURCE_SSC2)
    #elif ((CapSenseProx_CLK_SOURCE_PRS8) == CapSenseProx_CSD_SNS_CLK_SOURCE)
        #define CapSenseProx_DEFAULT_MODULATION_MODE                (CapSenseProx_CSD_SNS_CLK_SOURCE)
    #elif ((CapSenseProx_CLK_SOURCE_PRS12) == CapSenseProx_CSD_SNS_CLK_SOURCE)
        #define CapSenseProx_DEFAULT_MODULATION_MODE                (CapSenseProx_CSD_SNS_CLK_SOURCE)
    #else
        #define CapSenseProx_DEFAULT_MODULATION_MODE                (CapSenseProx_CSD_SNS_CLK_SOURCE)
    #endif /* (CapSenseProx_CLK_SOURCE_DIRECT != CapSenseProx_CSD_SNS_CLK_SOURCE) */

    /* IDACs Ranges */
    #if (CapSenseProx_IDAC_GAIN_LOW == CapSenseProx_CSD_IDAC_GAIN)
        #define CapSenseProx_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSenseProx_IDAC_MOD_RANGE_IDAC_LO << CYFLD_CSD_RANGE__OFFSET)
        #define CapSenseProx_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSenseProx_IDAC_COMP_RANGE_IDAC_LO << CYFLD_CSD_RANGE__OFFSET)
    #elif (CapSenseProx_IDAC_GAIN_MEDIUM == CapSenseProx_CSD_IDAC_GAIN)
        #define CapSenseProx_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSenseProx_IDAC_MOD_RANGE_IDAC_MED << CYFLD_CSD_RANGE__OFFSET)
        #define CapSenseProx_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSenseProx_IDAC_COMP_RANGE_IDAC_MED << CYFLD_CSD_RANGE__OFFSET)
    #else
        #define CapSenseProx_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSenseProx_IDAC_MOD_RANGE_IDAC_HI << CYFLD_CSD_RANGE__OFFSET)
        #define CapSenseProx_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSenseProx_IDAC_COMP_RANGE_IDAC_HI << CYFLD_CSD_RANGE__OFFSET)
    #endif

    /* IDACs Polarities */
    #if (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG)
        #define CapSenseProx_DEFAULT_IDAC_MOD_POLARITY              ((uint32)CapSenseProx_IDAC_MOD_POLARITY_VDDA_SNK << CYFLD_CSD_POLARITY__OFFSET)
        #define CapSenseProx_DEFAULT_IDAC_COMP_POLARITY             ((uint32)CapSenseProx_IDAC_COMP_POLARITY_VDDA_SNK << CYFLD_CSD_POLARITY__OFFSET)
    #else
        #define CapSenseProx_DEFAULT_IDAC_MOD_POLARITY              ((uint32)CapSenseProx_IDAC_MOD_POLARITY_VSSA_SRC << CYFLD_CSD_POLARITY__OFFSET)
        #define CapSenseProx_DEFAULT_IDAC_COMP_POLARITY             ((uint32)CapSenseProx_IDAC_COMP_POLARITY_VSSA_SRC << CYFLD_CSD_POLARITY__OFFSET)
    #endif /* (CapSenseProx_IDAC_SINKING == CapSenseProx_CSD_IDAC_CONFIG) */

    #define CapSenseProx_SW_REFGEN_VREF_SRC                         (CapSenseProx_SW_REFGEN_SEL_SW_SGR_MASK)

    /* IDAC legs configuration */
    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_IDAC_COMP_EN)
            #define CapSenseProx_DEFAULT_SW_REFGEN_SEL              (CapSenseProx_SW_REFGEN_VREF_SRC | CapSenseProx_SW_REFGEN_SEL_SW_IAIB_MASK)
    #else
            #define CapSenseProx_DEFAULT_SW_REFGEN_SEL              (CapSenseProx_SW_REFGEN_VREF_SRC)
    #endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_IDAC_COMP_EN) */

    /* IDACs register configuration is based on the Component configuration */
    #define CapSenseProx_IDAC_MOD_DEFAULT_CFG                       (CapSenseProx_DEFAULT_IDAC_MOD_RANGE | \
                                                                         CapSenseProx_DEFAULT_IDAC_MOD_POLARITY | \
                                                                         CapSenseProx_DEFAULT_IDAC_MOD_BALL_MODE | \
                                                                        ((uint32)(CapSenseProx_IDAC_MOD_LEG1_MODE_CSD << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)(CapSenseProx_IDAC_MOD_LEG2_MODE_CSD << CYFLD_CSD_LEG2_MODE__OFFSET)) | \
                                                                         CapSenseProx_IDAC_MOD_LEG1_EN_MASK)

    #define CapSenseProx_IDAC_COMP_DEFAULT_CFG                      (CapSenseProx_DEFAULT_IDAC_COMP_RANGE | \
                                                                         CapSenseProx_DEFAULT_IDAC_COMP_POLARITY | \
                                                                         CapSenseProx_DEFAULT_IDAC_COMP_BALL_MODE | \
                                                                        ((uint32)(CapSenseProx_IDAC_COMP_LEG1_MODE_CSD_STATIC << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)(CapSenseProx_IDAC_COMP_LEG2_MODE_CSD_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET)) | \
                                                                         CapSenseProx_IDAC_COMP_LEG1_EN_MASK)

    #define CapSenseProx_IDAC_MOD_CALIBRATION_CFG                   ((uint32)(CapSenseProx_DEFAULT_IDAC_MOD_RANGE | \
                                                                         CapSenseProx_DEFAULT_IDAC_MOD_POLARITY | \
                                                                         CapSenseProx_DEFAULT_IDAC_MOD_BALL_MODE | \
                                                                        ((uint32)(CapSenseProx_IDAC_MOD_LEG1_MODE_CSD << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                         CapSenseProx_IDAC_MOD_LEG1_EN_MASK | \
                                                                        ((uint32)((uint32)CapSenseProx_IDAC_MOD_LEG2_MODE_GP_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET))))

    #define CapSenseProx_IDAC_COMP_CALIBRATION_CFG                  ((uint32)(CapSenseProx_DEFAULT_IDAC_COMP_RANGE | \
                                                                         CapSenseProx_DEFAULT_IDAC_COMP_POLARITY | \
                                                                         CapSenseProx_DEFAULT_IDAC_COMP_BALL_MODE | \
                                                                        ((uint32)((uint32)CapSenseProx_IDAC_COMP_LEG1_MODE_GP_STATIC << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)((uint32)CapSenseProx_IDAC_COMP_LEG2_MODE_GP_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET))))
#else
    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_IDAC_COMP_EN)
        #define CapSenseProx_CSD_CAL_IDAC_MAX_VALUE                 (127u)
        #define CapSenseProx_CSD_CAL_MIDDLE_VALUE                   (0x40u)
    #else
        #define CapSenseProx_CSD_CAL_IDAC_MAX_VALUE                 (255u)
        #define CapSenseProx_CSD_CAL_MIDDLE_VALUE                   (0x80u)
    #endif

    #define CapSenseProx_IDAC_MOD_CFG_MASK                  (CapSenseProx_IDAC_POLARITY1_MIR_MASK |\
                                                                CapSenseProx_IDAC_MOD_RANGE_MASK |\
                                                                CapSenseProx_IDAC_MOD_MODE_MASK |\
                                                                CapSenseProx_IDAC_MOD_MASK)

    #define CapSenseProx_IDAC_COMP_CFG_MASK                 (CapSenseProx_IDAC_POLARITY2_MIR_MASK |\
                                                                CapSenseProx_IDAC_COMP_RANGE_MASK |\
                                                                CapSenseProx_IDAC_COMP_MODE_MASK |\
                                                                CapSenseProx_IDAC_COMP_MASK)

        #define CapSenseProx_PRS_8_CONFIG                       CapSenseProx_CONFIG_PRS_SELECT_MASK
    #define CapSenseProx_PRS_12_CONFIG                      (CapSenseProx_CONFIG_PRS_12_8_MASK |\
                                                                CapSenseProx_CONFIG_PRS_SELECT_MASK)

    /* Third-generation HW block Initial PRS mode */
    #if (CapSenseProx_CLK_SOURCE_PRS8 == CapSenseProx_CSD_SNS_CLK_SOURCE)
        #define CapSenseProx_DEFAULT_MODULATION_MODE        CapSenseProx_CONFIG_PRS_SELECT_MASK

    #elif (CapSenseProx_CLK_SOURCE_PRS12 == CapSenseProx_CSD_SNS_CLK_SOURCE)
        #define CapSenseProx_DEFAULT_MODULATION_MODE        (CapSenseProx_CONFIG_PRS_12_8_MASK |\
                                                                CapSenseProx_CONFIG_PRS_SELECT_MASK)
    #else
        #define CapSenseProx_DEFAULT_MODULATION_MODE        (0u)
    #endif /* (CapSenseProx_CSD_SNS_CLK_SOURCE == CapSenseProx_PRS_8BITS) */

    /* Defining default CSD configuration according to settings in customizer. */
    #define CapSenseProx_DEFAULT_CSD_CONFIG                 (CapSenseProx_CONFIG_SENSE_COMP_BW_MASK |\
                                                                CapSenseProx_DEFAULT_IDAC_POLARITY |\
                                                                CapSenseProx_CONFIG_SENSE_INSEL_MASK |\
                                                                CapSenseProx_CONFIG_REFBUF_DRV_MASK)

    /* Third-generation HW block Defining mask intended for clearing bits related to pre-charging options. */
    #define CapSenseProx_PRECHARGE_CONFIG_MASK              (CapSenseProx_CONFIG_REFBUF_EN_MASK |\
                                                                CapSenseProx_CONFIG_COMP_MODE_MASK |\
                                                                CapSenseProx_CONFIG_COMP_PIN_MASK  |\
                                                                CapSenseProx_CONFIG_REFBUF_OUTSEL_MASK)

    #define CapSenseProx_CMOD_PRECHARGE_CONFIG              (CapSenseProx_DEFAULT_CSD_CONFIG |\
                                                                CapSenseProx_CONFIG_REFBUF_EN_MASK |\
                                                                CapSenseProx_CONFIG_COMP_PIN_MASK)

    #define CapSenseProx_CMOD_PRECHARGE_CONFIG_CSD_EN       (CapSenseProx_DEFAULT_CSD_CONFIG |\
                                                                CapSenseProx_CSD_ENABLE_MASK |\
                                                                CapSenseProx_CONFIG_REFBUF_EN_MASK |\
                                                                CapSenseProx_CONFIG_COMP_PIN_MASK)


    #if (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN)
        #if((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_TANK_EN) &&\
            (CapSenseProx_CSH_PRECHARGE_IO_BUF == CapSenseProx_CSD_CSH_PRECHARGE_SRC))
            #define  CapSenseProx_CTANK_PRECHARGE_CONFIG    (CapSenseProx_DEFAULT_CSD_CONFIG |\
                                                                 CapSenseProx_CONFIG_REFBUF_OUTSEL_MASK |\
                                                                 CapSenseProx_CONFIG_REFBUF_EN_MASK |\
                                                                 CapSenseProx_CONFIG_COMP_MODE_MASK |\
                                                                 CapSenseProx_CONFIG_PRS_CLEAR_MASK |\
                                                                 CapSenseProx_CONFIG_COMP_PIN_MASK)
        #else
            #define  CapSenseProx_CTANK_PRECHARGE_CONFIG    (CapSenseProx_DEFAULT_CSD_CONFIG |\
                                                                 CapSenseProx_CONFIG_REFBUF_EN_MASK |\
                                                                 CapSenseProx_CONFIG_PRS_CLEAR_MASK |\
                                                                 CapSenseProx_CONFIG_REFBUF_OUTSEL_MASK)
        #endif
    #else
        #define  CapSenseProx_CTANK_PRECHARGE_CONFIG    (CapSenseProx_DEFAULT_CSD_CONFIG |\
                                                             CapSenseProx_CONFIG_REFBUF_OUTSEL_MASK |\
                                                             CapSenseProx_CONFIG_PRS_CLEAR_MASK)
    #endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) */


    #define  CapSenseProx_CTANK_PRECHARGE_CONFIG_CSD_EN     (CapSenseProx_CTANK_PRECHARGE_CONFIG |\
                                                                 CapSenseProx_CONFIG_ENABLE_MASK |\
                                                                 CapSenseProx_CONFIG_SENSE_COMP_EN_MASK)

#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSDV2) */

#define CapSenseProx_CSD_AVG_CYCLES_PER_LOOP                   (5u)
#define CapSenseProx_CSD_MEASURE_MAX_TIME_US                   (200000u)
#define CapSenseProx_CSD_PRECHARGE_MAX_TIME_US                 (50u)
#define CapSenseProx_CSD_ONE_CLOCK_MAX_TIME_US                 (50u)
#define CapSenseProx_WIDGET_MAX_SCAN_TIME_US                   (5u * 1000000u)

#define CapSenseProx_CSD_CALIBR_WATCHDOG_CYCLES_NUM            (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseProx_CSD_MEASURE_MAX_TIME_US)) /\
                                                                    (CapSenseProx_CSD_AVG_CYCLES_PER_LOOP))
#define CapSenseProx_CSD_PRECHARGE_WATCHDOG_CYCLES_NUM         (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseProx_CSD_PRECHARGE_MAX_TIME_US)) /\
                                                                    (CapSenseProx_CSD_AVG_CYCLES_PER_LOOP))
#define CapSenseProx_ONE_CLOCK_WATCHDOG_CYCLES_NUM             (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseProx_CSD_ONE_CLOCK_MAX_TIME_US)) /\
                                                                    (CapSenseProx_CSD_AVG_CYCLES_PER_LOOP))
#define CapSenseProx_WIDGET_MAX_SCAN_TIME                      (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSenseProx_WIDGET_MAX_SCAN_TIME_US)) /\
                                                                    (CapSenseProx_CSD_AVG_CYCLES_PER_LOOP))

/***************************************
* Global software variables
***************************************/

extern uint32 CapSenseProx_configCsd;

#if (CapSenseProx_ENABLE == CapSenseProx_CSD_NOISE_METRIC_EN)
    extern uint8 CapSenseProx_badConversionsNum;
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_NOISE_METRIC_EN) */


/***************************************
* Function Prototypes
**************************************/

/**
* \cond SECTION_C_LOW_LEVEL
* \addtogroup group_c_low_level
* \{
*/

void CapSenseProx_CSDSetupWidget(uint32 widgetId);
void CapSenseProx_CSDSetupWidgetExt(uint32 widgetId, uint32 sensorId);
void CapSenseProx_CSDScan(void);
void CapSenseProx_CSDScanExt(void);
#if ((CapSenseProx_CSD_SS_DIS != CapSenseProx_CSD_AUTOTUNE) || \
     (CapSenseProx_ENABLE == CapSenseProx_CSD_IDAC_AUTOCAL_EN))
    cystatus CapSenseProx_CSDCalibrateWidget(uint32 widgetId, uint32 target);
#endif /* ((CapSenseProx_CSD_SS_DIS != CapSenseProx_CSD_AUTOTUNE) || \
           (CapSenseProx_ENABLE == CapSenseProx_CSD_IDAC_AUTOCAL_EN))  */
void CapSenseProx_CSDConnectSns(CapSenseProx_FLASH_IO_STRUCT const *snsAddrPtr);
void CapSenseProx_CSDDisconnectSns(CapSenseProx_FLASH_IO_STRUCT const *snsAddrPtr);

/** \}
* \endcond */

/*****************************************************
* Function Prototypes - internal Low Level functions
*****************************************************/

/**
* \cond SECTION_C_INTERNAL
* \addtogroup group_c_internal
* \{
*/

void CapSenseProx_SsCSDInitialize(void);
void CapSenseProx_SsCSDStartSample(void);
void CapSenseProx_SsCSDSetUpIdacs(CapSenseProx_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CapSenseProx_SsCSDConfigClock(void);
void CapSenseProx_SsCSDElectrodeCheck(void);
#if ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
     (0u != CapSenseProx_CSD_TOTAL_SHIELD_COUNT))
    void CapSenseProx_SsCSDEnableShieldElectrodes(void);
    void CapSenseProx_SsCSDDisableShieldElectrodes(void);
    void CapSenseProx_SsCSDSetShieldElectrodesState(uint32 state);
#endif /* ((CapSenseProx_ENABLE == CapSenseProx_CSD_SHIELD_EN) && \
           (0u != CapSenseProx_CSD_TOTAL_SHIELD_COUNT)) */
#if (CapSenseProx_ENABLE == CapSenseProx_CSDV2)
    uint32 CapSenseProx_SsCSDGetNumberOfConversions(uint32 snsClkDivider, uint32 resolution, uint32 snsClkSrc);
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSDV2) */
void CapSenseProx_SsCSDCalculateScanDuration(CapSenseProx_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CapSenseProx_SsCSDConnectSensorExt(uint32 widgetId, uint32 sensorId);
void CapSenseProx_SsCSDDisconnectSnsExt(uint32 widgetId, uint32 sensorId);

#if ((CapSenseProx_CSD_SS_DIS != CapSenseProx_CSD_AUTOTUNE) || \
     (CapSenseProx_ENABLE == CapSenseProx_SELF_TEST_EN) || \
     (CapSenseProx_ENABLE == CapSenseProx_CSD_IDAC_AUTOCAL_EN))
#endif /* ((CapSenseProx_CSD_SS_DIS != CapSenseProx_CSD_AUTOTUNE) || \
           (CapSenseProx_ENABLE == CapSenseProx_SELF_TEST_EN) || \
           (CapSenseProx_ENABLE == CapSenseProx_CSD_IDAC_AUTOCAL_EN)) */

/** \}
* \endcond */

/***************************************
* Global software variables
***************************************/
extern uint32 CapSenseProx_configCsd;

/* Interrupt handler */
extern CY_ISR_PROTO(CapSenseProx_CSDPostSingleScan);
extern CY_ISR_PROTO(CapSenseProx_CSDPostMultiScan);
#if (CapSenseProx_ENABLE == CapSenseProx_CSD_GANGED_SNS_EN)
extern CY_ISR_PROTO(CapSenseProx_CSDPostMultiScanGanged);
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_GANGED_SNS_EN) */
#if (CapSenseProx_ENABLE == CapSenseProx_CSD_NOISE_METRIC_EN)
    extern uint8 CapSenseProx_badConversionsNum;
#endif /* (CapSenseProx_ENABLE == CapSenseProx_CSD_NOISE_METRIC_EN) */

#endif /* End CY_SENSE_CapSenseProx_SENSINGCSD_LL_H */


/* [] END OF FILE */
