/***************************************************************************//**
* \file CapSensep_RegisterMap.h
* \version 7.0
*
* \brief
*   This file provides the definitions for the Component data structure register.
*
* \see CapSensep v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSensep_REGISTER_MAP_H)
#define CY_SENSE_CapSensep_REGISTER_MAP_H

#include <cytypes.h>
#include "CapSensep_Configuration.h"
#include "CapSensep_Structure.h"

/*****************************************************************************/
/* RAM Data structure register definitions                                   */
/*****************************************************************************/
#define CapSensep_CONFIG_ID_VALUE                           (CapSensep_dsRam.configId)
#define CapSensep_CONFIG_ID_OFFSET                          (0u)
#define CapSensep_CONFIG_ID_SIZE                            (2u)
#define CapSensep_CONFIG_ID_PARAM_ID                        (0x87000000u)

#define CapSensep_DEVICE_ID_VALUE                           (CapSensep_dsRam.deviceId)
#define CapSensep_DEVICE_ID_OFFSET                          (2u)
#define CapSensep_DEVICE_ID_SIZE                            (2u)
#define CapSensep_DEVICE_ID_PARAM_ID                        (0x8B000002u)

#define CapSensep_HW_CLOCK_VALUE                            (CapSensep_dsRam.hwClock)
#define CapSensep_HW_CLOCK_OFFSET                           (4u)
#define CapSensep_HW_CLOCK_SIZE                             (2u)
#define CapSensep_HW_CLOCK_PARAM_ID                         (0x86000004u)

#define CapSensep_TUNER_CMD_VALUE                           (CapSensep_dsRam.tunerCmd)
#define CapSensep_TUNER_CMD_OFFSET                          (6u)
#define CapSensep_TUNER_CMD_SIZE                            (2u)
#define CapSensep_TUNER_CMD_PARAM_ID                        (0xA1000006u)

#define CapSensep_SCAN_COUNTER_VALUE                        (CapSensep_dsRam.scanCounter)
#define CapSensep_SCAN_COUNTER_OFFSET                       (8u)
#define CapSensep_SCAN_COUNTER_SIZE                         (2u)
#define CapSensep_SCAN_COUNTER_PARAM_ID                     (0x85000008u)

#define CapSensep_STATUS_VALUE                              (CapSensep_dsRam.status)
#define CapSensep_STATUS_OFFSET                             (12u)
#define CapSensep_STATUS_SIZE                               (4u)
#define CapSensep_STATUS_PARAM_ID                           (0xCB00000Cu)

#define CapSensep_WDGT_ENABLE0_VALUE                        (CapSensep_dsRam.wdgtEnable[0u])
#define CapSensep_WDGT_ENABLE0_OFFSET                       (16u)
#define CapSensep_WDGT_ENABLE0_SIZE                         (4u)
#define CapSensep_WDGT_ENABLE0_PARAM_ID                     (0xE6000010u)

#define CapSensep_WDGT_WORKING0_VALUE                       (CapSensep_dsRam.wdgtWorking[0u])
#define CapSensep_WDGT_WORKING0_OFFSET                      (20u)
#define CapSensep_WDGT_WORKING0_SIZE                        (4u)
#define CapSensep_WDGT_WORKING0_PARAM_ID                    (0xCC000014u)

#define CapSensep_WDGT_STATUS0_VALUE                        (CapSensep_dsRam.wdgtStatus[0u])
#define CapSensep_WDGT_STATUS0_OFFSET                       (24u)
#define CapSensep_WDGT_STATUS0_SIZE                         (4u)
#define CapSensep_WDGT_STATUS0_PARAM_ID                     (0xCF000018u)

#define CapSensep_SNS_STATUS0_VALUE                         (CapSensep_dsRam.snsStatus[0u])
#define CapSensep_SNS_STATUS0_OFFSET                        (28u)
#define CapSensep_SNS_STATUS0_SIZE                          (1u)
#define CapSensep_SNS_STATUS0_PARAM_ID                      (0x4900001Cu)

#define CapSensep_CSD0_CONFIG_VALUE                         (CapSensep_dsRam.csd0Config)
#define CapSensep_CSD0_CONFIG_OFFSET                        (30u)
#define CapSensep_CSD0_CONFIG_SIZE                          (2u)
#define CapSensep_CSD0_CONFIG_PARAM_ID                      (0xAB80001Eu)

#define CapSensep_MOD_CSD_CLK_VALUE                         (CapSensep_dsRam.modCsdClk)
#define CapSensep_MOD_CSD_CLK_OFFSET                        (32u)
#define CapSensep_MOD_CSD_CLK_SIZE                          (1u)
#define CapSensep_MOD_CSD_CLK_PARAM_ID                      (0x63800020u)

#define CapSensep_GLB_CRC_VALUE                             (CapSensep_dsRam.glbCrc)
#define CapSensep_GLB_CRC_OFFSET                            (34u)
#define CapSensep_GLB_CRC_SIZE                              (2u)
#define CapSensep_GLB_CRC_PARAM_ID                          (0x81000022u)

#define CapSensep_PROXIMITY0_CRC_VALUE                      (CapSensep_dsRam.wdgtList.proximity0.crc)
#define CapSensep_PROXIMITY0_CRC_OFFSET                     (36u)
#define CapSensep_PROXIMITY0_CRC_SIZE                       (2u)
#define CapSensep_PROXIMITY0_CRC_PARAM_ID                   (0x8C000024u)

#define CapSensep_PROXIMITY0_RESOLUTION_VALUE               (CapSensep_dsRam.wdgtList.proximity0.resolution)
#define CapSensep_PROXIMITY0_RESOLUTION_OFFSET              (38u)
#define CapSensep_PROXIMITY0_RESOLUTION_SIZE                (2u)
#define CapSensep_PROXIMITY0_RESOLUTION_PARAM_ID            (0xA6800026u)

#define CapSensep_PROXIMITY0_FINGER_TH_VALUE                (CapSensep_dsRam.wdgtList.proximity0.fingerTh)
#define CapSensep_PROXIMITY0_FINGER_TH_OFFSET               (40u)
#define CapSensep_PROXIMITY0_FINGER_TH_SIZE                 (2u)
#define CapSensep_PROXIMITY0_FINGER_TH_PARAM_ID             (0xA9800028u)

#define CapSensep_PROXIMITY0_NOISE_TH_VALUE                 (CapSensep_dsRam.wdgtList.proximity0.noiseTh)
#define CapSensep_PROXIMITY0_NOISE_TH_OFFSET                (42u)
#define CapSensep_PROXIMITY0_NOISE_TH_SIZE                  (1u)
#define CapSensep_PROXIMITY0_NOISE_TH_PARAM_ID              (0x6D80002Au)

#define CapSensep_PROXIMITY0_NNOISE_TH_VALUE                (CapSensep_dsRam.wdgtList.proximity0.nNoiseTh)
#define CapSensep_PROXIMITY0_NNOISE_TH_OFFSET               (43u)
#define CapSensep_PROXIMITY0_NNOISE_TH_SIZE                 (1u)
#define CapSensep_PROXIMITY0_NNOISE_TH_PARAM_ID             (0x6B80002Bu)

#define CapSensep_PROXIMITY0_HYSTERESIS_VALUE               (CapSensep_dsRam.wdgtList.proximity0.hysteresis)
#define CapSensep_PROXIMITY0_HYSTERESIS_OFFSET              (44u)
#define CapSensep_PROXIMITY0_HYSTERESIS_SIZE                (1u)
#define CapSensep_PROXIMITY0_HYSTERESIS_PARAM_ID            (0x6080002Cu)

#define CapSensep_PROXIMITY0_ON_DEBOUNCE_VALUE              (CapSensep_dsRam.wdgtList.proximity0.onDebounce)
#define CapSensep_PROXIMITY0_ON_DEBOUNCE_OFFSET             (45u)
#define CapSensep_PROXIMITY0_ON_DEBOUNCE_SIZE               (1u)
#define CapSensep_PROXIMITY0_ON_DEBOUNCE_PARAM_ID           (0x6680002Du)

#define CapSensep_PROXIMITY0_LOW_BSLN_RST_VALUE             (CapSensep_dsRam.wdgtList.proximity0.lowBslnRst)
#define CapSensep_PROXIMITY0_LOW_BSLN_RST_OFFSET            (46u)
#define CapSensep_PROXIMITY0_LOW_BSLN_RST_SIZE              (1u)
#define CapSensep_PROXIMITY0_LOW_BSLN_RST_PARAM_ID          (0x6C80002Eu)

#define CapSensep_PROXIMITY0_IDAC_MOD0_VALUE                (CapSensep_dsRam.wdgtList.proximity0.idacMod[0u])
#define CapSensep_PROXIMITY0_IDAC_MOD0_OFFSET               (47u)
#define CapSensep_PROXIMITY0_IDAC_MOD0_SIZE                 (1u)
#define CapSensep_PROXIMITY0_IDAC_MOD0_PARAM_ID             (0x4C00002Fu)

#define CapSensep_PROXIMITY0_IDAC_MOD1_VALUE                (CapSensep_dsRam.wdgtList.proximity0.idacMod[1u])
#define CapSensep_PROXIMITY0_IDAC_MOD1_OFFSET               (48u)
#define CapSensep_PROXIMITY0_IDAC_MOD1_SIZE                 (1u)
#define CapSensep_PROXIMITY0_IDAC_MOD1_PARAM_ID             (0x40000030u)

#define CapSensep_PROXIMITY0_IDAC_MOD2_VALUE                (CapSensep_dsRam.wdgtList.proximity0.idacMod[2u])
#define CapSensep_PROXIMITY0_IDAC_MOD2_OFFSET               (49u)
#define CapSensep_PROXIMITY0_IDAC_MOD2_SIZE                 (1u)
#define CapSensep_PROXIMITY0_IDAC_MOD2_PARAM_ID             (0x46000031u)

#define CapSensep_PROXIMITY0_IDAC_GAIN_INDEX_VALUE          (CapSensep_dsRam.wdgtList.proximity0.idacGainIndex)
#define CapSensep_PROXIMITY0_IDAC_GAIN_INDEX_OFFSET         (50u)
#define CapSensep_PROXIMITY0_IDAC_GAIN_INDEX_SIZE           (1u)
#define CapSensep_PROXIMITY0_IDAC_GAIN_INDEX_PARAM_ID       (0x41800032u)

#define CapSensep_PROXIMITY0_SNS_CLK_VALUE                  (CapSensep_dsRam.wdgtList.proximity0.snsClk)
#define CapSensep_PROXIMITY0_SNS_CLK_OFFSET                 (52u)
#define CapSensep_PROXIMITY0_SNS_CLK_SIZE                   (2u)
#define CapSensep_PROXIMITY0_SNS_CLK_PARAM_ID               (0xAF800034u)

#define CapSensep_PROXIMITY0_SNS_CLK_SOURCE_VALUE           (CapSensep_dsRam.wdgtList.proximity0.snsClkSource)
#define CapSensep_PROXIMITY0_SNS_CLK_SOURCE_OFFSET          (54u)
#define CapSensep_PROXIMITY0_SNS_CLK_SOURCE_SIZE            (1u)
#define CapSensep_PROXIMITY0_SNS_CLK_SOURCE_PARAM_ID        (0x40800036u)

#define CapSensep_PROXIMITY0_PROX_TOUCH_TH_VALUE            (CapSensep_dsRam.wdgtList.proximity0.proxTouchTh)
#define CapSensep_PROXIMITY0_PROX_TOUCH_TH_OFFSET           (56u)
#define CapSensep_PROXIMITY0_PROX_TOUCH_TH_SIZE             (2u)
#define CapSensep_PROXIMITY0_PROX_TOUCH_TH_PARAM_ID         (0xA1000038u)

#define CapSensep_PROXIMITY0_SNS0_RAW0_VALUE                (CapSensep_dsRam.snsList.proximity0[0u].raw[0u])
#define CapSensep_PROXIMITY0_SNS0_RAW0_OFFSET               (58u)
#define CapSensep_PROXIMITY0_SNS0_RAW0_SIZE                 (2u)
#define CapSensep_PROXIMITY0_SNS0_RAW0_PARAM_ID             (0x8600003Au)

#define CapSensep_PROXIMITY0_SNS0_RAW1_VALUE                (CapSensep_dsRam.snsList.proximity0[0u].raw[1u])
#define CapSensep_PROXIMITY0_SNS0_RAW1_OFFSET               (60u)
#define CapSensep_PROXIMITY0_SNS0_RAW1_SIZE                 (2u)
#define CapSensep_PROXIMITY0_SNS0_RAW1_PARAM_ID             (0x8B00003Cu)

#define CapSensep_PROXIMITY0_SNS0_RAW2_VALUE                (CapSensep_dsRam.snsList.proximity0[0u].raw[2u])
#define CapSensep_PROXIMITY0_SNS0_RAW2_OFFSET               (62u)
#define CapSensep_PROXIMITY0_SNS0_RAW2_SIZE                 (2u)
#define CapSensep_PROXIMITY0_SNS0_RAW2_PARAM_ID             (0x8700003Eu)

#define CapSensep_PROXIMITY0_SNS0_BSLN0_VALUE               (CapSensep_dsRam.snsList.proximity0[0u].bsln[0u])
#define CapSensep_PROXIMITY0_SNS0_BSLN0_OFFSET              (64u)
#define CapSensep_PROXIMITY0_SNS0_BSLN0_SIZE                (2u)
#define CapSensep_PROXIMITY0_SNS0_BSLN0_PARAM_ID            (0x8A000040u)

#define CapSensep_PROXIMITY0_SNS0_BSLN1_VALUE               (CapSensep_dsRam.snsList.proximity0[0u].bsln[1u])
#define CapSensep_PROXIMITY0_SNS0_BSLN1_OFFSET              (66u)
#define CapSensep_PROXIMITY0_SNS0_BSLN1_SIZE                (2u)
#define CapSensep_PROXIMITY0_SNS0_BSLN1_PARAM_ID            (0x86000042u)

#define CapSensep_PROXIMITY0_SNS0_BSLN2_VALUE               (CapSensep_dsRam.snsList.proximity0[0u].bsln[2u])
#define CapSensep_PROXIMITY0_SNS0_BSLN2_OFFSET              (68u)
#define CapSensep_PROXIMITY0_SNS0_BSLN2_SIZE                (2u)
#define CapSensep_PROXIMITY0_SNS0_BSLN2_PARAM_ID            (0x8B000044u)

#define CapSensep_PROXIMITY0_SNS0_BSLN_INV0_VALUE           (CapSensep_dsRam.snsList.proximity0[0u].bslnInv[0u])
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV0_OFFSET          (70u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV0_SIZE            (2u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV0_PARAM_ID        (0x87000046u)

#define CapSensep_PROXIMITY0_SNS0_BSLN_INV1_VALUE           (CapSensep_dsRam.snsList.proximity0[0u].bslnInv[1u])
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV1_OFFSET          (72u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV1_SIZE            (2u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV1_PARAM_ID        (0x88000048u)

#define CapSensep_PROXIMITY0_SNS0_BSLN_INV2_VALUE           (CapSensep_dsRam.snsList.proximity0[0u].bslnInv[2u])
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV2_OFFSET          (74u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV2_SIZE            (2u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_INV2_PARAM_ID        (0x8400004Au)

#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT0_VALUE           (CapSensep_dsRam.snsList.proximity0[0u].bslnExt[0u])
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT0_OFFSET          (76u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT0_SIZE            (1u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT0_PARAM_ID        (0x4100004Cu)

#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT1_VALUE           (CapSensep_dsRam.snsList.proximity0[0u].bslnExt[1u])
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT1_OFFSET          (77u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT1_SIZE            (1u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT1_PARAM_ID        (0x4700004Du)

#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT2_VALUE           (CapSensep_dsRam.snsList.proximity0[0u].bslnExt[2u])
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT2_OFFSET          (78u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT2_SIZE            (1u)
#define CapSensep_PROXIMITY0_SNS0_BSLN_EXT2_PARAM_ID        (0x4D00004Eu)

#define CapSensep_PROXIMITY0_SNS0_DIFF_VALUE                (CapSensep_dsRam.snsList.proximity0[0u].diff)
#define CapSensep_PROXIMITY0_SNS0_DIFF_OFFSET               (80u)
#define CapSensep_PROXIMITY0_SNS0_DIFF_SIZE                 (2u)
#define CapSensep_PROXIMITY0_SNS0_DIFF_PARAM_ID             (0x8F000050u)

#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_VALUE   (CapSensep_dsRam.snsList.proximity0[0u].negBslnRstCnt[0u])
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_OFFSET  (82u)
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_SIZE    (1u)
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT0_PARAM_ID (0x4B000052u)

#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT1_VALUE   (CapSensep_dsRam.snsList.proximity0[0u].negBslnRstCnt[1u])
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT1_OFFSET  (83u)
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT1_SIZE    (1u)
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT1_PARAM_ID (0x4D000053u)

#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT2_VALUE   (CapSensep_dsRam.snsList.proximity0[0u].negBslnRstCnt[2u])
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT2_OFFSET  (84u)
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT2_SIZE    (1u)
#define CapSensep_PROXIMITY0_SNS0_NEG_BSLN_RST_CNT2_PARAM_ID (0x46000054u)

#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP0_VALUE          (CapSensep_dsRam.snsList.proximity0[0u].idacComp[0u])
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP0_OFFSET         (85u)
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP0_SIZE           (1u)
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP0_PARAM_ID       (0x40000055u)

#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP1_VALUE          (CapSensep_dsRam.snsList.proximity0[0u].idacComp[1u])
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP1_OFFSET         (86u)
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP1_SIZE           (1u)
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP1_PARAM_ID       (0x4A000056u)

#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP2_VALUE          (CapSensep_dsRam.snsList.proximity0[0u].idacComp[2u])
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP2_OFFSET         (87u)
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP2_SIZE           (1u)
#define CapSensep_PROXIMITY0_SNS0_IDAC_COMP2_PARAM_ID       (0x4C000057u)

#define CapSensep_TEST_RESULT_MASK_VALUE                    (CapSensep_dsRam.selfTest.testResultMask)
#define CapSensep_TEST_RESULT_MASK_OFFSET                   (88u)
#define CapSensep_TEST_RESULT_MASK_SIZE                     (4u)
#define CapSensep_TEST_RESULT_MASK_PARAM_ID                 (0xE9000058u)

#define CapSensep_EXT_CAP0_VALUE                            (CapSensep_dsRam.selfTest.extCap[0u])
#define CapSensep_EXT_CAP0_OFFSET                           (92u)
#define CapSensep_EXT_CAP0_SIZE                             (2u)
#define CapSensep_EXT_CAP0_PARAM_ID                         (0xA700005Cu)

#define CapSensep_VDDA_VOLTAGE_VALUE                        (CapSensep_dsRam.selfTest.vddaVoltage)
#define CapSensep_VDDA_VOLTAGE_OFFSET                       (94u)
#define CapSensep_VDDA_VOLTAGE_SIZE                         (2u)
#define CapSensep_VDDA_VOLTAGE_PARAM_ID                     (0xAB00005Eu)

#define CapSensep_GLB_CRC_CALC_VALUE                        (CapSensep_dsRam.selfTest.glbCrcCalc)
#define CapSensep_GLB_CRC_CALC_OFFSET                       (96u)
#define CapSensep_GLB_CRC_CALC_SIZE                         (2u)
#define CapSensep_GLB_CRC_CALC_PARAM_ID                     (0xAB000060u)

#define CapSensep_WDGT_CRC_CALC_VALUE                       (CapSensep_dsRam.selfTest.wdgtCrcCalc)
#define CapSensep_WDGT_CRC_CALC_OFFSET                      (98u)
#define CapSensep_WDGT_CRC_CALC_SIZE                        (2u)
#define CapSensep_WDGT_CRC_CALC_PARAM_ID                    (0xA7000062u)

#define CapSensep_WDGT_CRC_ID_VALUE                         (CapSensep_dsRam.selfTest.wdgtCrcId)
#define CapSensep_WDGT_CRC_ID_OFFSET                        (100u)
#define CapSensep_WDGT_CRC_ID_SIZE                          (1u)
#define CapSensep_WDGT_CRC_ID_PARAM_ID                      (0x62000064u)

#define CapSensep_INV_BSLN_WDGT_ID_VALUE                    (CapSensep_dsRam.selfTest.invBslnWdgtId)
#define CapSensep_INV_BSLN_WDGT_ID_OFFSET                   (101u)
#define CapSensep_INV_BSLN_WDGT_ID_SIZE                     (1u)
#define CapSensep_INV_BSLN_WDGT_ID_PARAM_ID                 (0x64000065u)

#define CapSensep_INV_BSLN_SNS_ID_VALUE                     (CapSensep_dsRam.selfTest.invBslnSnsId)
#define CapSensep_INV_BSLN_SNS_ID_OFFSET                    (102u)
#define CapSensep_INV_BSLN_SNS_ID_SIZE                      (1u)
#define CapSensep_INV_BSLN_SNS_ID_PARAM_ID                  (0x6E000066u)

#define CapSensep_SHORTED_WDGT_ID_VALUE                     (CapSensep_dsRam.selfTest.shortedWdgtId)
#define CapSensep_SHORTED_WDGT_ID_OFFSET                    (103u)
#define CapSensep_SHORTED_WDGT_ID_SIZE                      (1u)
#define CapSensep_SHORTED_WDGT_ID_PARAM_ID                  (0x68000067u)

#define CapSensep_SHORTED_SNS_ID_VALUE                      (CapSensep_dsRam.selfTest.shortedSnsId)
#define CapSensep_SHORTED_SNS_ID_OFFSET                     (104u)
#define CapSensep_SHORTED_SNS_ID_SIZE                       (1u)
#define CapSensep_SHORTED_SNS_ID_PARAM_ID                   (0x61000068u)

#define CapSensep_IDAC_GAIN_INDEX_VALUE                     (CapSensep_dsRam.selfTest.idacGainIndex)
#define CapSensep_IDAC_GAIN_INDEX_OFFSET                    (105u)
#define CapSensep_IDAC_GAIN_INDEX_SIZE                      (1u)
#define CapSensep_IDAC_GAIN_INDEX_PARAM_ID                  (0x67000069u)

#define CapSensep_SNS_CLK_VALUE                             (CapSensep_dsRam.selfTest.snsClk)
#define CapSensep_SNS_CLK_OFFSET                            (106u)
#define CapSensep_SNS_CLK_SIZE                              (2u)
#define CapSensep_SNS_CLK_PARAM_ID                          (0xA500006Au)

#define CapSensep_SNS_CAP_SNS_CLK_HZ_VALUE                  (CapSensep_dsRam.selfTestConfig.snsCapSnsClkHz)
#define CapSensep_SNS_CAP_SNS_CLK_HZ_OFFSET                 (108u)
#define CapSensep_SNS_CAP_SNS_CLK_HZ_SIZE                   (4u)
#define CapSensep_SNS_CAP_SNS_CLK_HZ_PARAM_ID               (0xE700006Cu)

#define CapSensep_SNS_CAP_SNS_CLK_DIVIDER_VALUE             (CapSensep_dsRam.selfTestConfig.snsCapSnsClkDivider)
#define CapSensep_SNS_CAP_SNS_CLK_DIVIDER_OFFSET            (112u)
#define CapSensep_SNS_CAP_SNS_CLK_DIVIDER_SIZE              (2u)
#define CapSensep_SNS_CAP_SNS_CLK_DIVIDER_PARAM_ID          (0xAE000070u)

#define CapSensep_SNS_CAP_MOD_CLK_KHZ_VALUE                 (CapSensep_dsRam.selfTestConfig.snsCapModClkKHz)
#define CapSensep_SNS_CAP_MOD_CLK_KHZ_OFFSET                (114u)
#define CapSensep_SNS_CAP_MOD_CLK_KHZ_SIZE                  (2u)
#define CapSensep_SNS_CAP_MOD_CLK_KHZ_PARAM_ID              (0xA2000072u)

#define CapSensep_SNS_CAP_MOD_CLK_DIVIDER_VALUE             (CapSensep_dsRam.selfTestConfig.snsCapModClkDivider)
#define CapSensep_SNS_CAP_MOD_CLK_DIVIDER_OFFSET            (116u)
#define CapSensep_SNS_CAP_MOD_CLK_DIVIDER_SIZE              (2u)
#define CapSensep_SNS_CAP_MOD_CLK_DIVIDER_PARAM_ID          (0xAF000074u)

#define CapSensep_SNS_CAP_VREF_VOLTAGE_VALUE                (CapSensep_dsRam.selfTestConfig.snsCapVrefVoltage)
#define CapSensep_SNS_CAP_VREF_VOLTAGE_OFFSET               (118u)
#define CapSensep_SNS_CAP_VREF_VOLTAGE_SIZE                 (2u)
#define CapSensep_SNS_CAP_VREF_VOLTAGE_PARAM_ID             (0xA3000076u)

#define CapSensep_VDDA_VREF_VOLTAGE_VALUE                   (CapSensep_dsRam.selfTestConfig.vddaVrefVoltage)
#define CapSensep_VDDA_VREF_VOLTAGE_OFFSET                  (120u)
#define CapSensep_VDDA_VREF_VOLTAGE_SIZE                    (2u)
#define CapSensep_VDDA_VREF_VOLTAGE_PARAM_ID                (0xAC000078u)

#define CapSensep_EXT_CAP_VREF_VOLTAGE_VALUE                (CapSensep_dsRam.selfTestConfig.extCapVrefVoltage)
#define CapSensep_EXT_CAP_VREF_VOLTAGE_OFFSET               (122u)
#define CapSensep_EXT_CAP_VREF_VOLTAGE_SIZE                 (2u)
#define CapSensep_EXT_CAP_VREF_VOLTAGE_PARAM_ID             (0xA000007Au)

#define CapSensep_VDDA_MOD_CLK_DIVIDER_VALUE                (CapSensep_dsRam.selfTestConfig.vddaModClkDivider)
#define CapSensep_VDDA_MOD_CLK_DIVIDER_OFFSET               (124u)
#define CapSensep_VDDA_MOD_CLK_DIVIDER_SIZE                 (1u)
#define CapSensep_VDDA_MOD_CLK_DIVIDER_PARAM_ID             (0x6500007Cu)

#define CapSensep_VDDA_VREF_GAIN_VALUE                      (CapSensep_dsRam.selfTestConfig.vddaVrefGain)
#define CapSensep_VDDA_VREF_GAIN_OFFSET                     (125u)
#define CapSensep_VDDA_VREF_GAIN_SIZE                       (1u)
#define CapSensep_VDDA_VREF_GAIN_PARAM_ID                   (0x6300007Du)

#define CapSensep_VDDA_RESOLUTION_VALUE                     (CapSensep_dsRam.selfTestConfig.vddaResolution)
#define CapSensep_VDDA_RESOLUTION_OFFSET                    (126u)
#define CapSensep_VDDA_RESOLUTION_SIZE                      (1u)
#define CapSensep_VDDA_RESOLUTION_PARAM_ID                  (0x6900007Eu)

#define CapSensep_VDDA_IDAC_DEFAULT_VALUE                   (CapSensep_dsRam.selfTestConfig.vddaIdacDefault)
#define CapSensep_VDDA_IDAC_DEFAULT_OFFSET                  (127u)
#define CapSensep_VDDA_IDAC_DEFAULT_SIZE                    (1u)
#define CapSensep_VDDA_IDAC_DEFAULT_PARAM_ID                (0x6F00007Fu)

#define CapSensep_SNS_CAP_RESOLUTION_VALUE                  (CapSensep_dsRam.selfTestConfig.snsCapResolution)
#define CapSensep_SNS_CAP_RESOLUTION_OFFSET                 (128u)
#define CapSensep_SNS_CAP_RESOLUTION_SIZE                   (1u)
#define CapSensep_SNS_CAP_RESOLUTION_PARAM_ID               (0x67000080u)

#define CapSensep_SNS_CAP_VREF_GAIN_VALUE                   (CapSensep_dsRam.selfTestConfig.snsCapVrefGain)
#define CapSensep_SNS_CAP_VREF_GAIN_OFFSET                  (129u)
#define CapSensep_SNS_CAP_VREF_GAIN_SIZE                    (1u)
#define CapSensep_SNS_CAP_VREF_GAIN_PARAM_ID                (0x61000081u)

#define CapSensep_BIST_CSD_SNS_CAP_ISC_VALUE                (CapSensep_dsRam.selfTestConfig.bistCsdSnsCapISC)
#define CapSensep_BIST_CSD_SNS_CAP_ISC_OFFSET               (130u)
#define CapSensep_BIST_CSD_SNS_CAP_ISC_SIZE                 (1u)
#define CapSensep_BIST_CSD_SNS_CAP_ISC_PARAM_ID             (0x6B000082u)

#define CapSensep_BIST_CSX_SNS_CAP_ISC_VALUE                (CapSensep_dsRam.selfTestConfig.bistCsxSnsCapISC)
#define CapSensep_BIST_CSX_SNS_CAP_ISC_OFFSET               (131u)
#define CapSensep_BIST_CSX_SNS_CAP_ISC_SIZE                 (1u)
#define CapSensep_BIST_CSX_SNS_CAP_ISC_PARAM_ID             (0x6D000083u)

#define CapSensep_BIST_CSD_SH_CAP_ISC_VALUE                 (CapSensep_dsRam.selfTestConfig.bistCsdShCapISC)
#define CapSensep_BIST_CSD_SH_CAP_ISC_OFFSET                (132u)
#define CapSensep_BIST_CSD_SH_CAP_ISC_SIZE                  (1u)
#define CapSensep_BIST_CSD_SH_CAP_ISC_PARAM_ID              (0x66000084u)

#define CapSensep_EXT_CAP_VREF_GAIN_VALUE                   (CapSensep_dsRam.selfTestConfig.extCapVrefGain)
#define CapSensep_EXT_CAP_VREF_GAIN_OFFSET                  (133u)
#define CapSensep_EXT_CAP_VREF_GAIN_SIZE                    (1u)
#define CapSensep_EXT_CAP_VREF_GAIN_PARAM_ID                (0x60000085u)

#define CapSensep_STARTUP_DELAY_VALUE                       (CapSensep_dsRam.selfTestConfig.startupDelay)
#define CapSensep_STARTUP_DELAY_OFFSET                      (134u)
#define CapSensep_STARTUP_DELAY_SIZE                        (1u)
#define CapSensep_STARTUP_DELAY_PARAM_ID                    (0x6A000086u)

#define CapSensep_FINE_INIT_TIME_VALUE                      (CapSensep_dsRam.selfTestConfig.fineInitTime)
#define CapSensep_FINE_INIT_TIME_OFFSET                     (135u)
#define CapSensep_FINE_INIT_TIME_SIZE                       (1u)
#define CapSensep_FINE_INIT_TIME_PARAM_ID                   (0x6C000087u)

#define CapSensep_SNS_SHORT_TIME_VALUE                      (CapSensep_dsRam.selfTestConfig.snsShortTimeUs)
#define CapSensep_SNS_SHORT_TIME_OFFSET                     (136u)
#define CapSensep_SNS_SHORT_TIME_SIZE                       (1u)
#define CapSensep_SNS_SHORT_TIME_PARAM_ID                   (0x65000088u)

#define CapSensep_PROXIMITY0_SNS_CP0_VALUE                  (CapSensep_dsRam.snsCp.proximity0[0u])
#define CapSensep_PROXIMITY0_SNS_CP0_OFFSET                 (140u)
#define CapSensep_PROXIMITY0_SNS_CP0_SIZE                   (4u)
#define CapSensep_PROXIMITY0_SNS_CP0_PARAM_ID               (0xE300008Cu)

#define CapSensep_SNR_TEST_WIDGET_ID_VALUE                  (CapSensep_dsRam.snrTestWidgetId)
#define CapSensep_SNR_TEST_WIDGET_ID_OFFSET                 (144u)
#define CapSensep_SNR_TEST_WIDGET_ID_SIZE                   (1u)
#define CapSensep_SNR_TEST_WIDGET_ID_PARAM_ID               (0x62000090u)

#define CapSensep_SNR_TEST_SENSOR_ID_VALUE                  (CapSensep_dsRam.snrTestSensorId)
#define CapSensep_SNR_TEST_SENSOR_ID_OFFSET                 (145u)
#define CapSensep_SNR_TEST_SENSOR_ID_SIZE                   (1u)
#define CapSensep_SNR_TEST_SENSOR_ID_PARAM_ID               (0x64000091u)

#define CapSensep_SNR_TEST_SCAN_COUNTER_VALUE               (CapSensep_dsRam.snrTestScanCounter)
#define CapSensep_SNR_TEST_SCAN_COUNTER_OFFSET              (146u)
#define CapSensep_SNR_TEST_SCAN_COUNTER_SIZE                (2u)
#define CapSensep_SNR_TEST_SCAN_COUNTER_PARAM_ID            (0x8D000092u)

#define CapSensep_SNR_TEST_RAW_COUNT0_VALUE                 (CapSensep_dsRam.snrTestRawCount[0u])
#define CapSensep_SNR_TEST_RAW_COUNT0_OFFSET                (148u)
#define CapSensep_SNR_TEST_RAW_COUNT0_SIZE                  (2u)
#define CapSensep_SNR_TEST_RAW_COUNT0_PARAM_ID              (0x80000094u)

#define CapSensep_SNR_TEST_RAW_COUNT1_VALUE                 (CapSensep_dsRam.snrTestRawCount[1u])
#define CapSensep_SNR_TEST_RAW_COUNT1_OFFSET                (150u)
#define CapSensep_SNR_TEST_RAW_COUNT1_SIZE                  (2u)
#define CapSensep_SNR_TEST_RAW_COUNT1_PARAM_ID              (0x8C000096u)

#define CapSensep_SNR_TEST_RAW_COUNT2_VALUE                 (CapSensep_dsRam.snrTestRawCount[2u])
#define CapSensep_SNR_TEST_RAW_COUNT2_OFFSET                (152u)
#define CapSensep_SNR_TEST_RAW_COUNT2_SIZE                  (2u)
#define CapSensep_SNR_TEST_RAW_COUNT2_PARAM_ID              (0x83000098u)

#define CapSensep_SCAN_CSD_ISC_VALUE                        (CapSensep_dsRam.scanCsdISC)
#define CapSensep_SCAN_CSD_ISC_OFFSET                       (154u)
#define CapSensep_SCAN_CSD_ISC_SIZE                         (1u)
#define CapSensep_SCAN_CSD_ISC_PARAM_ID                     (0x4700009Au)

#define CapSensep_SCAN_CURRENT_ISC_VALUE                    (CapSensep_dsRam.scanCurrentISC)
#define CapSensep_SCAN_CURRENT_ISC_OFFSET                   (155u)
#define CapSensep_SCAN_CURRENT_ISC_SIZE                     (1u)
#define CapSensep_SCAN_CURRENT_ISC_PARAM_ID                 (0x4100009Bu)


/*****************************************************************************/
/* Flash Data structure register definitions                                 */
/*****************************************************************************/
#define CapSensep_PROXIMITY0_PTR2SNS_FLASH_VALUE            (CapSensep_dsFlash.wdgtArray[0].ptr2SnsFlash)
#define CapSensep_PROXIMITY0_PTR2SNS_FLASH_OFFSET           (0u)
#define CapSensep_PROXIMITY0_PTR2SNS_FLASH_SIZE             (4u)
#define CapSensep_PROXIMITY0_PTR2SNS_FLASH_PARAM_ID         (0xD1000000u)

#define CapSensep_PROXIMITY0_PTR2WD_RAM_VALUE               (CapSensep_dsFlash.wdgtArray[0].ptr2WdgtRam)
#define CapSensep_PROXIMITY0_PTR2WD_RAM_OFFSET              (4u)
#define CapSensep_PROXIMITY0_PTR2WD_RAM_SIZE                (4u)
#define CapSensep_PROXIMITY0_PTR2WD_RAM_PARAM_ID            (0xD0000004u)

#define CapSensep_PROXIMITY0_PTR2SNS_RAM_VALUE              (CapSensep_dsFlash.wdgtArray[0].ptr2SnsRam)
#define CapSensep_PROXIMITY0_PTR2SNS_RAM_OFFSET             (8u)
#define CapSensep_PROXIMITY0_PTR2SNS_RAM_SIZE               (4u)
#define CapSensep_PROXIMITY0_PTR2SNS_RAM_PARAM_ID           (0xD3000008u)

#define CapSensep_PROXIMITY0_PTR2FLTR_HISTORY_VALUE         (CapSensep_dsFlash.wdgtArray[0].ptr2FltrHistory)
#define CapSensep_PROXIMITY0_PTR2FLTR_HISTORY_OFFSET        (12u)
#define CapSensep_PROXIMITY0_PTR2FLTR_HISTORY_SIZE          (4u)
#define CapSensep_PROXIMITY0_PTR2FLTR_HISTORY_PARAM_ID      (0xD200000Cu)

#define CapSensep_PROXIMITY0_PTR2DEBOUNCE_VALUE             (CapSensep_dsFlash.wdgtArray[0].ptr2DebounceArr)
#define CapSensep_PROXIMITY0_PTR2DEBOUNCE_OFFSET            (16u)
#define CapSensep_PROXIMITY0_PTR2DEBOUNCE_SIZE              (4u)
#define CapSensep_PROXIMITY0_PTR2DEBOUNCE_PARAM_ID          (0xD4000010u)

#define CapSensep_PROXIMITY0_STATIC_CONFIG_VALUE            (CapSensep_dsFlash.wdgtArray[0].staticConfig)
#define CapSensep_PROXIMITY0_STATIC_CONFIG_OFFSET           (20u)
#define CapSensep_PROXIMITY0_STATIC_CONFIG_SIZE             (4u)
#define CapSensep_PROXIMITY0_STATIC_CONFIG_PARAM_ID         (0xD5000014u)

#define CapSensep_PROXIMITY0_TOTAL_NUM_SNS_VALUE            (CapSensep_dsFlash.wdgtArray[0].totalNumSns)
#define CapSensep_PROXIMITY0_TOTAL_NUM_SNS_OFFSET           (24u)
#define CapSensep_PROXIMITY0_TOTAL_NUM_SNS_SIZE             (2u)
#define CapSensep_PROXIMITY0_TOTAL_NUM_SNS_PARAM_ID         (0x99000018u)

#define CapSensep_PROXIMITY0_TYPE_VALUE                     (CapSensep_dsFlash.wdgtArray[0].wdgtType)
#define CapSensep_PROXIMITY0_TYPE_OFFSET                    (26u)
#define CapSensep_PROXIMITY0_TYPE_SIZE                      (1u)
#define CapSensep_PROXIMITY0_TYPE_PARAM_ID                  (0x5D00001Au)

#define CapSensep_PROXIMITY0_NUM_COLS_VALUE                 (CapSensep_dsFlash.wdgtArray[0].numCols)
#define CapSensep_PROXIMITY0_NUM_COLS_OFFSET                (27u)
#define CapSensep_PROXIMITY0_NUM_COLS_SIZE                  (1u)
#define CapSensep_PROXIMITY0_NUM_COLS_PARAM_ID              (0x5B00001Bu)

#define CapSensep_PROXIMITY0_PTR2SNS_CP_VALUE               (CapSensep_dsFlash.wdgtArray[0].ptr2SnsCpArr)
#define CapSensep_PROXIMITY0_PTR2SNS_CP_OFFSET              (28u)
#define CapSensep_PROXIMITY0_PTR2SNS_CP_SIZE                (4u)
#define CapSensep_PROXIMITY0_PTR2SNS_CP_PARAM_ID            (0xD700001Cu)


#endif /* End CY_SENSE_CapSensep_REGISTER_MAP_H */


/* [] END OF FILE */
