/***************************************************************************//**
* \file CapSensep_SensingCSD_LL.h
* \version 7.0
*
* \brief
*   This file provides the headers of APIs specific to CSD sensing implementation.
*
* \see CapSensep v7.0 Datasheet
*
*//*****************************************************************************
* Copyright (2016-2019), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*******************************************************************************/

#if !defined(CY_SENSE_CapSensep_SENSINGCSD_LL_H)
#define CY_SENSE_CapSensep_SENSINGCSD_LL_H

#include <CyLib.h>
#include <cyfitter.h>
#include <cytypes.h>
#include <cypins.h>
#include "CapSensep_Structure.h"
#include "CapSensep_Configuration.h"
#include "CapSensep_Sensing.h"

/****************************************************************************
* Register and mode mask definition
****************************************************************************/

#if (CapSensep_ENABLE == CapSensep_CSDV2)
    #define CapSensep_CSD_CSDCMP_INIT                                (CapSensep_CSDCMP_CSDCMP_DISABLED)

    /* SW_HS_P_SEL switches state for Coarse initialization of CMOD (sense path) */
    #if (CapSensep_ENABLE == CapSensep_CSD_EN)
        #if (CapSensep_CSD__CMOD_PAD == CapSensep_CMOD_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_COARSE_CMOD               (CapSensep_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #elif (CapSensep_CSD__CSHIELD_PAD == CapSensep_CMOD_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_COARSE_CMOD               (CapSensep_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #else
            #define CapSensep_CSD_HS_P_SEL_COARSE_CMOD               (CapSensep_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #endif /* (CapSensep_CSD__CMOD_PAD == CapSensep_CMOD_CONNECTION) */
    #else
        #define CapSensep_CSD_HS_P_SEL_COARSE_CMOD                   (0x00000000uL)
    #endif /* (CapSensep_ENABLE == CapSensep_CSD_EN) */

    #if ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN) && \
        (CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_COARSE_TANK               (CapSensep_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CapSensep_CSD__CSHIELD_PAD == CapSensep_CTANK_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_COARSE_TANK               (CapSensep_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CapSensep_CSD__CMOD_PAD == CapSensep_CTANK_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_COARSE_TANK               (CapSensep_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CapSensep_CSD_HS_P_SEL_COARSE_TANK               (CapSensep_SW_HS_P_SEL_SW_HMMA_STATIC_CLOSE)
        #endif /* (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION) */
    #else
        #define CapSensep_CSD_HS_P_SEL_COARSE_TANK                   (0x00000000uL)
    #endif /* ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN) && \
               (CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN)) */

    #define CapSensep_CSD_SW_HS_P_SEL_COARSE                         (CapSensep_HS_P_SEL_COARSE_CMOD | CapSensep_CSD_HS_P_SEL_COARSE_TANK)

    /* C_mod config */
    #if ((CapSensep_CSD__CMOD_PAD == CapSensep_CMOD_CONNECTION) || (CapSensep_CSD__CMOD_PAD == CapSensep_CTANK_CONNECTION))
        #define CapSensep_CSD_SW_FW_MOD_SEL_INIT             (CapSensep_SW_FW_MOD_SEL_SW_F1PM_STATIC_CLOSE |\
                                                                     CapSensep_SW_FW_MOD_SEL_SW_F1MA_STATIC_CLOSE |\
                                                                     CapSensep_SW_FW_MOD_SEL_SW_F1CA_STATIC_CLOSE)
        #define CapSensep_SW_DSI_SEL_CMODPAD                 (CapSensep_SW_DSI_CMOD)
    #else
        #define CapSensep_CSD_SW_FW_MOD_SEL_INIT             (0x00000000uL)
        #define CapSensep_SW_DSI_SEL_CMODPAD                 (0x00000000uL)
    #endif /* (CapSensep_CSD__CMOD_PAD == CapSensep_CMOD_CONNECTION) */

    /* C_tank config */
    #if ((CapSensep_CSD__CSH_TANK_PAD == CapSensep_CMOD_CONNECTION) || (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION))
        #define CapSensep_CSD_SW_FW_TANK_SEL_INIT            (CapSensep_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE |\
                                                                     CapSensep_SW_FW_TANK_SEL_SW_F2MA_STATIC_CLOSE |\
                                                                     CapSensep_SW_FW_TANK_SEL_SW_F2CA_STATIC_CLOSE)
        #define CapSensep_SW_DSI_SEL_TANKPAD                 (CapSensep_SW_DSI_CTANK)
    #else
        #define CapSensep_CSD_SW_FW_TANK_SEL_INIT            (0x00000000uL)
        #define CapSensep_SW_DSI_SEL_TANKPAD                 (0x00000000uL)
    #endif /* (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION) */

    #define CapSensep_CSD_SW_SHIELD_SEL_INIT                 (CapSensep_SW_SHIELD_SEL_SW_HCAV_HSCMP)

    /* Defining default HW configuration according to settings in customizer. */
    #define CapSensep_DEFAULT_CSD_CONFIG                 (CapSensep_CONFIG_FILTER_DELAY_12MHZ |\
                                                                 CapSensep_CONFIG_SAMPLE_SYNC_MASK)
    #if (CapSensep_ENABLE == CapSensep_CSD_AUTO_ZERO_EN)
        /* Enable CSDCMP */
        #define CapSensep_CSD_CSDCMP_SCAN                (CapSensep_CSDCMP_CSDCMP_EN_MASK |\
                                                                 CapSensep_CSDCMP_AZ_EN_MASK)
    #else
        /* Enable CSDCMP */
        #define CapSensep_CSD_CSDCMP_SCAN                (CapSensep_CSDCMP_CSDCMP_EN_MASK)
    #endif /* (CapSensep_ENABLE == CapSensep_CSD_AUTO_ZERO_EN) */

    #if ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN) && \
        (CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN))
        /* SW_HS_P_SEL switches state for Coarse initialization of CTANK (sense path) */
        #if (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_SCAN_TANK                 (CapSensep_SW_HS_P_SEL_SW_HMPT_STATIC_CLOSE)
        #elif (CapSensep_CSD__CSHIELD_PAD == CapSensep_CTANK_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_SCAN_TANK                 (CapSensep_SW_HS_P_SEL_SW_HMPS_STATIC_CLOSE)
        #elif (CapSensep_CSD__CMOD_PAD == CapSensep_CTANK_CONNECTION)
            #define CapSensep_CSD_HS_P_SEL_SCAN_TANK                 (CapSensep_SW_HS_P_SEL_SW_HMPM_STATIC_CLOSE)
        #else
            #define CapSensep_CSD_HS_P_SEL_SCAN_TANK                 (CapSensep_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
        #endif /* (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION) */
        #define CapSensep_CSD_SW_HS_P_SEL_SCAN                       (CapSensep_HS_P_SEL_SCAN_TANK)
    #elif(CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN)
        #define CapSensep_CSD_SW_HS_P_SEL_SCAN                       (CapSensep_SW_HS_P_SEL_SW_HMMB_STATIC_CLOSE)
    #else
        #define CapSensep_CSD_SW_HS_P_SEL_SCAN                       (CapSensep_STATIC_OPEN)
    #endif /* ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN) && \
               (CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN)) */

    /* SW_FW_MOD_SEL switches state for Coarse initialization of CMOD (sense path) */
    #define CapSensep_CSD_SW_FW_MOD_SEL_SCAN                     (0x00000000uL)

    #if((CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN) && \
        (CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN) && \
        (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION))
        #define CapSensep_CSD_SW_FW_TANK_SEL_SCAN                (CapSensep_SW_FW_TANK_SEL_SW_F2PT_STATIC_CLOSE | \
                                                                         CapSensep_SW_FW_TANK_SEL_SW_F2CB_STATIC_CLOSE)
    #else
        #define CapSensep_CSD_SW_FW_TANK_SEL_SCAN                (0x00000000uL)
    #endif /* ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN) && \
               (CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN) && \
               (CapSensep_CSD__CSH_TANK_PAD == CapSensep_CTANK_CONNECTION)) */

    /* Shield switch default config */
    #if ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN) && \
         (CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN))
        #if (CapSensep_IDAC_SINKING == CapSensep_CSD_IDAC_CONFIG)
            #define CapSensep_CSD_SW_SHIELD_SEL_SCAN             (CapSensep_SW_SHIELD_SEL_SW_HCBG_HSCMP)
        #else
            #define CapSensep_CSD_SW_SHIELD_SEL_SCAN             (CapSensep_SW_SHIELD_SEL_SW_HCBV_HSCMP)
        #endif /* (CapSensep_IDAC_SINKING == CapSensep_CSD_IDAC_CONFIG) */
    #elif(CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN)
        #if (CapSensep_IDAC_SINKING == CapSensep_CSD_IDAC_CONFIG)
            #define CapSensep_CSD_SW_SHIELD_SEL_SCAN             (CapSensep_SW_SHIELD_SEL_SW_HCBV_PHI1 | \
                                                                         CapSensep_SW_SHIELD_SEL_SW_HCBG_PHI2_HSCMP)
        #else
            #define CapSensep_CSD_SW_SHIELD_SEL_SCAN             (CapSensep_SW_SHIELD_SEL_SW_HCBG_PHI1 | \
                                                                         CapSensep_SW_SHIELD_SEL_SW_HCBV_PHI2_HSCMP)
        #endif /* (CapSensep_IDAC_SINKING == CapSensep_CSD_IDAC_CONFIG) */
    #else
        #define CapSensep_CSD_SW_SHIELD_SEL_SCAN                 (0x00000000uL)
    #endif /* ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN) && \
               (CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN)) */

    #define CapSensep_CSD_SW_RES_INIT                            (CapSensep_CSD_INIT_SWITCH_RES << CYFLD_CSD_RES_HCAV__OFFSET)
    #define CapSensep_CSD_SW_RES_SCAN                            ((CapSensep_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBV__OFFSET) |\
                                                                         (CapSensep_CSD_SHIELD_SWITCH_RES << CYFLD_CSD_RES_HCBG__OFFSET))

    #define CapSensep_CSD_SHIELD_GPIO_DM                         (CapSensep_GPIO_STRGDRV)
    #define CapSensep_CSD_SENSOR_HSIOM_SEL                       (CapSensep_HSIOM_SEL_CSD_SENSE)
    #define CapSensep_CSD_SHIELD_HSIOM_SEL                       (CapSensep_HSIOM_SEL_CSD_SHIELD)
    #define CapSensep_CSD_CMOD_HSIOM_SEL                         (CapSensep_HSIOM_SEL_AMUXA)

    #define CapSensep_DEFAULT_IDAC_MOD_BALL_MODE                 ((uint32)CapSensep_IDAC_MOD_BALL_MODE_FULL <<\
                                                                         CYFLD_CSD_BAL_MODE__OFFSET)
    #define CapSensep_DEFAULT_IDAC_COMP_BALL_MODE                ((uint32)CapSensep_IDAC_COMP_BALL_MODE_FULL <<\
                                                                         CYFLD_CSD_BAL_MODE__OFFSET)

    #define CapSensep_DEFAULT_SENSE_DUTY_SEL                     (CapSensep_SENSE_DUTY_OVERLAP_PHI1_MASK |\
                                                                         CapSensep_SENSE_DUTY_OVERLAP_PHI2_MASK)

    #define CapSensep_CSD_CAL_MIDDLE_VALUE                       (0x40u)
    #define CapSensep_CSD_CAL_IDAC_MAX_VALUE                     (127u)

    #define CapSensep_DELAY_EXTRACYCLES_NUM                      (9u)

    /* Clock Source Mode */
    #if (CapSensep_CLK_SOURCE_DIRECT == CapSensep_CSD_SNS_CLK_SOURCE)
        #define CapSensep_DEFAULT_MODULATION_MODE                (CapSensep_CLK_SOURCE_DIRECT)
    #elif (CapSensep_CLK_SOURCE_PRSAUTO == CapSensep_CSD_SNS_CLK_SOURCE)
        #define CapSensep_DEFAULT_MODULATION_MODE                (CapSensep_CLK_SOURCE_SSC2)
    #elif ((CapSensep_CLK_SOURCE_PRS8) == CapSensep_CSD_SNS_CLK_SOURCE)
        #define CapSensep_DEFAULT_MODULATION_MODE                (CapSensep_CSD_SNS_CLK_SOURCE)
    #elif ((CapSensep_CLK_SOURCE_PRS12) == CapSensep_CSD_SNS_CLK_SOURCE)
        #define CapSensep_DEFAULT_MODULATION_MODE                (CapSensep_CSD_SNS_CLK_SOURCE)
    #else
        #define CapSensep_DEFAULT_MODULATION_MODE                (CapSensep_CSD_SNS_CLK_SOURCE)
    #endif /* (CapSensep_CLK_SOURCE_DIRECT != CapSensep_CSD_SNS_CLK_SOURCE) */

    /* IDACs Ranges */
    #if (CapSensep_IDAC_GAIN_LOW == CapSensep_CSD_IDAC_GAIN)
        #define CapSensep_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSensep_IDAC_MOD_RANGE_IDAC_LO << CYFLD_CSD_RANGE__OFFSET)
        #define CapSensep_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSensep_IDAC_COMP_RANGE_IDAC_LO << CYFLD_CSD_RANGE__OFFSET)
    #elif (CapSensep_IDAC_GAIN_MEDIUM == CapSensep_CSD_IDAC_GAIN)
        #define CapSensep_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSensep_IDAC_MOD_RANGE_IDAC_MED << CYFLD_CSD_RANGE__OFFSET)
        #define CapSensep_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSensep_IDAC_COMP_RANGE_IDAC_MED << CYFLD_CSD_RANGE__OFFSET)
    #else
        #define CapSensep_DEFAULT_IDAC_MOD_RANGE                 ((uint32)CapSensep_IDAC_MOD_RANGE_IDAC_HI << CYFLD_CSD_RANGE__OFFSET)
        #define CapSensep_DEFAULT_IDAC_COMP_RANGE                ((uint32)CapSensep_IDAC_COMP_RANGE_IDAC_HI << CYFLD_CSD_RANGE__OFFSET)
    #endif

    /* IDACs Polarities */
    #if (CapSensep_IDAC_SINKING == CapSensep_CSD_IDAC_CONFIG)
        #define CapSensep_DEFAULT_IDAC_MOD_POLARITY              ((uint32)CapSensep_IDAC_MOD_POLARITY_VDDA_SNK << CYFLD_CSD_POLARITY__OFFSET)
        #define CapSensep_DEFAULT_IDAC_COMP_POLARITY             ((uint32)CapSensep_IDAC_COMP_POLARITY_VDDA_SNK << CYFLD_CSD_POLARITY__OFFSET)
    #else
        #define CapSensep_DEFAULT_IDAC_MOD_POLARITY              ((uint32)CapSensep_IDAC_MOD_POLARITY_VSSA_SRC << CYFLD_CSD_POLARITY__OFFSET)
        #define CapSensep_DEFAULT_IDAC_COMP_POLARITY             ((uint32)CapSensep_IDAC_COMP_POLARITY_VSSA_SRC << CYFLD_CSD_POLARITY__OFFSET)
    #endif /* (CapSensep_IDAC_SINKING == CapSensep_CSD_IDAC_CONFIG) */

    #define CapSensep_SW_REFGEN_VREF_SRC                         (CapSensep_SW_REFGEN_SEL_SW_SGR_MASK)

    /* IDAC legs configuration */
    #if (CapSensep_ENABLE == CapSensep_CSD_IDAC_COMP_EN)
            #define CapSensep_DEFAULT_SW_REFGEN_SEL              (CapSensep_SW_REFGEN_VREF_SRC | CapSensep_SW_REFGEN_SEL_SW_IAIB_MASK)
    #else
            #define CapSensep_DEFAULT_SW_REFGEN_SEL              (CapSensep_SW_REFGEN_VREF_SRC)
    #endif /* (CapSensep_ENABLE == CapSensep_CSD_IDAC_COMP_EN) */

    /* IDACs register configuration is based on the Component configuration */
    #define CapSensep_IDAC_MOD_DEFAULT_CFG                       (CapSensep_DEFAULT_IDAC_MOD_RANGE | \
                                                                         CapSensep_DEFAULT_IDAC_MOD_POLARITY | \
                                                                         CapSensep_DEFAULT_IDAC_MOD_BALL_MODE | \
                                                                        ((uint32)(CapSensep_IDAC_MOD_LEG1_MODE_CSD << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)(CapSensep_IDAC_MOD_LEG2_MODE_CSD << CYFLD_CSD_LEG2_MODE__OFFSET)) | \
                                                                         CapSensep_IDAC_MOD_LEG1_EN_MASK)

    #define CapSensep_IDAC_COMP_DEFAULT_CFG                      (CapSensep_DEFAULT_IDAC_COMP_RANGE | \
                                                                         CapSensep_DEFAULT_IDAC_COMP_POLARITY | \
                                                                         CapSensep_DEFAULT_IDAC_COMP_BALL_MODE | \
                                                                        ((uint32)(CapSensep_IDAC_COMP_LEG1_MODE_CSD_STATIC << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)(CapSensep_IDAC_COMP_LEG2_MODE_CSD_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET)) | \
                                                                         CapSensep_IDAC_COMP_LEG1_EN_MASK)

    #define CapSensep_IDAC_MOD_CALIBRATION_CFG                   ((uint32)(CapSensep_DEFAULT_IDAC_MOD_RANGE | \
                                                                         CapSensep_DEFAULT_IDAC_MOD_POLARITY | \
                                                                         CapSensep_DEFAULT_IDAC_MOD_BALL_MODE | \
                                                                        ((uint32)(CapSensep_IDAC_MOD_LEG1_MODE_CSD << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                         CapSensep_IDAC_MOD_LEG1_EN_MASK | \
                                                                        ((uint32)((uint32)CapSensep_IDAC_MOD_LEG2_MODE_GP_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET))))

    #define CapSensep_IDAC_COMP_CALIBRATION_CFG                  ((uint32)(CapSensep_DEFAULT_IDAC_COMP_RANGE | \
                                                                         CapSensep_DEFAULT_IDAC_COMP_POLARITY | \
                                                                         CapSensep_DEFAULT_IDAC_COMP_BALL_MODE | \
                                                                        ((uint32)((uint32)CapSensep_IDAC_COMP_LEG1_MODE_GP_STATIC << CYFLD_CSD_LEG1_MODE__OFFSET)) | \
                                                                        ((uint32)((uint32)CapSensep_IDAC_COMP_LEG2_MODE_GP_STATIC << CYFLD_CSD_LEG2_MODE__OFFSET))))
#else
    #if (CapSensep_ENABLE == CapSensep_CSD_IDAC_COMP_EN)
        #define CapSensep_CSD_CAL_IDAC_MAX_VALUE                 (127u)
        #define CapSensep_CSD_CAL_MIDDLE_VALUE                   (0x40u)
    #else
        #define CapSensep_CSD_CAL_IDAC_MAX_VALUE                 (255u)
        #define CapSensep_CSD_CAL_MIDDLE_VALUE                   (0x80u)
    #endif

    #define CapSensep_IDAC_MOD_CFG_MASK                  (CapSensep_IDAC_POLARITY1_MIR_MASK |\
                                                                CapSensep_IDAC_MOD_RANGE_MASK |\
                                                                CapSensep_IDAC_MOD_MODE_MASK |\
                                                                CapSensep_IDAC_MOD_MASK)

    #define CapSensep_IDAC_COMP_CFG_MASK                 (CapSensep_IDAC_POLARITY2_MIR_MASK |\
                                                                CapSensep_IDAC_COMP_RANGE_MASK |\
                                                                CapSensep_IDAC_COMP_MODE_MASK |\
                                                                CapSensep_IDAC_COMP_MASK)

        #define CapSensep_PRS_8_CONFIG                       CapSensep_CONFIG_PRS_SELECT_MASK
    #define CapSensep_PRS_12_CONFIG                      (CapSensep_CONFIG_PRS_12_8_MASK |\
                                                                CapSensep_CONFIG_PRS_SELECT_MASK)

    /* Third-generation HW block Initial PRS mode */
    #if (CapSensep_CLK_SOURCE_PRS8 == CapSensep_CSD_SNS_CLK_SOURCE)
        #define CapSensep_DEFAULT_MODULATION_MODE        CapSensep_CONFIG_PRS_SELECT_MASK

    #elif (CapSensep_CLK_SOURCE_PRS12 == CapSensep_CSD_SNS_CLK_SOURCE)
        #define CapSensep_DEFAULT_MODULATION_MODE        (CapSensep_CONFIG_PRS_12_8_MASK |\
                                                                CapSensep_CONFIG_PRS_SELECT_MASK)
    #else
        #define CapSensep_DEFAULT_MODULATION_MODE        (0u)
    #endif /* (CapSensep_CSD_SNS_CLK_SOURCE == CapSensep_PRS_8BITS) */

    /* Defining default CSD configuration according to settings in customizer. */
    #define CapSensep_DEFAULT_CSD_CONFIG                 (CapSensep_CONFIG_SENSE_COMP_BW_MASK |\
                                                                CapSensep_DEFAULT_IDAC_POLARITY |\
                                                                CapSensep_CONFIG_SENSE_INSEL_MASK |\
                                                                CapSensep_CONFIG_REFBUF_DRV_MASK)

    /* Third-generation HW block Defining mask intended for clearing bits related to pre-charging options. */
    #define CapSensep_PRECHARGE_CONFIG_MASK              (CapSensep_CONFIG_REFBUF_EN_MASK |\
                                                                CapSensep_CONFIG_COMP_MODE_MASK |\
                                                                CapSensep_CONFIG_COMP_PIN_MASK  |\
                                                                CapSensep_CONFIG_REFBUF_OUTSEL_MASK)

    #define CapSensep_CMOD_PRECHARGE_CONFIG              (CapSensep_DEFAULT_CSD_CONFIG |\
                                                                CapSensep_CONFIG_REFBUF_EN_MASK |\
                                                                CapSensep_CONFIG_COMP_PIN_MASK)

    #define CapSensep_CMOD_PRECHARGE_CONFIG_CSD_EN       (CapSensep_DEFAULT_CSD_CONFIG |\
                                                                CapSensep_CSD_ENABLE_MASK |\
                                                                CapSensep_CONFIG_REFBUF_EN_MASK |\
                                                                CapSensep_CONFIG_COMP_PIN_MASK)


    #if (CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN)
        #if((CapSensep_ENABLE == CapSensep_CSD_SHIELD_TANK_EN) &&\
            (CapSensep_CSH_PRECHARGE_IO_BUF == CapSensep_CSD_CSH_PRECHARGE_SRC))
            #define  CapSensep_CTANK_PRECHARGE_CONFIG    (CapSensep_DEFAULT_CSD_CONFIG |\
                                                                 CapSensep_CONFIG_REFBUF_OUTSEL_MASK |\
                                                                 CapSensep_CONFIG_REFBUF_EN_MASK |\
                                                                 CapSensep_CONFIG_COMP_MODE_MASK |\
                                                                 CapSensep_CONFIG_PRS_CLEAR_MASK |\
                                                                 CapSensep_CONFIG_COMP_PIN_MASK)
        #else
            #define  CapSensep_CTANK_PRECHARGE_CONFIG    (CapSensep_DEFAULT_CSD_CONFIG |\
                                                                 CapSensep_CONFIG_REFBUF_EN_MASK |\
                                                                 CapSensep_CONFIG_PRS_CLEAR_MASK |\
                                                                 CapSensep_CONFIG_REFBUF_OUTSEL_MASK)
        #endif
    #else
        #define  CapSensep_CTANK_PRECHARGE_CONFIG    (CapSensep_DEFAULT_CSD_CONFIG |\
                                                             CapSensep_CONFIG_REFBUF_OUTSEL_MASK |\
                                                             CapSensep_CONFIG_PRS_CLEAR_MASK)
    #endif /* (CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN) */


    #define  CapSensep_CTANK_PRECHARGE_CONFIG_CSD_EN     (CapSensep_CTANK_PRECHARGE_CONFIG |\
                                                                 CapSensep_CONFIG_ENABLE_MASK |\
                                                                 CapSensep_CONFIG_SENSE_COMP_EN_MASK)

#endif /* (CapSensep_ENABLE == CapSensep_CSDV2) */

#define CapSensep_CSD_AVG_CYCLES_PER_LOOP                   (5u)
#define CapSensep_CSD_MEASURE_MAX_TIME_US                   (200000u)
#define CapSensep_CSD_PRECHARGE_MAX_TIME_US                 (50u)
#define CapSensep_CSD_ONE_CLOCK_MAX_TIME_US                 (50u)
#define CapSensep_WIDGET_MAX_SCAN_TIME_US                   (5u * 1000000u)

#define CapSensep_CSD_CALIBR_WATCHDOG_CYCLES_NUM            (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSensep_CSD_MEASURE_MAX_TIME_US)) /\
                                                                    (CapSensep_CSD_AVG_CYCLES_PER_LOOP))
#define CapSensep_CSD_PRECHARGE_WATCHDOG_CYCLES_NUM         (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSensep_CSD_PRECHARGE_MAX_TIME_US)) /\
                                                                    (CapSensep_CSD_AVG_CYCLES_PER_LOOP))
#define CapSensep_ONE_CLOCK_WATCHDOG_CYCLES_NUM             (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSensep_CSD_ONE_CLOCK_MAX_TIME_US)) /\
                                                                    (CapSensep_CSD_AVG_CYCLES_PER_LOOP))
#define CapSensep_WIDGET_MAX_SCAN_TIME                      (((CYDEV_BCLK__SYSCLK__MHZ) * (CapSensep_WIDGET_MAX_SCAN_TIME_US)) /\
                                                                    (CapSensep_CSD_AVG_CYCLES_PER_LOOP))

/***************************************
* Global software variables
***************************************/

extern uint32 CapSensep_configCsd;

#if (CapSensep_ENABLE == CapSensep_CSD_NOISE_METRIC_EN)
    extern uint8 CapSensep_badConversionsNum;
#endif /* (CapSensep_ENABLE == CapSensep_CSD_NOISE_METRIC_EN) */


/***************************************
* Function Prototypes
**************************************/

/**
* \cond SECTION_C_LOW_LEVEL
* \addtogroup group_c_low_level
* \{
*/

void CapSensep_CSDSetupWidget(uint32 widgetId);
void CapSensep_CSDSetupWidgetExt(uint32 widgetId, uint32 sensorId);
void CapSensep_CSDScan(void);
void CapSensep_CSDScanExt(void);
#if ((CapSensep_CSD_SS_DIS != CapSensep_CSD_AUTOTUNE) || \
     (CapSensep_ENABLE == CapSensep_CSD_IDAC_AUTOCAL_EN))
    cystatus CapSensep_CSDCalibrateWidget(uint32 widgetId, uint32 target);
#endif /* ((CapSensep_CSD_SS_DIS != CapSensep_CSD_AUTOTUNE) || \
           (CapSensep_ENABLE == CapSensep_CSD_IDAC_AUTOCAL_EN))  */
void CapSensep_CSDConnectSns(CapSensep_FLASH_IO_STRUCT const *snsAddrPtr);
void CapSensep_CSDDisconnectSns(CapSensep_FLASH_IO_STRUCT const *snsAddrPtr);

/** \}
* \endcond */

/*****************************************************
* Function Prototypes - internal Low Level functions
*****************************************************/

/**
* \cond SECTION_C_INTERNAL
* \addtogroup group_c_internal
* \{
*/

void CapSensep_SsCSDInitialize(void);
void CapSensep_SsCSDStartSample(void);
void CapSensep_SsCSDSetUpIdacs(CapSensep_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CapSensep_SsCSDConfigClock(void);
void CapSensep_SsCSDElectrodeCheck(void);
#if ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN) && \
     (0u != CapSensep_CSD_TOTAL_SHIELD_COUNT))
    void CapSensep_SsCSDEnableShieldElectrodes(void);
    void CapSensep_SsCSDDisableShieldElectrodes(void);
    void CapSensep_SsCSDSetShieldElectrodesState(uint32 state);
#endif /* ((CapSensep_ENABLE == CapSensep_CSD_SHIELD_EN) && \
           (0u != CapSensep_CSD_TOTAL_SHIELD_COUNT)) */
#if (CapSensep_ENABLE == CapSensep_CSDV2)
    uint32 CapSensep_SsCSDGetNumberOfConversions(uint32 snsClkDivider, uint32 resolution, uint32 snsClkSrc);
#endif /* (CapSensep_ENABLE == CapSensep_CSDV2) */
void CapSensep_SsCSDCalculateScanDuration(CapSensep_RAM_WD_BASE_STRUCT const *ptrWdgt);
void CapSensep_SsCSDConnectSensorExt(uint32 widgetId, uint32 sensorId);
void CapSensep_SsCSDDisconnectSnsExt(uint32 widgetId, uint32 sensorId);

#if ((CapSensep_CSD_SS_DIS != CapSensep_CSD_AUTOTUNE) || \
     (CapSensep_ENABLE == CapSensep_SELF_TEST_EN) || \
     (CapSensep_ENABLE == CapSensep_CSD_IDAC_AUTOCAL_EN))
#endif /* ((CapSensep_CSD_SS_DIS != CapSensep_CSD_AUTOTUNE) || \
           (CapSensep_ENABLE == CapSensep_SELF_TEST_EN) || \
           (CapSensep_ENABLE == CapSensep_CSD_IDAC_AUTOCAL_EN)) */

/** \}
* \endcond */

/***************************************
* Global software variables
***************************************/
extern uint32 CapSensep_configCsd;

/* Interrupt handler */
extern CY_ISR_PROTO(CapSensep_CSDPostSingleScan);
extern CY_ISR_PROTO(CapSensep_CSDPostMultiScan);
#if (CapSensep_ENABLE == CapSensep_CSD_GANGED_SNS_EN)
extern CY_ISR_PROTO(CapSensep_CSDPostMultiScanGanged);
#endif /* (CapSensep_ENABLE == CapSensep_CSD_GANGED_SNS_EN) */
#if (CapSensep_ENABLE == CapSensep_CSD_NOISE_METRIC_EN)
    extern uint8 CapSensep_badConversionsNum;
#endif /* (CapSensep_ENABLE == CapSensep_CSD_NOISE_METRIC_EN) */

#endif /* End CY_SENSE_CapSensep_SENSINGCSD_LL_H */


/* [] END OF FILE */
